(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    190032,       5630]*)
(*NotebookOutlinePosition[    283536,       8680]*)
(*  CellTagsIndexPosition[    278953,       8546]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Computational Physics", "OnlineHeader"],

Cell[CellGroupData[{

Cell[TextData[{

  CounterBox["Title"],

  ". ",

  "Basics of ",

  StyleBox["Mathematica",

    FontSlant->"Italic"],

  " Programming"

}], "Title",

  CounterAssignments->{{"Title", 1}}],

Cell["Paul Abbott", "Author"],

Cell[TextData[{
  "Department of Physics\nUniversity of Western Australia\nNedlands WA 6907, \
Australia\n",
  ButtonBox["paul@physics.uwa.edu.au",
    ButtonData:>{
      URL[ "mailto:paul@physics.uwa.edu.au"], None},
    ButtonStyle->"Hyperlink"],
  "\n",
  ButtonBox["physics.uwa.edu.au/~paul",
    ButtonData:>{
      URL[ "http://physics.uwa.edu.au/~paul"], None},
    ButtonStyle->"Hyperlink"]
}], "Address"],

Cell[CellGroupData[{

Cell["Pre-requisites", "Subsubsection"],

Cell[TextData[{
  "To improve the appearance of graphics, ",
  StyleBox["TraditionalForm", "InlineInputTraditionalForm"],
  " will be used as the default format type for text that appears in \
graphics,"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($FormatType = TraditionalForm;\)\)], "Input",
  InitializationCell->True],

Cell["\<\
and the default style for text in graphics is set as follows.\
\>", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\($TextStyle = {FontSize \[Rule] 10};\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Introduction"
}], "SectionFirst"],

Cell[TextData[{
  "In this assignment simple functions are used to illustrate the elements of \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming style. Aspects of the language including function \
definitions, transformation and replacement rules, pattern-matching, \
functional operations, and association are also introduced."
}], "Text"],

Cell[TextData[{
  "Built-in functions are fast and implemented in the most general way \
possible. They mesh well with other objects and their properties \[LongDash]  \
derivatives, integrals, series, special cases, numerical evaluation (for  \
arbitrary complex parameters), ",
  StyleBox["etc",
    FontSlant->"Italic"],
  ".\[LongDash] are incorporated into the kernel. "
}], "Text",
  CellTags->{"Kernel", "Built-in functions"}],

Cell["\<\
There are over 1000 built-in functions and often you do not have to write a  \
program (in the standard sense) but can solve problems by a sequence of  \
simple built-in operations. Not only are such programs elegant and compact \
but they are also efficient and modular and can serve as building blocks for  \
robust large programs.  \
\>", "Text",
  CellTags->{
  "Tour of Mathematica", "The Mathematica Journal", "Tricks of the Trade", 
    "In and Out"}],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " includes a wide array of programming constructs and programming in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is different to most other languages. Before considering the style of \
programming most appropriate for a given problem, you should check whether \
the functions or operations you require already exist in the system. In \
general, commands are interpreted rather than compiled which is usually \
convenient.  Moreover, one can do a lot of  computation without writing a \
collection of functions longer than a couple of lines each. By changing the \
parameters and selecting a range of cells, one can get ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to update all the cells \[LongDash] similar to working with a spreadsheet \
\[LongDash] and this is, for many purposes, all the programming needed to get \
the answer to a wide range of problems."
}], "Text",
  CellTags->{"Interpreted code", "Compiled code", "Spreadsheet"}],

Cell[TextData[{
  "In these exercises I have included a number of examples which are  \
applicable to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programs of all sizes.  Time spent writing few-line programs is rarely \
wasted because it is more likely to lead to code that is elegant, efficient, \
robust, maintainable, understandable, verifiable, and extensible. "
}], "Text",
  CellTags->{
  "Programming principles", "Program verification", "Efficiency", 
    "Generalisation"}],

Cell[TextData[{
  "The range and flavour of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming styles are illustrated using simple examples: First, a \
factorial exposition outlines the different styles available. Two sections on \
the fundamental tools \[LongDash] functional programming, pattern-matching  \
and replacement rules \[LongDash] are demonstrated using a number of \
exercises. The section on association highlights the advantages and pitfalls \
of association. The last section presents a brief discussion on writing \
programs by collecting together code fragments."
}], "Text"],

Cell["\<\
A number of basic principles are identified which, it is hoped, will help the \
reader take advantage of the possibilities offered by this high-level, \
powerful, and flexible, programming language.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Factorial!"
}], "Section"],

Cell[TextData[{
  "In the following examples, the factorial function is used to present an \
overview of the range of ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "programming styles available. The factorial function is an excellent \
vehicle for expounding the various ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "programming styles because it admits such a large number of points of \
view:",
  StyleBox[" ",
    FontSlant->"Italic"]
}], "Text",
  CellTags->{"Factorial", "Programming styles"}],

Cell[TextData[{
  StyleBox["Multiplicative",
    FontSlant->"Italic"],
  " \[LongDash] ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\  = \ 
        1\ 2\ 3\ \[Ellipsis]\ \((n - 1)\)\ n\)]],
  ". This can be used as the basis for simple non-recursive procedural code  \
and also for a functional implementation."
}], "BulletedList",
  CellTags->{"Procedural programming", "Functional programming"}],

Cell[TextData[{
  StyleBox["Recursive or Inductive",
    FontSlant->"Italic"],
  " \[LongDash] ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\  = \ n\ \(\((n - 1)\)!\); \ \(0!\)\  = \ 
        1\)]],
  ". This definition is easily implemented using recursive (inductive) \
programming and can be made efficient so as to avoid repetitive computation."
}], "BulletedList",
  CellTags->{"Recursive programming", "Efficiency", "Inductive programming"}],

Cell[TextData[{
  StyleBox["Analytic",
    FontSlant->"Italic"],
  " \[LongDash] ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma](n + 1)\  = \ \(n!\)\)]],
  ". Analytic continuation of factorial to complex arguments permits series \
and asymptotic expansions and leads on to approximations."
}], "BulletedList",
  CellTags->{"Series", "Asymptotic expansion", "Analytic representation"}],

Cell[TextData[{
  StyleBox["Horner",
    FontSlant->"Italic"],
  " \[LongDash] ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\  = \ \((\(\[Ellipsis](\((\((1\ 2)\)\ 3)\)\ \
4)\)\ \[Ellipsis]\ \((n - 1)\))\)\ n\)]],
  ". Though this might not look different to the multiplicative definition  \
above, the emphasis here is on pair-wise operations, starting from the inside \
and working outwards. See below for more on ",
  ButtonBox["Horner representations",
    ButtonData:>"Horner representation",
    ButtonStyle->"Hyperlink"],
  "."
}], "BulletedList",
  CellTags->{"Pair-wise operations", "Functional programming"}],

Cell[TextData[{
  "To some extent each of these viewpoints is naturally implemented using a \
particular style of programming. An important question to help select a \
programming style is whether the code will work for both numerical and \
symbolic parameters (if appropriate) and the ease of generalisation to more \
parameters, ",
  StyleBox["e.g.",
    FontSlant->"Italic"],
  ", to two and more dimensions.  In many situations, a specific choice of \
programming style may present itself as optimal because it most naturally \
handles the widest range of possibilities; functional programs often satisfy \
this criteria."
}], "Text",
  CellTags->{
  "Optimal programming style", "Functional programming", "Generalisation"}],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Built-in"
}], "Subsection",
  CellTags->"Built-in functions"],

Cell[TextData[{

  "The factorial function is, of course, ",

  StyleBox["built-in",

    FontSlant->"Italic"],

  ":"

}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(10!\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`3628800\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Alternatively, one can use the Gamma function (",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma](n + 1) \[Congruent] \(n!\)\)]],
  ") which  generalises factorial to non-integer, negative, and complex \
values."
}], "Text",
  CellTags->{"Gamma function", "Generalisation"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\[CapitalGamma](11)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`3628800\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Compute 100!."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Procedural"
}], "Subsection",
  CellTags->"Procedural programming"],

Cell[TextData[{

  "Fortran, Pascal, or C programmers will probably understand the following ",

  

  StyleBox["procedural code",

    FontSlant->"Italic"],

  " without any explanation:"

}], "Text",

  CellTags->"Procedural programming"],

Cell[BoxData[
    \(TraditionalForm\`\(facProcedural = \[IndentingNewLine]Function[{n}, \
\[IndentingNewLine]Module[{i = 1, s = 1}, \n\t
            While[i < n, \(i++\); 
              s = s\ i]; \[IndentingNewLine]s]\[IndentingNewLine]];\)\)], \
"Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facProcedural[10] == \(10!\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter this code and use it to verify that it also works for ",
  Cell[BoxData[
      \(TraditionalForm\`\(100!\)\)]],
  "."
}], "BeginEndQuestion"],

Cell[TextData[{
  "The syntactical subleties are the use of ",
  ButtonBox["Function",
    ButtonData:>"Function",
    ButtonStyle->"Hyperlink"],
  ", denoting a ",
  StyleBox["pure",
    FontSlant->"Italic"],
  " or ",
  StyleBox["anonymous function",
    FontSlant->"Italic"],
  ", and ",
  ButtonBox["Module",
    ButtonData:>"Module",
    ButtonStyle->"Hyperlink"],
  ", which delimits a block of code."
}], "Text",
  CellTags->"Pure function"],

Cell["Advantages of procedural style include: ", "Text"],

Cell["many users come from a procedural programming background;", \
"BulletedList",
  CellTags->"Procedural programming"],

Cell["\<\
(pseudo-) compilation of procedural code is relatively straightforward;\
\>", "BulletedList",
  CellTags->"Compilation"],

Cell["\<\
conversion of procedural code to fortran or C is easier than for other \
programming styles.\
\>", "BulletedList",
  CellTags->"Conversion to fortran or C"],

Cell["Disadvantages include:", "Text"],

Cell[TextData[{
  "unnecessary ",
  StyleBox["dummy variables",
    FontSlant->"Italic"],
  " often need to be introduced; the above implementation uses two dummy \
variables, ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`s\)]],
  ";"
}], "BulletedList",
  CellTags->"Dummy variables"],

Cell["\<\
generalisation, such as extension to higher dimensions or to symbolic \
arguments, when appropriate, is not always straightforward;\
\>", "BulletedList",
  CellTags->"Generalisation"],

Cell[TextData[{
  "other styles, such as rule-based and functional programming, take \
advantage of the way the ",
  StyleBox["Mathematica ",
    FontSlant->"Italic"],
  "system was designed;"
}], "BulletedList",
  CellTags->{"Optimal programming style", "Mathematica design"}],

Cell[TextData[{
  "procedural programs in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " are usually less efficient."
}], "BulletedList",
  CellTags->"Efficiency"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Recursive"
}], "Subsection",
  CellTags->"Recursive programming"],

Cell[TextData[{

  "The recursive view of the factorial function leads to the following ",

  StyleBox["recursive program",

    FontSlant->"Italic"],

  " which may appear more natural:"

}], "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`facRecursive[n_] := If[n == 1, 1, n\ facRecursive[n - 1]]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facRecursive[10] == \(10!\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The syntactical subleties here are the use of ",
  Cell[BoxData[
      FormBox[
        StyleBox["n_",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "  (read as ",
  StyleBox["n blank",
    FontSlant->"Italic"],
  ") to denote a ",
  StyleBox["generic variable",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " whose value is bound and passed to the right-hand side of the expression  \
and ",
  Cell[BoxData[
      FormBox[
        StyleBox[":=",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " (delayed assignment or ",
  StyleBox["SetDelayed", "InlineInputTraditionalForm"],
  ") which delays execution of the right-hand side of the procedure until ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is bound to a value. "
}], "Text",
  CellTags->{
  "Blank", "Generic variables", "Delayed assignment", "SetDelayed", 
    "Variable binding"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Write a recursive function for computing the Fibonacci numbers (look-up \
the definition of the Fibonacci numbers on the web if you don't know what \
these are) and compute the the first 15 Fibonacci numbers."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Rule-based"
}], "Subsection",
  CellTags->"Rule-based programming"],

Cell[TextData[{

  "For many situations ",

  StyleBox["rule-based programming",

    FontSlant->"Italic"],

  " is often simplest and most elegant. Specifying the initial condition:"

}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(facRule[0] = 1;\)\)], "Input"],

Cell["and the general recursive rule:", "Text",

  CellTags->"Recursive programming"],

Cell[BoxData[
    \(TraditionalForm\`facRule[n_] := n\ facRule[n - 1]\)], "Input"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " automatically applies the recursive definition (up to ",
  StyleBox["$RecursionLimit", "InlineInputTraditionalForm"],
  "):"
}], "Text",
  CellTags->"$RecursionLimit"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facRule[10] == \(10!\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "One advantage of this programming style is that it is often similar to the \
actual problem specification for a wide range of problems in science and \
engineering. This fact reduces the likelihood of transcription and \
algorithmic coding errors.",
  StyleBox[" ",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"Natural implementation"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Compute the first 15 Fibonacci numbers using a rule-based function"
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Functional"
}], "Subsection",
  CellTags->"Functional programming"],

Cell[TextData[{
  "For the purpose of this overview ",
  StyleBox["functional programming ",
    FontSlant->"Italic"],
  "is defined as programming using a level of abstraction which emphasises  \
the essential algorithmic structure."
}], "Text",
  CellTags->"Functional programming"],

Cell[TextData[{
  "A functional algorithm for factorial can be stated as ",
  StyleBox["multiply together all numbers from 1 to n",
    FontSlant->"Italic"],
  ", and coded using ",
  Cell[BoxData[
      \(TraditionalForm\`Range\)]],
  ", say"
}], "Text",
  CellTags->"Range"],

Cell[BoxData[
    \(TraditionalForm\`Range[10]\)], "Input"],

Cell[TextData[{
  "and then Applying (using the shorthand ",
  StyleBox["infix",
    FontSlant->"Italic"],
  " notation ",
  Cell[BoxData[
      \(TraditionalForm\`@@\)]],
  ") the ",
  Cell[BoxData[
      \(TraditionalForm\`Times\)]],
  " operation to this List to multiply these numbers together:"
}], "Text",
  CellTags->{"Apply", "Times", "List"}],

Cell[BoxData[
    \(TraditionalForm\`Times@@%\)], "Input"],

Cell["This is easily converted into a procedure:", "Text"],

Cell[BoxData[
    \(TraditionalForm\`facFunctional[n_] := Times@@Range[n]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facFunctional[10] == \(10!\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["FoldList", "Subsubsection"],

Cell[TextData[{
  "Another important functional operation is ",
  StyleBox["FoldList", "InlineInputTraditionalForm"],
  ":"
}], "Text",
  CellTags->{"FoldList", "Functional programming"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?FoldList\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"FoldList[f, x, {a, b, ... }] gives {x, f[x, a], f[f[x, a], b], ... }."\
\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "Using ",
  StyleBox["FoldList", "InlineInputTraditionalForm"],
  " one can efficiently generate, in one pass, a whole table of factorials \
values (starting from ",
  Cell[BoxData[
      \(TraditionalForm\`\(0!\)\)]],
  "):"
}], "Text",
  CellTags->"Efficiency"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`FoldList[Times, 1, Range[10]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{1, 1, 2, 6, 24, 120, 720, 5040, 40320, 362880, 3628800}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Use ",
  StyleBox["FoldList", "InlineInputTraditionalForm"],
  " to compute the ",
  StyleBox["cumulative sum",
    FontSlant->"Italic"],
  " of the first ten integers"
}], "BeginEndQuestion"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Series"
}], "Subsection",
  CellTags->"Series"],

Cell[TextData[{
  "Truncating (using ",
  StyleBox["Normal", "InlineInputTraditionalForm"],
  ") the asymptotic series for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma](n)\)]],
  ","
}], "Text",
  CellTags->{"Asymptotic series", "Gamma function"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Normal[
      Series[\[CapitalGamma](n), {n, \[Infinity], 1}]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\[ExponentialE]\^\(-n\)\ \@\(1\/n\)\ n\^n\ \@\(2\ \
\[Pi]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "yields, using the relation ",
  Cell[BoxData[
      \(TraditionalForm\`\(n!\)\  \[Congruent] \ 
        n\ \(\[CapitalGamma](n)\)\)]],
  ","
}], "Text",
  CellTags->{"Truncation", "Normal"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facSeries[n_] = n\ %\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\[ExponentialE]\^\(-n\)\ \@\(1\/n\)\ n\^\(n + 1\)\ \
\@\(2\ \[Pi]\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This expression (the first term in ",
  StyleBox["Stirling's formula",
    FontSlant->"Italic"],
  ") is suitable for approximate computation of the factorial function. For \
example, here is the ",
  StyleBox["fractional error",
    FontSlant->"Italic"],
  " in this approximation for n from 1 to 10:"
}], "Text",
  CellTags->{"Approximation", "fractional error", "Stirling's formula"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Table[
      N[\(\(n!\) - facSeries[n]\)\/\(n!\)], {n, 10}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0.07786299110421091`, 0.04049782425550841`, 
      0.027298401442355846`, 0.020576036129446102`, 0.016506933686749055`, 
      0.01378029910807628`, 0.011826223886416142`, 0.010357255638474264`, 
      0.0092127622300806`, 0.008295960443937999`}\)], "Output"]
}, Open  ]],

Cell["\<\
This idea is quite general: if one has an analytic representation of a \
function (or a recurrence relation), an asymptotic expansion can be used to \
generate approximations.\
\>", "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute the asymptotic series for ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma](n)\)]],
  " up to the next order and use this determine the error (not the",
  " fractional error",
  ")."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Dynamic Programming"
}], "Subsection",
  CellTags->"Dynamic programming"],

Cell[TextData[{
  "As it stands, the code for ",
  Cell[BoxData[
      \(TraditionalForm\`facRule\)]],
  " above is somewhat inefficient. After entering"
}], "Text",
  CellTags->"Efficiency"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facRule[10]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`3628800\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "one can use ",
  Cell[BoxData[
      \(TraditionalForm\`?\)]],
  " (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Information\)]],
  ") to see the values assigned to ",
  Cell[BoxData[
      \(TraditionalForm\`facRule\)]],
  ": "
}], "Text",
  CellTags->{"Information", "?"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?facRule\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Global`facRule"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        StyleBox[\(facRule[0]\  = \ 1\n\ \n
          facRule[n_]\  := \ n*facRule[n\  - \ 1]\),
          ShowStringCharacters->True,
          NumberMarks->True],
        InputForm[ 
          Definition[ facRule]],
        Editable->True,
        AutoDelete->True], TraditionalForm]], "Print"]
}, Open  ]],

Cell[TextData[{
  "One finds that, after computing ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(facRule[10]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ", intermediate values have not been saved.  This can be addressed by using \
 ",
  StyleBox["dynamic programming",
    FontSlant->"Italic"],
  ", ",
  StyleBox["i.e.,",
    FontSlant->"Italic"],
  " saving the intermediate results. The syntax for this is always of the  \
form",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox[\(f[n_]\  := \ \(f[n]\  = \  ... \)\),
            "InlineInputTraditionalForm"]}], TraditionalForm]]],
  ", and so is easily implemented:"
}], "Text",
  CellTags->"Dynamic programming"],

Cell[BoxData[
    \(TraditionalForm\`\(facDynamic[0] = 1; \)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`facDynamic[n_] := \(facDynamic[n] = 
        n\ facDynamic[n - 1]\)\)], "Input"],

Cell["Now, after computing the factorial of 3:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facDynamic[3]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`6\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "a check on ",
  Cell[BoxData[
      \(TraditionalForm\`facDynamic\)]],
  " reveals that the intermediate values have been recorded:"
}], "Text",
  CellTags->"?"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?facDynamic\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Global`facDynamic"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        StyleBox[\(facDynamic[0]\  = \ 1\n\ \n
          facDynamic[1]\  = \ 1\n\ \n
          facDynamic[2]\  = \ 2\n\ \n
          facDynamic[3]\  = \ 6\n\ \n
          
          facDynamic[n_]\  := \ 
            \(facDynamic[n]\  = \ n*facDynamic[n\  - \ 1]\)\),
          ShowStringCharacters->True,
          NumberMarks->True],
        InputForm[ 
          Definition[ facDynamic]],
        Editable->True,
        AutoDelete->True], TraditionalForm]], "Print"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Use ",
  StyleBox["dynamic programming",
    FontSlant->"Italic"],
  " to write a function called ",
  StyleBox["fib", "InlineInputTraditionalForm"],
  " for computing the fibonacci numbers. Compute the first 200 Fibonacci \
numbers.  Use ",
  StyleBox["ListPlot", "InlineInputTraditionalForm"],
  " to show the logarithm of the Fibonacci numbers you have just computed. \
Note that ",
  StyleBox["Log", "InlineInputTraditionalForm"],
  " is ",
  StyleBox["Listable", "InlineInputTraditionalForm"],
  " (Can you guess what ",
  StyleBox["Listable", "InlineInputTraditionalForm"],
  " means?)"
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". ",
  "Compute (and numerically evaluate) the successive ratios of Fibonacci  \
numbers (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": ",
  StyleBox["RotateLeft", "InlineInputTraditionalForm"],
  " may be helpful here).  Estimate the limit of this ratio."
}], "BeginEndQuestion"],

Cell[TextData[{
  "The down-side of dynamic programming is that, because all intermediate  \
values or expressions are being stored, it is possible to run out of memory  \
using this approach. Another disadvantage, particularly when developing code, \
is that if you want to change any of the defining functions you need to ",
  StyleBox["Remove", "InlineInputTraditionalForm"],
  " all rules, make the necessary modification, and then re-enter them."
}], "Text",
  CellTags->{"Storage", "Remove"}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Argument Checking"
}], "Subsection",
  CellTags->"Argument checking"],

Cell[TextData[{
  "One defect of ",
  Cell[BoxData[
      \(TraditionalForm\`facDynamic\)]],
  " is that its code only makes sense for positive integer arguments.  "
}], "Text"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Enter ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(facDynamic[\(-3\)]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(facDynamic[m]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " and describe what happens"
}], "BeginEndQuestion"],

Cell["", "Answer"],

Cell[TextData[{
  "Conditions to check the validity of function arguments are easily  \
incorporated. The argument ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " to factorial must be ",
  StyleBox["Positive", "InlineInputTraditionalForm"],
  " and an ",
  StyleBox["Integer", "InlineInputTraditionalForm"],
  ". ",
  "After removing the previous definitions for ",
  StyleBox["facDynamic", "InlineInputTraditionalForm"],
  ":"
}], "Text",
  CellTags->{"Condition", "Positive", "Integer", "?"}],

Cell[BoxData[
    \(TraditionalForm\`Remove[facDynamic]\)], "Input"],

Cell[TextData[{

  "we can implement this in ",

  StyleBox["Mathematica",

    FontSlant->"Italic"],

  " syntax as"

}], "Text",

  CellTags->"Syntax"],

Cell[BoxData[
    \(TraditionalForm\`\(facDynamic[0] = 1; \)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`facDynamic[n_Integer?Positive] := 
      \(facDynamic[n] = n\ facDynamic[n - 1]\)\)], "Input"],

Cell["Here are four examples. The first evaluates as before,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facDynamic[3]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`6\)], "Output"]
}, Open  ]],

Cell["The second,", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facDynamic[y]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`facDynamic(y)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "fails because ",
  StyleBox["y", "InlineInputTraditionalForm"],
  " is not an integer. The third"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facDynamic[\(-5\)]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`facDynamic(\(-5\))\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "fails because ",
  StyleBox["-5", "InlineInputTraditionalForm"],
  " is not positive and, finally,"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facDynamic[1.2]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"facDynamic", "(", 
        StyleBox["1.19999999999999996`",
          StyleBoxAutoDelete->True,
          PrintPrecision->2], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "fails because ",
  StyleBox["1.2", "InlineInputTraditionalForm"],
  " is not an integer."
}], "Text"],

Cell[TextData[{

  StyleBox["Mathematica",

    FontSlant->"Italic"],

  " does not require the user to specify the number or type of arguments of a \

function. Here are four reasons why :"

}], "Text",

  CellTags->{"Function arguments", "Argument type"}],

Cell[TextData[{
  
  CounterBox["List"],
  ". It allows you to define and use options;"
}], "BeginNumberedList",
  CellTags->"Options"],

Cell[TextData[{
  
  CounterBox["List"],
  ". ",
  "It allows you to overload functions;"
}], "NumberedList",
  CellTags->{"Overloading", "Object-Oriented Programming"}],

Cell[TextData[{
  
  CounterBox["List"],
  ". ",
  "You can use or refer to functions before they are defined;"
}], "NumberedList"],

Cell[TextData[{
  
  CounterBox["List"],
  ". ",
  "It allows you to call functions with unspecified arguments."
}], "NumberedList",
  CellTags->"Unspecified arguments"],

Cell[CellGroupData[{

Cell["An Aside", "Subsubsection"],

Cell[TextData[{
  "You can always generate an error message if a function is called with \
inappropriate arguments.  E.g., since factorial is a function of one \
argument, the following catch-all rule (for all other cases) issues an error \
message (using the built-in ",
  Cell[BoxData[
      \(TraditionalForm\`Message\)]],
  " mechanism) if ",
  StyleBox["facDynamic", "InlineInputTraditionalForm"],
  " is called with an incorrect number of arguments:"
}], "Text",
  CellTags->{
  "Argument checking", "Function arguments", "Message", "Error messages", 
    "Catch-all rule"}],

Cell[BoxData[
    \(TraditionalForm\`facDynamic[args___] := 
      Null /; Length[{args}] \[NotEqual] 1 && 
          Message[facDynamic::"\<argx\>", facDynamic, 
            Length[{args}]]\)], "Input"],

Cell[TextData[{
  "As a side-effect of evaluating the ",
  StyleBox["Condition", "InlineInputTraditionalForm"],
  " \[LongDash] entered using the infix shorthand ",
  StyleBox["/;", "InlineInputTraditionalForm"],
  ", which can be read as such that:"
}], "Text",
  CellTags->{
  "Condition", "Side-effect", "Argument checking", "Shorthand", 
    "Infix operator"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?/;\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"patt /; test is a pattern which matches only if the evaluation of test \
yields True. lhs :> rhs /; test represents a rule which applies only if the \
evaluation of test yields True. lhs := rhs /; test is a definition to be used \
only if test yields True."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "the rule on the right-hand side computes the number of arguments using ",
  StyleBox["Length", "InlineInputTraditionalForm"],
  " and (denoted here by ",
  StyleBox["&&", "InlineInputTraditionalForm"],
  ") prints a message when it is not equal to one (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Length[{args}]\  != \ 1\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  "):"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`facDynamic[1, 2]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{\(facDynamic::"argx"\), \(\(:\)\(\ \)\), \
"\<\"\\!\\(TraditionalForm\\`facDynamic\\) called with \
\\!\\(TraditionalForm\\`2\\) arguments; 1 argument is expected.\"\>"}], 
      TraditionalForm]], "Message"],

Cell[BoxData[
    \(TraditionalForm\`facDynamic(1, 2)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note that our incorrect input is returned rather than the (dummy) ",
  StyleBox["Null", "InlineInputTraditionalForm"],
  " because the conditional test failed. Also, we see that only output  \
corresponding to valid input has been stored:"
}], "Text",
  CellTags->{"Condition", "Null"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?facDynamic\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Global`facDynamic"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        StyleBox[\(facDynamic[0]\  = \ 1\n\ \n
          facDynamic[1]\  = \ 1\n\ \n
          facDynamic[2]\  = \ 2\n\ \n
          facDynamic[3]\  = \ 6\n\ \n
          
          facDynamic[\((n_Integer)\)?Positive]\  := \ 
            \(facDynamic[n]\  = \ n*facDynamic[n\  - \ 1]\)\n\ \n
          
          facDynamic[args___]\  := \ 
            Null\  /; \ 
              Length[{args}]\  != \ 1\  && \ 
                Message[facDynamic::argx, \ facDynamic, \ Length[{args}]]\),
          ShowStringCharacters->True,
          NumberMarks->True],
        InputForm[ 
          Definition[ facDynamic]],
        Editable->True,
        AutoDelete->True], TraditionalForm]], "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Tracing Computations"
}], "Subsection",
  CellTags->"Tracing computations"],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " includes a ",
  StyleBox["Trace", "InlineInputTraditionalForm"],
  " function for tracing steps in a computation.  This can be used to verify  \
that intermediate factorial values are being saved and not recomputed. For  \
example, when computing ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(facDynamic[5]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " only ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(facDynamic[4]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " has to be computed as ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(facDynamic[3]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " has already been computed above.  "
}], "Text",
  CellTags->{"Trace", "Efficiency"}],

Cell[TextData[{
  "Tracing all computations of ",
  StyleBox["facDynamic", "InlineInputTraditionalForm"],
  " (selected using the pattern ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(facDynamic[_]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ") when evaluating ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(facDynamic[5]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " verifies that this is indeed the case:"
}], "Text",
  CellTags->"Pattern-matching"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Trace[facDynamic[5], facDynamic[_]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          TagBox[\(facDynamic(5)\),
            HoldForm], ",", 
          RowBox[{"(", GridBox[{
                {\(facDynamic(4)\), 
                  RowBox[{"(", GridBox[{
                        {\(facDynamic(3)\)}
                        }], ")"}]}
                }], ")"}]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "The ",
  StyleBox["Trace", "InlineInputTraditionalForm"],
  " command can take an arbitrary patterns (see ",
  ButtonBox["pattern-matching",
    ButtonData:>"pattern-matching",
    ButtonStyle->"Hyperlink"],
  ") to focus on particular aspects of a programming problem.  For example, \
here we only trace those computations of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(facDynamic[n]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " for which ",
  Cell[BoxData[
      \(TraditionalForm\`n > 24\)]],
  ":"
}], "Text",
  CellTags->"Pattern-matching"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Trace[facDynamic[30], 
      facDynamic[n_ /; n > 24]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          TagBox[\(facDynamic(30)\),
            HoldForm], ",", 
          RowBox[{"(", GridBox[{
                {\(facDynamic(29)\), 
                  RowBox[{"(", GridBox[{
                        {\(facDynamic(28)\), 
                          RowBox[{"(", GridBox[{
                                {\(facDynamic(27)\), 
                                  RowBox[{"(", GridBox[{
                                        {\(facDynamic(26)\), 
                                        RowBox[{"(", GridBox[{
                                        {\(facDynamic(25)\)}
                                        }], ")"}]}
                                        }], ")"}]}
                                }], ")"}]}
                        }], ")"}]}
                }], ")"}]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Remove your Fibonacci function (",
  StyleBox["fibDynamic", "InlineInputTraditionalForm"],
  ") and then re-enter the definitions.  Trace the computation of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(fibDynamic[20]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". Trace ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(fibDynamic[40]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " but this time only trace calls for ",
  Cell[BoxData[
      \(TraditionalForm\`n > 30\)]],
  "."
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Functional Programming"
}], "Section",
  CellTags->"Functional programming"],

Cell["\<\
Functional programming is very powerful and general.  Users who have not been \
exposed to procedural programming often accept and utilise functional \
programming as though it is second nature. Functional programming operators \
are powerful programming constructs; this is illustrated here through a \
number of examples.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Horner Form"
}], "Subsection"],

Cell[TextData[{
  "One can use the ",
  StyleBox["Horner representation",
    FontSlant->"Italic"],
  " to convert a list of digits in an arbitrary base into its corresponding  \
number:"
}], "Text",
  CellTags->"Horner representation"],

Cell[BoxData[
    FormBox[
      RowBox[{\(Horner[u_List, x_]\), ":=", 
        RowBox[{"Fold", "[", 
          RowBox[{
            StyleBox[\(Function[{a, b}, a\ x + b]\),
              "Input"], ",", "0", ",", "u"}], "]"}]}], 
      TraditionalForm]], "Input"],

Cell[TextData[{
  "You can use the shorthand ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(#1\ x + #2 &\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " instead of ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(Function[{a, b}, \ a\ x + b]\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ". These are completely equivalent. ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(#1\ x + #2 &\),
          "InlineInputTraditionalForm"], TraditionalForm]]],
  " means multiply the first (dummy) argument, ",
  Cell[BoxData[
      FormBox[
        StyleBox["#1",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ", by ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and then add the second argument, ",
  Cell[BoxData[
      FormBox[
        StyleBox["#2",
          "InlineInputTraditionalForm"], TraditionalForm]]],
  ".  The ampersand (",
  StyleBox["&", "InlineInputTraditionalForm"],
  ") delimits the end of this ",
  StyleBox["pure",
    FontSlant->"Italic"],
  " or ",
  StyleBox["anonymous",
    FontSlant->"Italic"],
  " function (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", one in which there are only ",
  StyleBox["dummy arguments",
    FontSlant->"Italic"],
  ")."
}], "Warning",
  CellTags->"Function"],

Cell[TextData[{
  "For example, ",
  StyleBox["13247", "InlineInputTraditionalForm"],
  " in base ",
  StyleBox["8", "InlineInputTraditionalForm"],
  " is"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Horner[{1, 3, 2, 4, 7}, 8]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`5799\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This can be checked using the built-in ",
  StyleBox["BaseForm", "InlineInputTraditionalForm"],
  " function,"
}], "Text",
  CellTags->"BaseForm"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`BaseForm[5799, \ 8]\)], "Input"],

Cell[BoxData[
    FormBox[
      TagBox[
        InterpretationBox[\("13247"\_"8"\),
          5799,
          Editable->False],
        (BaseForm[ #, 8]&)], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  "using the notation ",
  StyleBox["base", "TI"],
  StyleBox["^^", "MR"],
  StyleBox["digits", "TI"],
  " (in any base from 2 to 36),"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`8^^13247 == 5799\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "or by applying ",
  StyleBox["IntegerDigits", "InlineInputTraditionalForm"],
  " in base ",
  Cell[BoxData[
      \(TraditionalForm\`8\)]],
  "."
}], "Text",
  CellTags->"IntegerDigits"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`IntegerDigits[5799, 8]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 3, 2, 4, 7}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Importantly, ",
  StyleBox["Horner", "InlineInputTraditionalForm"],
  " works for both numbers and symbols \[LongDash] it provides an efficient  \
represent polynomials (by minimising the number of addition and  \
multiplication operations):"
}], "Text",
  CellTags->{"Efficiency", "Polynomials"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Horner[{a, b, c, d}, x]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`d + x\ \((c + x\ \((b + a\ x)\))\)\)], "Output"]
}, Open  ]],

Cell["\<\
Furthermore, one can verify this program by running it for symbolic \
arguments. For example,\
\>", "Text",
  CellTags->"Program verification"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Expand[Horner[{a, b, c, d}, x]]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`a\ x\^3 + b\ x\^2 + c\ x + d\)], "Output"]
}, Open  ]],

Cell["\<\
is obviously correct. In this way, coding errors can often be located.\
\>", "Text"],

Cell[TextData[{
  "As an aside, other applications of Horner representations include speeding \
up the computation of matrix powers and efficient computation of ",
  Cell[BoxData[
      \(TraditionalForm\`x\^n\)]],
  "."
}], "Text",
  CellTags->"Matrix power"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["Horner", "InlineInputTraditionalForm"],
  " to convert ",
  Cell[BoxData[
      \(TraditionalForm\`111111111111111111\)]],
  " in base 2 to base 10. Check your result."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Jacobian Determinant"
}], "Subsection"],

Cell[TextData[{
  "You've heard of inner products.  Here is an example of the use of the ",
  StyleBox["outer product",
    FontSlant->"Italic"],
  " (through ",
  Cell[BoxData[
      \(TraditionalForm\`Outer\)]],
  ") to provide a natural implementation of the ",
  StyleBox["Jacobian matrix",
    FontSlant->"Italic"],
  ", required when changing integration variables:"
}], "Text",
  CellTags->{"Jacobian matrix", "Outer"}],

Cell[BoxData[
    \(TraditionalForm
    \`JacobianMatrix[f_List, vars_List] := Outer[D, f, vars]\)], "Input"],

Cell[TextData[{
  "For example, when changing from cartesian coordinates, ",
  Cell[BoxData[
      \(TraditionalForm\`{x, y}\)]],
  ", to polar coordinates, ",
  Cell[BoxData[
      \(TraditionalForm\`{r, \[Theta]}\)]],
  ", the Jacobian matrix is:"
}], "Text",
  CellTags->{"Cartesian coordinates", "Polar coordinates", "Volume element"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`JacobianMatrix[{r\ Cos[\[Theta]], r\ Sin[\[Theta]]}, {r, \[Theta]}]\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\(cos(\[Theta])\), \(\(-r\)\ \(sin(\[Theta])\)\)},
            {\(sin(\[Theta])\), \(r\ \(cos(\[Theta])\)\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["This has determinant", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Det[%] // Simplify\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`r\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In functional programming, ",
  StyleBox["generalisation",
    FontSlant->"Italic"],
  " from a scalars to vectors (one dimension) and then to matrices (and even  \
to tensors) is often straightforward. For example, ",
  Cell[BoxData[
      \(TraditionalForm\`JacobianMatrix\)]],
  " automatically works for an ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  " number of variables. "
}], "Text",
  CellTags->{
  "Generalisation", "Functional programming", "Spherical polar coordinates"}],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  StyleBox["JacobianMatrix", "InlineInputTraditionalForm"],
  " to compute the Jacobian determinant relating spherical polar and \
cartesian coordinates."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Digital Roots"
}], "Subsection"],

Cell["\<\
In numerology, one adds together all the digits of a number and repeats this \
process until the result does not change:\
\>", "Text",
  CellTags->{"FixedPoint", "IntegerDigits"}],

Cell[BoxData[
    \(TraditionalForm
    \`DigitalRoot[n_] := FixedPoint[Plus@@IntegerDigits[#]&, n]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`DigitalRoot[1234567]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Map ",
  Cell[BoxData[
      \(TraditionalForm\`DigitalRoot\)]],
  " over the ",
  Cell[BoxData[
      \(TraditionalForm\`Range\)]],
  " of numbers between ",
  Cell[BoxData[
      \(TraditionalForm\`20000\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`20100\)]],
  " (You may need to look up ",
  Cell[BoxData[
      \(TraditionalForm\`Map\)]],
  " to see how to do this). Use ",
  Cell[BoxData[
      \(TraditionalForm\`ListPlot\)]],
  " to display the result.  "
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Compute a ",
  Cell[BoxData[
      \(TraditionalForm\`Table\)]],
  " of the first 100 ",
  Cell[BoxData[
      \(TraditionalForm\`Prime\)]],
  " numbers. Map ",
  Cell[BoxData[
      \(TraditionalForm\`DigitalRoot\)]],
  " over these numbers and then apply ",
  Cell[BoxData[
      \(TraditionalForm\`Union\)]],
  " to the result.  Explain the result."
}], "BeginEndQuestion"],

Cell["", "Answer"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Logistic Map"
}], "Subsection"],

Cell[TextData[{

  "The logistic map is an example of a ",

  StyleBox["dynamical system",

    FontSlant->"Italic"],

  ":"

}], "Text",

  CellTags->{"Logistic map", "Dynamical system"}],

Cell[BoxData[
    \(TraditionalForm\`Logistic\_\[Mu]_[x_] := \[Mu]\ x\ \((1 - x)\)\)], 
  "Input"],

Cell[TextData[{
  "Here we iterate ",
  Cell[BoxData[
      \(TraditionalForm\`Logistic\_3.5\)]],
  " forty times starting at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0.3\)]],
  ":"
}], "Text",
  CellTags->"NestList"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`NestList[Logistic\_3.5, 0.3, 40]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          StyleBox["0.3`",
            StyleBoxAutoDelete->True,
            PrintPrecision->1], ",", "0.734999999999999964`", ",", 
          "0.681712499999999899`", ",", "0.759431985703125089`", ",", 
          "0.639432656779467123`", ",", "0.806954869781967509`", ",", 
          "0.545225477709973738`", ",", "0.867841296580666288`", ",", 
          "0.401424731854489991`", ",", "0.840990207785142906`", ",", 
          "0.468039873681257834`", ",", "0.871424926139915001`", ",", 
          "0.392152334846855232`", ",", "0.834291083923553067`", ",", 
          "0.483873149232255972`", ",", "0.874089736395102434`", ",", 
          "0.385199041933449883`", ",", "0.828872590094507799`", ",", 
          "0.496449868195854548`", ",", "0.874955887974606127`", ",", 
          "0.382928287256110966`", ",", "0.827029749263243196`", ",", 
          "0.500680400838871086`", ",", "0.874998379691444583`", ",", 
          "0.382816753300768866`", ",", "0.826938303425594867`", ",", 
          "0.50088971013617769`", ",", "0.874997229455557423`", ",", 
          "0.382819772652295942`", ",", "0.826940780115591422`", ",", 
          "0.500884042040929955`", ",", "0.874997264643844552`", ",", 
          "0.382819680283720522`", ",", "0.826940704349166821`", ",", 
          "0.500884215438847224`", ",", "0.87499726357070191`", ",", 
          "0.382819683100699226`", ",", "0.826940706659828173`", ",", 
          "0.500884210150702813`", ",", "0.874997263603432884`", ",", 
          "0.382819683014781162`"}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(ListPlot[%, PlotJoined \[Rule] True]; \)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0232288 -0.292383 1.02366 [
[.2561 .00222 -6 -9 ]
[.2561 .00222 6 0 ]
[.48839 .00222 -6 -9 ]
[.48839 .00222 6 0 ]
[.72067 .00222 -6 -9 ]
[.72067 .00222 6 0 ]
[.95296 .00222 -6 -9 ]
[.95296 .00222 6 0 ]
[.01131 .11708 -18 -4.5 ]
[.01131 .11708 0 4.5 ]
[.01131 .21945 -18 -4.5 ]
[.01131 .21945 0 4.5 ]
[.01131 .32181 -18 -4.5 ]
[.01131 .32181 0 4.5 ]
[.01131 .42418 -18 -4.5 ]
[.01131 .42418 0 4.5 ]
[.01131 .52655 -18 -4.5 ]
[.01131 .52655 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2561 .01472 m
.2561 .02097 L
s
[(10)] .2561 .00222 0 1 Mshowa
.48839 .01472 m
.48839 .02097 L
s
[(20)] .48839 .00222 0 1 Mshowa
.72067 .01472 m
.72067 .02097 L
s
[(30)] .72067 .00222 0 1 Mshowa
.95296 .01472 m
.95296 .02097 L
s
[(40)] .95296 .00222 0 1 Mshowa
.125 Mabswid
.07027 .01472 m
.07027 .01847 L
s
.11672 .01472 m
.11672 .01847 L
s
.16318 .01472 m
.16318 .01847 L
s
.20964 .01472 m
.20964 .01847 L
s
.30256 .01472 m
.30256 .01847 L
s
.34901 .01472 m
.34901 .01847 L
s
.39547 .01472 m
.39547 .01847 L
s
.44193 .01472 m
.44193 .01847 L
s
.53484 .01472 m
.53484 .01847 L
s
.5813 .01472 m
.5813 .01847 L
s
.62776 .01472 m
.62776 .01847 L
s
.67422 .01472 m
.67422 .01847 L
s
.76713 .01472 m
.76713 .01847 L
s
.81359 .01472 m
.81359 .01847 L
s
.86005 .01472 m
.86005 .01847 L
s
.9065 .01472 m
.9065 .01847 L
s
.99942 .01472 m
.99942 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
.02381 .11708 m
.03006 .11708 L
s
[(0.4)] .01131 .11708 1 0 Mshowa
.02381 .21945 m
.03006 .21945 L
s
[(0.5)] .01131 .21945 1 0 Mshowa
.02381 .32181 m
.03006 .32181 L
s
[(0.6)] .01131 .32181 1 0 Mshowa
.02381 .42418 m
.03006 .42418 L
s
[(0.7)] .01131 .42418 1 0 Mshowa
.02381 .52655 m
.03006 .52655 L
s
[(0.8)] .01131 .52655 1 0 Mshowa
.125 Mabswid
.02381 .03519 m
.02756 .03519 L
s
.02381 .05566 m
.02756 .05566 L
s
.02381 .07613 m
.02756 .07613 L
s
.02381 .09661 m
.02756 .09661 L
s
.02381 .13755 m
.02756 .13755 L
s
.02381 .15803 m
.02756 .15803 L
s
.02381 .1785 m
.02756 .1785 L
s
.02381 .19897 m
.02756 .19897 L
s
.02381 .23992 m
.02756 .23992 L
s
.02381 .26039 m
.02756 .26039 L
s
.02381 .28087 m
.02756 .28087 L
s
.02381 .30134 m
.02756 .30134 L
s
.02381 .34229 m
.02756 .34229 L
s
.02381 .36276 m
.02756 .36276 L
s
.02381 .38323 m
.02756 .38323 L
s
.02381 .40371 m
.02756 .40371 L
s
.02381 .44465 m
.02756 .44465 L
s
.02381 .46513 m
.02756 .46513 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .50607 m
.02756 .50607 L
s
.02381 .54702 m
.02756 .54702 L
s
.02381 .56749 m
.02756 .56749 L
s
.02381 .58797 m
.02756 .58797 L
s
.02381 .60844 m
.02756 .60844 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.04704 .01472 m
.07027 .46001 L
.0935 .40546 L
.11672 .48502 L
.13995 .36218 L
.16318 .53367 L
.18641 .26574 L
.20964 .59599 L
.23287 .11854 L
.2561 .56851 L
.27933 .18673 L
.30256 .59966 L
.32578 .10905 L
.34901 .56165 L
.37224 .20294 L
.39547 .60239 L
.4187 .10193 L
.44193 .5561 L
.46516 .21581 L
.48839 .60328 L
.51161 .09961 L
.53484 .55422 L
.55807 .22014 L
.5813 .60332 L
.60453 .09949 L
.62776 .55412 L
.65099 .22036 L
.67422 .60332 L
.69744 .09949 L
.72067 .55412 L
.7439 .22035 L
.76713 .60332 L
.79036 .09949 L
.81359 .55412 L
.83682 .22035 L
.86005 .60332 L
.88328 .09949 L
.9065 .55412 L
.92973 .22035 L
.95296 .60332 L
.97619 .09949 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P0000/A000`40O003h00Oogoo8Goo003oOolQ
Ool004moo`<000Aoo`8003Ioo`@000=oo`8003Moo`<000Aoo`8003Moo`<000=oo`8000Yoo`00D7oo
00<007ooOol00Woo00@007ooOol003Ioo`03001oogoo009oo`04001oogoo000iOol01000Oomoo`00
0Woo00<007ooOol0=Goo00D007ooOomoo`00009oo`03001oogoo00Moo`00D7oo00<007ooOol00Woo
00@007ooOol003Moo`05001oogooOol00002Ool00`00Oomoo`0gOol01000Oomoo`000Woo00<007oo
Ool0<goo10000Woo00@007ooOol000Uoo`00D7oo00<007ooOol00Woo00@007ooOol003Qoo`04001o
ogoo0002Ool00`00Oomoo`0eOol20003Ool01000Oomoo`00=Goo00<007oo00000goo00@007ooOol0
00Uoo`00D7oo00<007ooOol00Woo00@007ooOol003Eoo`04001oogoo0002Ool01000Oomoo`00>Goo
00@007ooOol0009oo`03001oogoo03=oo`03001oo`0000=oo`04001oogoo0009Ool004moo`8000Eo
o`8003Moo`8000Aoo`8003Moo`<000Aoo`8003Moo`8000Aoo`8000Yoo`005Goo00<007ooOol0ogoo
2Goo000EOol00`00Oomoo`3oOol9Ool001Eoo`03001oogoo0?moo`Uoo`005Goo00<007ooOol0ogoo
2Goo000>Oooo000C000001Eoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001o
ogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`03001oogoo00Yoo`03001o
ogoo00Uoo`03001oogoo00Yoo`03001oogoo00Yoo`03001oogoo00Uoo`40005oo`005Goo00<007oo
Ool00goo00<007ooOol0=Woo00<007ooOol0?7oo00<007ooOol0?Goo00<007ooOol0?7oo00<007oo
Ool02goo000EOol00`00Oomoo`03Ool00`00Oomoo`3oOol3Ool001Eoo`03001oogoo00=oo`03001o
ogoo0?moo`=oo`005Goo00<007ooOol00goo00<007ooOol0ogoo0goo000EOol20004Ool00`00Oomo
o`3oOol3Ool001Eoo`03001oogoo00=oo`03001oogoo0?moo`=oo`005Goo00<007ooOol00goo00<0
07ooOol0ogoo0goo000EOol00`00Oomoo`03Ool00`00Oomoo`3oOol3Ool001Eoo`03001oogoo00Ao
o`03001oogoo0?moo`9oo`005Goo0P001Goo00<007ooOol0ogoo0Woo000EOol00`00Oomoo`04Ool0
0`00Oomoo`3oOol2Ool001Eoo`03001oogoo00Aoo`03001oogoo0?moo`9oo`005Goo00<007ooOol0
17oo00<007ooOol0ogoo0Woo000EOol00`00Oomoo`04Ool00`00Oomoo`3oOol2Ool001Eoo`03001o
ogoo00Aoo`03001oogoo0?moo`9oo`005Goo0P001Goo00<007ooOol0ogoo0Woo000EOol00`00Oomo
o`04Ool00`00Oomoo`3oOol2Ool001Eoo`03001oogoo00Aoo`03001oogoo0?moo`9oo`005Goo00<0
07ooOol017oo00<007ooOol0ogoo0Woo000EOol00`00Oomoo`04Ool00`00Oomoo`3oOol2Ool001Eo
o`8000Eoo`03001oogoo0?moo`9oo`005Goo00<007ooOol017oo00<007ooOol0Ngoo00<007ooOol0
5Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol0
1Goo000EOol00`00Oomoo`04Ool00`00Oomoo`1QOol00`00Oomoo`0GOol00`00Oomoo`0FOol00`00
Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`05Ool001Eo
o`03001oogoo00Aoo`03001oogoo065oo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo01Io
o`03001oogoo01Ioo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo00Eoo`000Woo0P0017oo
0P0017oo0`0017oo00<007ooOol017oo00<007ooOol0B7oo00<007ooOol05Woo00<007ooOol05goo
00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo
00<007ooOol01Goo00001Goo001oogoo00000goo0P001Goo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol0Agoo00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol05Woo
00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol01Goo00001Goo001oogoo
000027oo100017oo0`001Goo00<007ooOol0;Woo00<007ooOol05Woo00<007ooOol05Woo00<007oo
Ool05goo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05goo00<007oo
Ool05Woo00<007ooOol01Goo00001Goo001oogoo000027oo00<007oo00001Goo00<007ooOol01Goo
00<007ooOol0;Woo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo
00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol01Goo
00001Goo001oogoo000027oo00<007oo00001Goo00<007ooOol01Goo00<007ooOol0;Woo00<007oo
Ool05Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol05Woo00<007oo
Ool05Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol01Goo0002Ool2000:Ool20005Ool0
0`00Oomoo`05Ool00`00Oomoo`0^Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0GOol0
0`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0FOol0
0`00Oomoo`05Ool001Eoo`03001oogoo00Eoo`03001oogoo02ioo`03001oogoo01Ioo`03001oogoo
01Ioo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo
01Moo`03001oogoo01Ioo`03001oogoo00Eoo`005Goo00<007ooOol01Goo00<007ooOol0;Woo00<0
07ooOol05Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol05Woo0P00
5goo0P0067oo00<007ooOol05Woo00<007ooOol01Goo000EOol20006Ool00`00Oomoo`0^Ool00`00
Oomoo`0FOol00`00Oomoo`0FOol2000GOol00`00Ool0000GOol2000GOol2000GOol2000GOol00`00
Ool0000GOol00`00Oomoo`05Ool001Eoo`03001oogoo00Eoo`03001oogoo02ioo`03001oogoo01Io
o`03001oogoo01Ioo`8001Moo`03001oo`0001Ioo`03001oo`0001Ioo`03001oo`0001Ioo`03001o
o`0001Moo`03001oo`0001Ioo`03001oogoo00Ioo`005Goo00<007ooOol01Goo00<007ooOol0;Woo
00<007ooOol05Woo00<007ooOol05Goo00<007oo00005goo00<007oo00005Woo00<007oo00005Woo
00<007oo00005Woo00<007oo00005goo00<007oo00005Woo00<007ooOol01Woo000EOol00`00Oomo
o`05Ool00`00Oomoo`0^Ool00`00Oomoo`0FOol2000FOol00`00Ool0000GOol00`00Ool0000FOol0
0`00Ool0000FOol00`00Ool0000FOol00`00Ool0000GOol00`00Ool0000FOol00`00Oomoo`06Ool0
01Eoo`03001oogoo00Eoo`03001oogoo02eoo`8001Moo`03001oo`0001Ioo`03001oo`0001Moo`03
001oo`0001Ioo`03001oo`0001Ioo`03001oo`0001Ioo`03001oo`0001Moo`03001oo`0001Ioo`03
001oogoo00Ioo`005Goo0P001Woo00<007ooOol0;Goo00<007oo00005Woo00<007oo00005Woo00<0
07oo00005goo00<007oo00005Woo00<007oo00005Woo00<007oo00005Woo00<007oo00005goo00<0
07oo00005Woo00<007ooOol01Woo000EOol00`00Oomoo`05Ool00`00Oomoo`0]Ool00`00Ool0000F
Ool00`00Ool0000FOol00`00Ool0000GOol00`00Ool0000FOol00`00Ool0000FOol00`00Ool0000F
Ool00`00Ool0000GOol00`00Ool0000FOol00`00Oomoo`06Ool001Eoo`03001oogoo00Eoo`03001o
ogoo02eoo`03001oo`0001Ioo`03001oo`0001Ioo`03001oo`0001Moo`03001oo`0001Ioo`03001o
o`0001Ioo`03001oo`0001Ioo`03001oo`0001Moo`03001oo`0001Ioo`03001oogoo00Ioo`005Goo
00<007ooOol01Goo00<007ooOol0;Goo00<007oo00005Woo00<007oo00005Woo00<007oo00005goo
00<007oo00005Woo00<007oo00005Woo00<007oo00005Woo00<007oo00005goo00<007oo00005Woo
00<007ooOol01Woo000EOol00`00Oomoo`05Ool00`00Oomoo`0]Ool00`00Ool0000FOol00`00Ool0
000FOol00`00Ool0000GOol00`00Ool0000FOol00`00Ool0000FOol00`00Ool0000FOol00`00Ool0
000GOol00`00Ool0000FOol00`00Oomoo`06Ool001Eoo`03001oogoo00Ioo`03001oogoo02aoo`03
001oo`0001Ioo`03001oo`0001Ioo`03001oo`0001Moo`03001oo`0001Ioo`03001oo`0001Ioo`03
001oo`0001Ioo`03001oo`0001Moo`03001oo`0001Ioo`03001oogoo00Ioo`005Goo0P001goo00<0
07ooOol0;7oo00<007oo00005Woo00<007oo00005Woo00<007oo00005goo00<007oo00005Woo00<0
07oo00005Woo00<007oo00005Woo00<007oo00005goo00<007oo00005Woo00<007ooOol01Woo000E
Ool00`00Oomoo`06Ool00`00Oomoo`0/Ool00`00Ool0000FOol00`00Ool0000FOol00`00Ool0000G
Ool00`00Ool0000FOol00`00Ool0000FOol00`00Ool0000FOol00`00Ool0000GOol00`00Ool0000F
Ool00`00Oomoo`06Ool001Eoo`03001oogoo00Ioo`03001oogoo02aoo`03001oo`0000Yoo`03001o
ogoo00Uoo`03001oo`0001Ioo`03001oo`0001Moo`03001oo`0001Ioo`03001oo`0001Ioo`03001o
o`0001Ioo`03001oo`0001Moo`03001oo`0001Ioo`03001oogoo00Ioo`005Goo00<007ooOol01Woo
00<007ooOol0;7oo00<007oo00002Woo00<007ooOol02Goo00<007oo00005Woo00<007oo00005goo
00<007oo00005Woo00<007oo00005Woo00<007oo00005Woo00<007oo00005goo00<007oo00005Woo
00<007ooOol01Woo000EOol00`00Oomoo`06Ool00`00Oomoo`0/Ool00`00Ool0000:Ool00`00Oomo
o`09Ool00`00Ool0000FOol00`00Ool0000GOol00`00Ool0000FOol00`00Ool0000FOol00`00Ool0
000FOol00`00Ool0000GOol00`00Ool0000FOol00`00Oomoo`06Ool001Eoo`8000Moo`03001oogoo
02aoo`03001oo`0000Yoo`03001oogoo00Uoo`03001oo`0001Ioo`03001oo`0001Moo`03001oo`00
01Ioo`03001oo`0001Ioo`03001oo`0001Ioo`03001oo`0001Moo`03001oo`0001Ioo`03001oogoo
00Ioo`005Goo00<007ooOol01Woo00<007ooOol0;7oo00<007oo00002Woo00<007ooOol02Goo00<0
07oo00002goo00<007ooOol027oo00@007ooOol001Ioo`03001oo`0001Ioo`03001oo`0001Ioo`04
001oogoo000EOol01000Oomoo`005Woo00<007oo00005Woo00<007ooOol01Woo000EOol00`00Oomo
o`06Ool00`00Oomoo`0/Ool00`00Ool0000:Ool00`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomo
o`08Ool01000Oomoo`005Woo00<007oo00005Woo00<007oo00005Woo00@007ooOol001Eoo`04001o
ogoo000FOol00`00Ool0000FOol00`00Oomoo`06Ool001Eoo`03001oogoo00Ioo`03001oogoo02ao
o`03001oo`0000Yoo`03001oogoo00Uoo`03001oo`0000]oo`03001oogoo00Qoo`04001oogoo000E
Ool01000Oomoo`005Woo00<007oo00005Woo00@007ooOol001Eoo`04001oogoo000EOol01000Oomo
o`005Woo00<007ooOol01Woo0002Ool20004Ool20003Ool30005Ool00`00Oomoo`06Ool00`00Oomo
o`0/Ool00`00Ool0000:Ool00`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomoo`08Ool01000Oomo
o`005Goo00@007ooOol001Ioo`03001oo`0001Ioo`04001oogoo000EOol01000Oomoo`005Goo00@0
07ooOol001Ioo`03001oogoo00Ioo`0000Eoo`00Oomoo`0000=oo`8000Ioo`03001oogoo009oo`03
001oogoo00Ioo`03001oogoo02aoo`03001oo`0000Yoo`03001oogoo00Uoo`03001oo`0000]oo`03
001oogoo00Qoo`04001oogoo000:Ool00`00Oomoo`08Ool01@00Oomoogoo00005Goo00@007ooOol0
01Eoo`04001oogoo000EOol01000Oomoo`005Goo00D007ooOomoo`0001Eoo`03001oogoo00Ioo`00
00Eoo`00Oomoo`0000]oo`03001oogoo009oo`<000Ioo`03001oogoo02aoo`03001oo`0000Yoo`80
00Yoo`03001oo`0000]oo`03001oogoo00Qoo`04001oogoo000:Ool00`00Oomoo`08Ool01@00Oomo
ogoo00002Goo00<007ooOol02Goo00@007ooOol000Yoo`03001oogoo00Qoo`04001oogoo000:Ool0
0`00Oomoo`08Ool01000Oomoo`002Woo00<007ooOol027oo00D007ooOomoo`0000Uoo`03001oogoo
00Uoo`03001oogoo00Ioo`0000Eoo`00Oomoo`0000Qoo`<000Eoo`03001oogoo00Ioo`03001oogoo
02]oo`04001oogoo0009Ool00`00Ool0000:Ool00`00Ool0000;Ool00`00Oomoo`08Ool01000Oomo
o`002Woo00<007ooOol027oo00D007ooOomoo`0000Uoo`03001oogoo00Uoo`04001oogoo000:Ool0
0`00Oomoo`08Ool01000Oomoo`002Woo00<007ooOol027oo00@007ooOol000Yoo`03001oogoo00Qo
o`05001oogooOol00009Ool00`00Oomoo`09Ool00`00Oomoo`06Ool00005Ool007ooOol00008Ool0
0`00Oomoo`05Ool00`00Oomoo`06Ool00`00Oomoo`0[Ool01000Oomoo`002Goo00<007oo00002Woo
00@007ooOol000Yoo`03001oogoo00Qoo`04001oogoo000:Ool00`00Oomoo`08Ool01@00Oomoogoo
00002Goo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo00Moo`05001oogooOol0000:
Ool00`00Oomoo`07Ool01@00Oomoogoo00002Woo00<007ooOol027oo00D007ooOomoo`0000Uoo`03
001oogoo00Qoo`03001oogoo00Moo`000Woo0P002Goo100017oo00<007ooOol01Woo00<007ooOol0
:goo00@007ooOol000Uoo`03001oo`0000Yoo`04001oogoo0009Ool20009Ool01@00Oomoogoo0000
2Woo00<007ooOol027oo00D007ooOomoo`0000Uoo`03001oogoo00Qoo`05001oogooOol0000:Ool0
0`00Oomoo`07Ool01@00Oomoogoo00002Woo00<007ooOol01goo00D007ooOomoo`0000Yoo`03001o
ogoo00Qoo`05001oogooOol00009Ool00`00Oomoo`08Ool00`00Oomoo`07Ool001Eoo`03001oogoo
00Ioo`03001oogoo02]oo`05001oogooOol00008Ool00`00Ool00009Ool01@00Oomoogoo00002Goo
0P002Goo00D007ooOomoo`0000Yoo`03001oogoo00Qoo`05001oogooOol00009Ool00`00Oomoo`08
Ool01@00Oomoogoo00002Woo00<007ooOol01goo00D007ooOomoo`0000Yoo`03001oogoo00Moo`05
001oogooOol0000:Ool00`00Oomoo`08Ool01@00Oomoogoo00002Goo00<007ooOol027oo00<007oo
Ool01goo000EOol20008Ool00`00Oomoo`0ZOol01@00Oomoogoo000027oo00<007oo00002Goo00D0
07ooOomoo`0000Uoo`03001oo`0000Qoo`05001oogooOol0000:Ool00`00Oomoo`08Ool01@00Oomo
ogoo00002Goo00<007ooOol027oo00D007ooOomoo`0000Yoo`03001oogoo00Moo`05001oogooOol0
000:Ool00`00Oomoo`07Ool01@00Oomoogoo00002Woo00<007ooOol027oo00D007ooOomoo`0000Uo
o`03001oogoo00Qoo`03001oogoo00Moo`005Goo00<007ooOol01goo00<007ooOol0:Woo00D007oo
Oomoo`0000Qoo`03001oo`0000Uoo`05001oogooOol00009Ool00`00Ool00008Ool01@00Oomoogoo
00002Woo00<007ooOol027oo00D007ooOomoo`0000Uoo`03001oogoo00Qoo`05001oogooOol0000:
Ool00`00Oomoo`07Ool01@00Oomoogoo00002Woo00<007ooOol01goo00D007ooOomoo`0000Yoo`03
001oogoo00Qoo`05001oogooOol00009Ool00`00Oomoo`08Ool00`00Oomoo`07Ool001Eoo`03001o
ogoo00Moo`03001oogoo02Yoo`05001oogooOol00008Ool00`00Ool00009Ool01@00Oomoogoo0000
2Goo00<007oo000027oo00D007ooOomoo`0000Yoo`03001oogoo00Qoo`05001oogooOol00009Ool0
0`00Oomoo`08Ool01@00Oomoogoo00002Goo0P002Goo00D007ooOomoo`0000Yoo`03001oogoo00Mo
o`05001oogooOol0000:Ool00`00Oomoo`08Ool01@00Oomoogoo00002Goo00<007ooOol027oo00<0
07ooOol01goo000EOol00`00Oomoo`07Ool00`00Oomoo`0ZOol01@00Oomoogoo000027oo00<007oo
00002Goo00D007ooOomoo`0000Uoo`03001oo`0000Qoo`05001oogooOol00009Ool2000:Ool01@00
Oomoogoo00002Goo0P002Goo00D007ooOomoo`0000Uoo`8000Uoo`05001oogooOol0000:Ool00`00
Oomoo`07Ool01@00Oomoogoo00002Woo00<007ooOol027oo00D007ooOomoo`0000Uoo`8000Uoo`03
001oogoo00Moo`005Goo00<007ooOol01goo00<007ooOol0:Woo00D007ooOomoo`0000Qoo`03001o
o`0000Uoo`05001oogooOol00009Ool00`00Ool00008Ool01@00Oomoogoo00002Goo00<007oo0000
2Goo00D007ooOomoo`0000Qoo`03001oo`0000Uoo`05001oogooOol00009Ool20009Ool01@00Oomo
ogoo00002Goo0P002Goo00D007ooOomoo`0000Uoo`8000Yoo`05001oogooOol00008Ool00`00Ool0
0009Ool00`00Oomoo`07Ool001Eoo`03001oogoo00Moo`03001oogoo02Yoo`05001oogooOol00008
Ool00`00Ool00009Ool01@00Oomoogoo00002Goo00<007oo000027oo00D007ooOomoo`0000Uoo`03
001oo`0000Uoo`05001oogooOol00008Ool00`00Ool00009Ool01@00Oomoogoo00002Goo00<007oo
000027oo00D007ooOomoo`0000Uoo`03001oo`0000Qoo`05001oogooOol00009Ool00`00Ool00009
Ool01@00Oomoogoo000027oo00<007oo00002Goo00<007ooOol01goo000EOol20008Ool00`00Oomo
o`0ZOol01@00Oomoogoo000027oo00<007oo00002Goo00D007ooOomoo`0000Uoo`03001oo`0000Qo
o`05001oogooOol00009Ool00`00Ool00009Ool01@00Oomoogoo000027oo00<007oo00002Goo00D0
07ooOomoo`0000Uoo`03001oo`0000Qoo`05001oogooOol00009Ool00`00Ool00008Ool01@00Oomo
ogoo00002Goo00<007oo00002Goo00D007ooOomoo`0000Qoo`03001oo`0000Uoo`03001oogoo00Mo
o`005Goo00<007ooOol01goo00<007ooOol07goo00<007ooOol027oo00D007ooOomoo`0000Qoo`03
001oo`0000Uoo`05001oogooOol00009Ool00`00Ool00008Ool01@00Oomoogoo00002Goo00<007oo
00002Goo00D007ooOomoo`0000Qoo`03001oo`0000Uoo`05001oogooOol00009Ool00`00Ool00008
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Ool00009Ool01@00Oomoogoo000027oo00<007oo00002Goo00<007ooOol01goo000EOol0
0`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`08Ool01@00Oomoogoo000027oo00<007oo0000
2Goo00D007ooOomoo`0000Uoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00Ioo`03001o
o`0000Uoo`05001oogooOol00008Ool00`00Ool00009Ool01@00Oomoogoo00002Goo00<007oo0000
27oo00<007ooOol00Woo00<007ooOol01Woo00<007oo000027oo00<007ooOol00Woo00<007ooOol0
1Woo00<007oo00002Goo00D007ooOomoo`0000Qoo`03001oo`0000Uoo`03001oogoo00Moo`005Goo
00<007ooOol01goo00<007ooOol07goo00<007ooOol027oo00D007ooOomoo`0000Qoo`03001oo`00
00Uoo`05001oogooOol00009Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Ool00009Ool01@00Oomoogoo000027oo00<007oo00002Goo00D007ooOomoo`0000Uoo`03001oo`00
00Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo
00Ioo`03001oo`0000Uoo`05001oogooOol00008Ool00`00Ool00009Ool00`00Oomoo`07Ool001Eo
o`03001oogoo00Moo`03001oogoo01moo`03001oogoo00Qoo`05001oogooOol00008Ool00`00Ool0
0009Ool01@00Oomoogoo00002Goo00<007oo000027oo00<007ooOol00Woo00<007ooOol01Woo00<0
07oo00002Goo00D007ooOomoo`0000Qoo`03001oo`0000Uoo`05001oogooOol00009Ool00`00Ool0
0008Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool00`00Ool00009Ool01@00Oomoogoo000027oo00<007oo00002Goo00<007ooOol01goo000E
Ool00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`08Ool01@00Oomoogoo000027oo00@007oo
Ool000Qoo`05001oogooOol00009Ool00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Ool00009Ool01@00Oomoogoo000027oo00<007oo00002Goo00D007ooOomoo`0000Uoo`03001o
o`0000Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo009oo`03001o
ogoo00Ioo`03001oo`0000Uoo`05001oogooOol00008Ool00`00Ool00009Ool00`00Oomoo`07Ool0
01Eoo`8000Qoo`03001oogoo01moo`03001oogoo00Qoo`05001oogooOol00008Ool01000Oomoo`00
27oo00D007ooOomoo`0000Qoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00
Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00009Ool01@00Oomoogoo00002Goo
00<007oo000027oo00<007ooOol00Woo00<007ooOol01Woo00<007oo000027oo00<007ooOol00Woo
00<007ooOol01Woo00<007oo000027oo00<007ooOol00Woo00<007ooOol01Woo00<007oo00002Goo
00<007ooOol01goo000EOol00`00Oomoo`07Ool00`00Oomoo`0OOol00`00Oomoo`08Ool01@00Oomo
ogoo00001goo00D007ooOomoo`0000Qoo`05001oogooOol00008Ool01000Oomoo`0027oo00<007oo
Ool00Woo00<007ooOol01Woo00<007oo000027oo00<007ooOol00Woo00<007ooOol01Woo00<007oo
00002Goo00D007ooOomoo`0000Uoo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00Ioo`03
001oo`0000Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo009oo`03
001oogoo00Ioo`03001oo`0000Uoo`03001oogoo00Moo`005Goo00<007ooOol01goo00<007ooOol0
7Woo0P002Goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Qoo`05001oogooOol0
0008Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol01Woo00<007oo000027oo00<007oo
Ool00Woo00<007ooOol01Woo00<007oo00002Goo00D007ooOomoo`0000Uoo`03001oo`0000Qoo`03
001oogoo009oo`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00Ioo`03
001oo`0000Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000Uoo`03001oogoo00Moo`00
5Goo00<007ooOol01goo00<007ooOol07Woo00<007oo000027oo00<007ooOol00Woo00<007ooOol0
1Goo00D007ooOomoo`0000Qoo`05001oogooOol00008Ool01000Oomoo`0027oo00<007ooOol00Woo
00<007ooOol01Woo00<007oo000027oo00<007ooOol00goo00<007ooOol01Goo00<007oo00002Goo
00<007ooOol00Woo00<007ooOol01Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Io
o`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo00=o
o`03001oogoo00Eoo`03001oo`0000Uoo`03001oogoo00Moo`005Goo00<007ooOol01goo00<007oo
Ool07Woo00<007oo000027oo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Qoo`05
001oogooOol00008Ool01000Oomoo`0027oo00<007ooOol00Woo00<007ooOol01Woo00<007oo0000
27oo00<007ooOol00goo00<007ooOol01Goo00<007oo00002Goo00<007ooOol00Woo00<007ooOol0
1Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo
009oo`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo00Eoo`03001oo`00
00Uoo`03001oogoo00Moo`005Goo0P0027oo00<007ooOol07Woo00<007oo000027oo00<007ooOol0
0Woo00<007ooOol01Goo00D007ooOomoo`0000Qoo`03001oogoo009oo`03001oogoo00Eoo`04001o
ogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Ool00008Ool00`00Oomoo`03Ool00`00
Oomoo`05Ool00`00Ool00009Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01000Oomoo`0027oo00<0
07ooOol00Woo00<007ooOol01Woo00<007oo000027oo00<007ooOol00Woo00<007ooOol01Woo00<0
07oo000027oo00<007ooOol00goo00<007ooOol01Goo00<007oo00002Goo00<007ooOol01goo000E
Ool00`00Oomoo`08Ool00`00Oomoo`0MOol00`00Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool01@00Oomoogoo000027oo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Moo`03
001oogoo009oo`03001oogoo00Eoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`05Ool0
1000Oomoo`0027oo00<007ooOol00Woo00<007ooOol01Goo00@007ooOol000Qoo`03001oogoo009o
o`03001oogoo00Ioo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00Ioo`03001oo`0000Qo
o`03001oogoo00=oo`03001oogoo00Eoo`04001oogoo0008Ool00`00Oomoo`07Ool001Eoo`03001o
ogoo00Qoo`03001oogoo01eoo`03001oo`0000Qoo`03001oogoo00=oo`03001oogoo00Aoo`05001o
ogooOol00008Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo00<007ooOol0
0Woo00<007ooOol01Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo00Aoo`05001oogoo
Ool00008Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01000Oomoo`0027oo00<007ooOol00Woo00<0
07ooOol01Goo00@007ooOol000Qoo`03001oogoo009oo`03001oogoo00Eoo`04001oogoo0008Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool01@00Oomoogoo000027oo00<007ooOol01goo000EOol00`00
Oomoo`08Ool00`00Oomoo`0MOol00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01@00
Oomoogoo000027oo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Moo`03001oogoo
009oo`03001oogoo00Eoo`04001oogoo0008Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01@00Oomo
ogoo00001goo00<007ooOol00goo00<007ooOol01Goo00@007ooOol000Moo`03001oogoo00=oo`03
001oogoo00Eoo`04001oogoo0007Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`0027oo
00<007ooOol00goo00<007ooOol017oo00D007ooOomoo`0000Moo`03001oogoo00Qoo`000Woo0P00
17oo0P0017oo0P001Goo00<007ooOol027oo00<007ooOol07Goo00<007oo000027oo00<007ooOol0
0goo00<007ooOol017oo00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo00Eoo`05001o
ogooOol00006Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo00<007ooOol0
0goo00<007ooOol017oo00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo00Eoo`04001o
ogoo0007Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01000Oomoo`001goo00<007ooOol00goo00<0
07ooOol01Goo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo00Aoo`05001oogooOol00007
Ool00`00Oomoo`08Ool00005Ool007ooOol00003Ool20003Ool01000Oomoo`0017oo00<007ooOol0
27oo00<007ooOol07Goo00<007oo000027oo00<007ooOol00goo00<007ooOol017oo00D007ooOomo
o`0000Moo`03001oogoo00=oo`03001oogoo00Eoo`05001oogooOol00006Ool00`00Oomoo`03Ool0
0`00Oomoo`05Ool01@00Oomoogoo00001goo00<007ooOol00goo00<007ooOol017oo00D007ooOomo
o`0000Moo`03001oogoo00=oo`03001oogoo00Eoo`05001oogooOol00006Ool00`00Oomoo`03Ool0
0`00Oomoo`05Ool01@00Oomoogoo00001Woo00<007ooOol00goo00<007ooOol01Goo00D007ooOomo
o`0000Moo`03001oogoo00=oo`03001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`08Ool0
0005Ool007ooOol00008Ool01000Oomoo`0017oo0`0027oo00<007ooOol07Goo00<007oo000027oo
00<007ooOol00goo00<007ooOol017oo00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo
00Eoo`05001oogooOol00006Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo
00<007ooOol00goo00<007ooOol017oo00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo
00Eoo`05001oogooOol00006Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01@00Oomoogoo00001Woo
00<007ooOol00goo00<007ooOol01Goo00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo
00Aoo`05001oogooOol00007Ool00`00Oomoo`08Ool00005Ool007ooOol00008Ool30005Ool00`00
Oomoo`08Ool00`00Oomoo`0MOol00`00Ool00008Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01@00
Oomoogoo00001goo00<007ooOol00goo00<007ooOol01Goo00D007ooOomoo`0000Ioo`03001oogoo
00=oo`03001oogoo00Eoo`05001oogooOol00007Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01@00
Oomoogoo00001goo00<007ooOol00goo00<007ooOol01Goo00D007ooOomoo`0000Ioo`03001oogoo
00=oo`03001oogoo00Eoo`05001oogooOol00006Ool00`00Oomoo`03Ool00`00Oomoo`05Ool01@00
Oomoogoo00001goo00<007ooOol00goo00<007ooOol017oo00D007ooOomoo`0000Moo`03001oogoo
00Qoo`0000Eoo`00Oomoo`0000Qoo`03001oogoo00Eoo`03001oogoo00Qoo`03001oogoo01eoo`03
001oo`0000Qoo`03001oogoo00=oo`03001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`03
Ool00`00Oomoo`05Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol017oo00D007oo
Oomoo`0000Moo`03001oogoo00=oo`03001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`03
Ool00`00Oomoo`05Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol017oo00D007oo
Oomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`03
Ool00`00Oomoo`04Ool01@00Oomoogoo00001goo00<007ooOol027oo0002Ool2000:Ool30004Ool0
0`00Oomoo`08Ool00`00Oomoo`0LOol01000Oomoo`0027oo00<007ooOol00goo00<007ooOol017oo
00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`03Ool00`00
Oomoo`04Ool01@00Oomoogoo00001goo00<007ooOol00goo00<007ooOol01Goo00D007ooOomoo`00
00Ioo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool01@00Oomoogoo00001goo00<007ooOol00goo00<007ooOol017oo00D007ooOomoo`00
00Moo`03001oogoo00Qoo`005Goo00<007ooOol027oo00<007ooOol077oo00@007ooOol000Qoo`03
001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`05
001oogooOol00007Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01@00Oomoogoo00001goo00<007oo
Ool00goo00<007ooOol01Goo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00Aoo`05
001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo00001goo00<007oo
Ool00goo00<007ooOol017oo00D007ooOomoo`0000Moo`03001oogoo00Qoo`005Goo0P002Goo00<0
07ooOol077oo00@007ooOol000Qoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool01@00Oomoogoo00001goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol017oo00<007ooOol017oo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03
001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`03Ool00`00Oomoo`04Ool01@00Oomoogoo
00001goo00<007ooOol027oo000EOol00`00Oomoo`08Ool00`00Oomoo`0LOol01000Oomoo`0027oo
00<007ooOol00goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00goo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol017oo
00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo00Aoo`05001oogooOol00007Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol017oo00D007ooOomoo`00
00Moo`03001oogoo00=oo`03001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`08Ool001Eo
o`03001oogoo00Qoo`03001oogoo01aoo`05001oogooOol00007Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo00001goo00<0
07ooOol00goo00<007ooOol017oo00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol0
0006Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo00001goo00<007ooOol00goo00<0
07ooOol017oo00D007ooOomoo`0000Moo`03001oogoo00Qoo`005Goo00<007ooOol027oo00<007oo
Ool077oo00D007ooOomoo`0000Moo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03
001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03
001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool01@00Oomoogoo00001goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol017oo00<007ooOol017oo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03
001oogoo00Aoo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00Oomoo`04Ool01@00Oomoogoo
00001goo00<007ooOol027oo000EOol00`00Oomoo`08Ool00`00Oomoo`0LOol01@00Oomoogoo0000
1goo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol017oo00<007ooOol0
17oo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00007Ool0
0`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool0
0`00Oomoo`04Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol017oo00D007ooOomo
o`0000Ioo`03001oogoo00Aoo`03001oogoo00Aoo`05001oogooOol00007Ool00`00Oomoo`08Ool0
01Eoo`03001oogoo00Qoo`03001oogoo01aoo`05001oogooOol00006Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00
Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00
Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00
Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00
Oomoo`04Ool01@00Oomoogoo00001Woo00<007ooOol017oo00<007ooOol017oo00D007ooOomoo`00
00Ioo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
00Qoo`005Goo0P002Goo00<007ooOol04Woo00<007ooOol01goo00D007ooOomoo`0000Ioo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001o
ogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00Aoo`03001oogoo00Qoo`005Goo00<007ooOol02Goo00<007ooOol04Goo
00<007ooOol01goo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo
00Qoo`005Goo00<007ooOol02Goo00<007ooOol04Goo00<007ooOol01goo00D007ooOomoo`0000Io
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=o
o`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=o
o`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Ao
o`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo009o
o`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Qoo`005Goo00<007ooOol02Goo00<007oo
Ool047oo0P002Goo00D007ooOomoo`0000Ioo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
00Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo
00=oo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
009oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo
00Qoo`005Goo00<007ooOol02Goo00<007ooOol047oo0P0027oo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
17oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol0
0goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol0
17oo00<007ooOol017oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol0
17oo00<007ooOol00goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol027oo000EOol2000:Ool00`00Oomoo`0@
Ool00`00Ool00007Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`04
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`04
Ool00`00Oomoo`08Ool001Eoo`03001oogoo00Uoo`03001oogoo011oo`03001oo`0000Moo`03001o
ogoo009oo`03001oogoo00Aoo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00Eoo`03001o
ogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00=oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00Eoo`03001oogoo009oo`03001oogoo00=oo`03001oogoo00Aoo`03001oogoo00Qoo`005Goo
00<007ooOol02Goo00<007ooOol047oo00<007oo00001goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol017oo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo
00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00goo
00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo
00<007ooOol00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo
00<007ooOol00goo00<007ooOol017oo00<007ooOol027oo000EOol00`00Oomoo`09Ool00`00Oomo
o`0?Ool01000Oomoo`001goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol017oo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00goo00<007ooOol017oo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol027oo000EOol00`00Oomoo`09Ool00`00Oomoo`0?Ool01000Oomoo`001goo
00<007ooOol00Woo00<007ooOol017oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo
00<007ooOol00goo00<007ooOol017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol01Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo
00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo
00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol00goo
00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo
00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol02Goo
000EOol00`00Oomoo`09Ool00`00Oomoo`0?Ool01000Oomoo`001goo00<007ooOol00Woo00<007oo
Ool017oo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007oo
Ool00Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol02Goo000EOol2000:Ool00`00Oomo
o`04Ool00`00Oomoo`08Ool01000Oomoo`001goo00<007ooOol00goo00<007ooOol00goo00<007oo
Ool01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Goo00<007oo
Ool00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007oo
Ool00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007oo
Ool01Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Woo00<007oo
Ool00Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007oo
Ool00goo00<007ooOol00goo00<007ooOol02Goo000EOol00`00Oomoo`09Ool00`00Oomoo`04Ool0
0`00Oomoo`08Ool01@00Oomoogoo00001Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol0
0Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol00goo00<007ooOol0
0goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol0
1Woo00<007ooOol00Woo00<007ooOol00goo00<007ooOol00Woo00<007ooOol01Woo00<007ooOol0
0Woo00<007ooOol00goo00<007ooOol00goo00<007ooOol01Goo00<007ooOol00Woo00<007ooOol0
0goo00<007ooOol00goo00<007ooOol02Goo000EOol00`00Oomoo`09Ool00`00Oomoo`03Ool20009
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05
Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`03
Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool00`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02
Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`03
Ool00`00Oomoo`03Ool00`00Oomoo`09Ool001Eoo`03001oogoo00Uoo`03001oogoo00=oo`03001o
o`0000Qoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo00=oo`03001o
ogoo00Eoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool0
0`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02Ool00`00Oomoo`03Ool0
0`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
0`00Oomoo`02Ool00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`02Ool0
0`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`09Ool0009oo`8000Aoo`8000Aoo`03001oogoo00Aoo`03001oogoo
00Uoo`03001oogoo00=oo`03001oo`0000Qoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
00=oo`03001oogoo00=oo`03001oogoo00Eoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00
Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00
Oomoogoo00001Woo00<007ooOol00goo00<007ooOol01Goo00D007ooOomoo`0000Moo`03001oogoo
009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo
00Ioo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomoogoo00001Woo
00<007ooOol00goo00<007ooOol01Goo00D007ooOomoo`0000Moo`03001oogoo009oo`03001oogoo
00Uoo`0000Eoo`00Oomoo`0000=oo`8000Aoo`03001oogoo00Aoo`03001oogoo00Uoo`03001oogoo
009oo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomo
o`03Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol01Goo00<0
07ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomoo`0000Io
o`03001oogoo00=oo`03001oogoo00Eoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomo
o`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomo
ogoo00001Woo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomoo`0000Ioo`03001oogoo00=o
o`03001oogoo00Eoo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`09Ool00005Ool0
07ooOol0000:Ool00`00Oomoo`03Ool30009Ool00`00Oomoo`02Ool01@00Oomoogoo00001Woo00<0
07ooOol00goo00<007ooOol00goo00<007ooOol017oo00<007ooOol00goo00<007ooOol01Goo00D0
07ooOomoo`0000Moo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Ao
o`03001oogoo009oo`03001oogoo00Ioo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomo
o`06Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol00Woo00<0
07ooOol017oo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomoo`0000Ioo`03001oogoo009o
o`03001oogoo00Ioo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomo
ogoo00001goo00<007ooOol00Woo00<007ooOol02Goo00001Goo001oogoo00002Woo00<007ooOol0
0goo00<007ooOol02Woo00@007ooOol000Aoo`03001oogoo00Aoo`03001oogoo00=oo`03001oogoo
00=oo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Ioo`05001oogooOol00007Ool00`00
Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00
Oomoo`06Ool01@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomoo`00
00Moo`03001oogoo009oo`03001oogoo00Eoo`03001oogoo009oo`03001oogoo00Aoo`03001oogoo
009oo`03001oogoo00Ioo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00
Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomoo`0000Moo`03001oogoo
009oo`03001oogoo00Uoo`0000Eoo`00Oomoo`0000]oo`03001oogoo009oo`03001oogoo00Yoo`04
001oogoo0004Ool00`00Oomoo`04Ool00`00Oomoo`03Ool00`00Oomoo`03Ool00`00Oomoo`04Ool0
0`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol0
1Goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomo
o`0000Ioo`03001oogoo009oo`03001oogoo00Ioo`05001oogooOol00007Ool00`00Oomoo`02Ool0
0`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool0
1@00Oomoogoo00001Woo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomoo`0000Ioo`03001o
ogoo009oo`03001oogoo00Ioo`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`09Ool0
009oo`8000Uoo`@000Aoo`03001oogoo00Yoo`04001oogoo0004Ool00`00Oomoo`04Ool00`00Oomo
o`04Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomo
ogoo00001goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Moo`03001oogoo009o
o`03001oogoo00Ioo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomo
ogoo00001goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Moo`03001oogoo009o
o`03001oogoo00Ioo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomo
ogoo00001Woo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomoo`0000Moo`03001oogoo009o
o`03001oogoo00Uoo`005Goo00<007ooOol02Woo00<007oo00001Woo00<007ooOol00goo00<007oo
Ool017oo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo00<007ooOol01Woo00D007oo
Oomoo`0000Moo`03001oogoo009oo`03001oogoo00Eoo`05001oogooOol00008Ool01@00Oomoogoo
000027oo00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo00Ioo`05001oogooOol00007
Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007oo
Ool01Woo00D007ooOomoo`0000Ioo`03001oogoo009oo`03001oogoo00Ioo`05001oogooOol00006
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007oo
Ool02Goo000EOol2000;Ool00`00Ool00006Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomo
o`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01@00Oomoogoo00001goo00<0
07ooOol00Woo00<007ooOol01Goo00D007ooOomoo`0000Qoo`05001oogooOol00008Ool01@00Oomo
ogoo00001goo00D007ooOomoo`0000Uoo`04001oogoo0007Ool00`00Oomoo`02Ool00`00Oomoo`06
Ool01000Oomoo`001goo00<007ooOol00Woo00<007ooOol01Woo00D007ooOomoo`0000Ioo`03001o
ogoo009oo`03001oogoo00Ioo`05001oogooOol00006Ool00`00Oomoo`02Ool00`00Oomoo`07Ool0
1000Oomoo`001goo00<007ooOol00Woo00<007ooOol02Goo000EOol00`00Oomoo`0:Ool20007Ool0
0`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomoo`02Ool0
0`00Oomoo`06Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol01Goo00D007ooOomo
o`0000Qoo`05001oogooOol00008Ool01@00Oomoogoo00001goo00D007ooOomoo`0000Uoo`04001o
ogoo0007Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01000Oomoo`0027oo00D007ooOomoo`0000Qo
o`05001oogooOol00007Ool01@00Oomoogoo000027oo00D007ooOomoo`0000Moo`05001oogooOol0
0009Ool01000Oomoo`001goo00<007ooOol00Woo00<007ooOol02Goo000EOol00`00Oomoo`0:Ool2
0007Ool00`00Oomoo`02Ool00`00Oomoo`05Ool00`00Oomoo`02Ool00`00Oomoo`04Ool00`00Oomo
o`02Ool00`00Oomoo`06Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol01Woo00@0
07ooOol000Qoo`05001oogooOol00008Ool01@00Oomoogoo00001goo00D007ooOomoo`0000Uoo`04
001oogoo0007Ool00`00Oomoo`02Ool00`00Oomoo`06Ool01000Oomoo`0027oo00D007ooOomoo`00
00Qoo`05001oogooOol00007Ool01@00Oomoogoo000027oo00D007ooOomoo`0000Moo`05001oogoo
Ool00009Ool01000Oomoo`001goo00<007ooOol00Woo00<007ooOol02Goo000EOol00`00Oomoo`0:
Ool20008Ool01@00Oomoogoo00001goo00<007ooOol00Woo00<007ooOol017oo00<007ooOol00Woo
00<007ooOol01Woo00D007ooOomoo`0000Qoo`05001oogooOol00008Ool01000Oomoo`0027oo00D0
07ooOomoo`0000Qoo`05001oogooOol00007Ool01@00Oomoogoo00002Goo00@007ooOol000Moo`03
001oogoo009oo`03001oogoo00Ioo`04001oogoo0008Ool01@00Oomoogoo000027oo00D007ooOomo
o`0000Moo`05001oogooOol00008Ool01@00Oomoogoo00001goo00D007ooOomoo`0000Uoo`04001o
ogoo0007Ool00`00Oomoo`02Ool00`00Oomoo`09Ool001Eoo`03001oogoo00Yoo`03001oogoo00Mo
o`05001oogooOol00007Ool00`00Oomoo`02Ool00`00Oomoo`05Ool01@00Oomoogoo00002Goo00@0
07ooOol000Qoo`05001oogooOol00008Ool01000Oomoo`0027oo00D007ooOomoo`0000Qoo`05001o
ogooOol00007Ool01@00Oomoogoo00002Goo00@007ooOol000Moo`03001oogoo009oo`03001oogoo
00Ioo`04001oogoo0008Ool01@00Oomoogoo00002Goo00@007ooOol000Moo`05001oogooOol00009
Ool01000Oomoo`001goo00D007ooOomoo`0000Uoo`04001oogoo0007Ool00`00Oomoo`02Ool00`00
Oomoo`09Ool001Eoo`03001oogoo01Aoo`04001oogoo0008Ool00`00Oomoo`02Ool00`00Oomoo`05
Ool01@00Oomoogoo00002Goo00@007ooOol000Qoo`05001oogooOol00008Ool01000Oomoo`0027oo
00D007ooOomoo`0000Uoo`04001oogoo0007Ool01@00Oomoogoo00002Goo00@007ooOol000Moo`03
001oogoo009oo`03001oogoo00Ioo`04001oogoo0008Ool01@00Oomoogoo00002Goo00@007ooOol0
00Moo`05001oogooOol00009Ool01000Oomoo`001goo00D007ooOomoo`0000Uoo`04001oogoo0007
Ool00`00Oomoo`02Ool00`00Oomoo`09Ool001Eoo`8001Ioo`03001oo`0000Uoo`05001oogooOol0
0007Ool01@00Oomoogoo00002Goo00@007ooOol000Qoo`05001oogooOol00008Ool01000Oomoo`00
27oo00D007ooOomoo`0000Uoo`04001oogoo0007Ool01@00Oomoogoo00002Goo00@007ooOol000Mo
o`03001oogoo009oo`03001oogoo00Ioo`04001oogoo0008Ool01@00Oomoogoo00002Goo00@007oo
Ool000Moo`05001oogooOol00009Ool01000Oomoo`001goo00D007ooOomoo`0000Uoo`04001oogoo
0007Ool00`00Oomoo`02Ool00`00Oomoo`09Ool001Eoo`03001oogoo01Eoo`03001oo`0000Uoo`04
001oogoo0008Ool01@00Oomoogoo00002Goo00@007ooOol000Qoo`05001oogooOol00008Ool01000
Oomoo`0027oo00D007ooOomoo`0000Uoo`04001oogoo0007Ool01@00Oomoogoo00002Goo00@007oo
Ool000Qoo`05001oogooOol00008Ool01000Oomoo`0027oo00D007ooOomoo`0000Uoo`04001oogoo
0007Ool01@00Oomoogoo00002Goo00@007ooOol000Moo`05001oogooOol00009Ool01000Oomoo`00
27oo00D007ooOomoo`0000]oo`005Goo00<007ooOol05Goo00<007oo00002Goo00@007ooOol000Qo
o`05001oogooOol00009Ool01000Oomoo`0027oo00D007ooOomoo`0000Qoo`04001oogoo0008Ool0
1@00Oomoogoo00002Goo00<007oo000027oo00D007ooOomoo`0000Uoo`03001oo`0000Uoo`05001o
ogooOol00008Ool01000Oomoo`0027oo00D007ooOomoo`0000Uoo`03001oo`0000Qoo`05001oogoo
Ool00009Ool00`00Ool00008Ool01@00Oomoogoo00002Goo00<007oo00002Goo00D007ooOomoo`00
00]oo`005Goo00<007ooOol05Goo00<007oo00002Goo00@007ooOol000Qoo`05001oogooOol00009
Ool00`00Ool00009Ool01@00Oomoogoo000027oo00@007ooOol000Qoo`05001oogooOol00009Ool0
0`00Ool00008Ool01@00Oomoogoo00002Goo00<007oo00002Goo00D007ooOomoo`0000Qoo`04001o
ogoo0008Ool01@00Oomoogoo00002Goo00<007oo000027oo00D007ooOomoo`0000Uoo`03001oo`00
00Qoo`05001oogooOol00009Ool00`00Ool00009Ool01@00Oomoogoo00002goo000EOol00`00Oomo
o`0FOol00`00Oomoo`08Ool01000Oomoo`0027oo00D007ooOomoo`0000Uoo`03001oo`0000Uoo`04
001oogoo0009Ool01000Oomoo`0027oo00@007ooOol000Yoo`03001oo`0000Qoo`05001oogooOol0
0009Ool00`00Ool00009Ool01000Oomoo`002Goo00@007ooOol000Qoo`04001oogoo000:Ool00`00
Ool00008Ool01000Oomoo`002Woo00<007oo000027oo00D007ooOomoo`0000Uoo`03001oo`0000Uo
o`04001oogoo000<Ool001Eoo`8001Moo`03001oogoo00Qoo`04001oogoo0008Ool01@00Oomoogoo
00002Goo00<007oo00002Goo00@007ooOol000Uoo`04001oogoo0008Ool01000Oomoo`002Woo00<0
07oo000027oo00D007ooOomoo`0000Uoo`03001oo`0000Uoo`04001oogoo0009Ool00`00Ool00009
Ool01000Oomoo`002Woo00<007oo000027oo00@007ooOol000Yoo`03001oo`0000Qoo`05001oogoo
Ool00009Ool00`00Ool00009Ool01000Oomoo`0037oo000EOol00`00Oomoo`0QOol01000Oomoo`00
27oo00D007ooOomoo`0000Uoo`03001oo`0000Uoo`04001oogoo0009Ool00`00Ool00009Ool01000
Oomoo`002Woo00<007oo000027oo00D007ooOomoo`0000Uoo`03001oo`0000Uoo`04001oogoo0009
Ool00`00Ool00009Ool01000Oomoo`002Woo00<007oo000027oo00@007ooOol000Yoo`03001oo`00
00Qoo`05001oogooOol00009Ool00`00Ool00009Ool01000Oomoo`0037oo000EOol00`00Oomoo`0R
Ool00`00Ool00008Ool01@00Oomoogoo00002Goo00<007oo00002Goo00@007ooOol000Uoo`03001o
o`0000Uoo`04001oogoo000:Ool00`00Ool00008Ool01@00Oomoogoo00002Goo00<007oo00002Goo
00@007ooOol000Uoo`03001oo`0000Uoo`04001oogoo000:Ool00`00Ool00008Ool01000Oomoo`00
2Woo00<007oo000027oo00D007ooOomoo`0000Uoo`03001oo`0000Uoo`04001oogoo000<Ool001Eo
o`03001oogoo029oo`03001oo`0000Qoo`04001oogoo000:Ool00`00Ool00009Ool01000Oomoo`00
2Goo00<007oo00002Goo00@007ooOol000Yoo`03001oo`0000Qoo`05001oogooOol00009Ool00`00
Ool00009Ool01000Oomoo`002Goo00<007oo00002Goo00@007ooOol000Yoo`03001oo`0000Qoo`04
001oogoo000:Ool00`00Ool00008Ool01@00Oomoogoo00002Goo00<007oo00002Goo00@007ooOol0
00aoo`005Goo00<007ooOol08Woo00<007oo000027oo00@007ooOol000Yoo`03001oo`0000Uoo`04
001oogoo0009Ool00`00Ool00009Ool01000Oomoo`002Woo00<007oo000027oo00@007ooOol000Yo
o`03001oo`0000Uoo`04001oogoo0009Ool00`00Ool00009Ool01000Oomoo`002Woo00<007oo0000
27oo00@007ooOol000Yoo`03001oo`0000Qoo`04001oogoo000:Ool00`00Ool00009Ool01000Oomo
o`0037oo000EOol00`00Oomoo`0ROol00`00Ool00008Ool01000Oomoo`002Woo00<007oo00002Goo
00@007ooOol000Uoo`03001oo`0000Uoo`04001oogoo000:Ool00`00Ool00008Ool01000Oomoo`00
2Woo00<007oo00002Goo00@007ooOol000Uoo`03001oo`0000Uoo`04001oogoo000:Ool00`00Ool0
0008Ool01000Oomoo`002Woo00<007oo000027oo00@007ooOol000Yoo`03001oo`0000Uoo`04001o
ogoo000<Ool001Eoo`8002=oo`03001oo`0000Qoo`04001oogoo000:Ool00`00Ool00009Ool01000
Oomoo`002Goo00<007oo00002Woo00<007oo00002Woo00<007oo000027oo00@007ooOol000Yoo`03
001oo`0000Uoo`04001oogoo0009Ool00`00Ool00009Ool01000Oomoo`002Woo00<007oo000027oo
00@007ooOol000Yoo`03001oo`0000Qoo`04001oogoo000:Ool00`00Ool00009Ool01000Oomoo`00
37oo000EOol00`00Oomoo`0ROol00`00Ool00008Ool01000Oomoo`002Woo00<007oo00002Goo00@0
07ooOol000Uoo`03001oo`0000Yoo`03001oo`0000Yoo`03001oo`0000Uoo`03001oo`0000Yoo`03
001oo`0000Uoo`04001oogoo0009Ool00`00Ool0000:Ool00`00Ool0000:Ool00`00Ool00009Ool0
0`00Ool0000:Ool00`00Ool00009Ool00`00Ool0000:Ool00`00Ool00009Ool01000Oomoo`0037oo
000EOol00`00Oomoo`0ROol2000:Ool00`00Ool0000:Ool00`00Ool0000:Ool00`00Ool00009Ool0
0`00Ool0000:Ool00`00Ool0000:Ool00`00Ool00009Ool00`00Ool0000:Ool00`00Ool00009Ool0
1000Oomoo`002Goo00<007oo00002Woo00<007oo00002Woo00<007oo00002Goo00<007oo00002Woo
00<007oo00002Goo00<007oo00002Woo00<007oo00002Goo00@007ooOol000aoo`000Woo0P0017oo
0P0017oo0P001Goo00<007ooOol08Woo0P002Woo00<007oo00002Woo00<007oo00002Woo00<007oo
00002Goo00<007oo00002Woo00<007oo00002Woo00<007oo00002Goo00<007oo00002Woo00<007oo
00002Goo00@007ooOol000Uoo`03001oo`0000Yoo`03001oo`0000Yoo`03001oo`0000Uoo`03001o
o`0000Yoo`03001oo`0000Uoo`03001oo`0000Yoo`03001oo`0000Uoo`04001oogoo000<Ool00005
Ool007ooOol00003Ool20003Ool01000Oomoo`0017oo00<007ooOol08goo00<007ooOol027oo00<0
07oo00002Woo00<007oo00002Woo00<007oo00002Goo00<007oo00002Woo00<007oo00002Woo00<0
07oo00002Goo00<007oo00002goo0P002Goo00@007ooOol000Yoo`8000Yoo`03001oo`0000Yoo`03
001oo`0000Uoo`03001oo`0000Yoo`03001oo`0000Uoo`03001oo`0000]oo`8000Uoo`04001oogoo
000<Ool00005Ool007ooOol00008Ool01000Oomoo`0017oo0`008goo00<007ooOol027oo00<007oo
00002Woo00<007oo00002Woo00<007oo00002Goo00<007oo00002Woo00<007oo00002goo0P002Goo
00<007oo00002goo0P002Woo00<007oo00002Woo0P002Woo00<007oo00002goo0P002Goo00<007oo
00002goo0P002Goo00<007oo00002goo0P002Woo00<007oo000037oo00001Goo001oogoo00002Goo
0P001Goo00<007ooOol08goo00<007ooOol027oo00<007oo00002Woo00<007oo00002Woo00<007oo
00002Woo0P002Woo00<007oo00002goo00<007ooOol027oo00<007oo00002goo00<007ooOol02Goo
00<007oo00002Woo0P002Woo00<007oo00002goo00<007ooOol027oo00<007oo00002goo00<007oo
Ool027oo00<007oo00002goo00<007ooOol02Goo00<007oo000037oo00001Goo001oogoo000027oo
00@007ooOol000Aoo`03001oogoo02=oo`03001oogoo00Qoo`03001oo`0000Yoo`03001oo`0000Yo
o`03001oo`0000Yoo`8000Yoo`03001oo`0000]oo`03001oogoo00Qoo`03001oo`0000]oo`03001o
ogoo00Uoo`03001oo`0000Yoo`03001oogoo00Uoo`03001oo`0000]oo`03001oogoo00Qoo`03001o
o`0000]oo`03001oogoo00Qoo`03001oo`0000]oo`03001oogoo00Uoo`03001oo`0000aoo`000Woo
0P002Woo0P001Goo00<007ooOol0;Woo00<007oo00002goo0P002Woo00<007oo00002Woo0P002Woo
00<007oo00002goo00<007ooOol027oo00<007oo00002goo00<007ooOol02Goo00<007oo00002Woo
00<007ooOol02Goo00<007oo00002goo00<007ooOol027oo00<007oo00002goo00<007ooOol027oo
00<007oo00002goo00<007ooOol02Goo00<007oo000037oo000EOol00`00Oomoo`0^Ool00`00Ool0
000;Ool00`00Oomoo`09Ool00`00Ool0000:Ool00`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomo
o`08Ool00`00Ool0000;Ool00`00Oomoo`09Ool00`00Ool0000:Ool00`00Oomoo`09Ool00`00Ool0
000;Ool00`00Oomoo`08Ool00`00Ool0000;Ool00`00Oomoo`08Ool00`00Ool0000;Ool00`00Oomo
o`09Ool00`00Ool0000<Ool001Eoo`03001oogoo02ioo`03001oo`0000]oo`03001oogoo00Uoo`03
001oo`0000Yoo`03001oogoo00Uoo`03001oo`0000]oo`03001oogoo00Qoo`03001oo`0000]oo`03
001oogoo00Uoo`03001oo`0000Yoo`03001oogoo00Uoo`03001oo`0000]oo`03001oogoo00Qoo`03
001oo`0000]oo`03001oogoo00Qoo`03001oo`0000]oo`03001oogoo00Uoo`03001oo`0000aoo`00
5Goo0P00;goo00<007oo00002goo00<007ooOol02Goo00<007oo00002Woo00<007ooOol02Goo00<0
07oo00002goo00<007ooOol027oo00<007oo00002goo00<007ooOol02Goo00<007oo00002Woo00<0
07ooOol02Goo00<007oo00002goo00<007ooOol027oo00<007oo00002goo00<007ooOol027oo00<0
07oo00002goo00<007ooOol02Goo00<007oo000037oo000EOol00`00Oomoo`0^Ool00`00Ool0000;
Ool00`00Oomoo`09Ool00`00Ool0000:Ool00`00Oomoo`09Ool00`00Ool0000;Ool00`00Oomoo`08
Ool00`00Ool0000;Ool00`00Oomoo`09Ool00`00Ool0000:Ool00`00Oomoo`09Ool00`00Ool0000;
Ool00`00Oomoo`08Ool00`00Ool0000;Ool00`00Oomoo`08Ool00`00Ool0000;Ool00`00Oomoo`09
Ool00`00Ool0000<Ool001Eoo`03001oogoo02ioo`03001oo`0000]oo`03001oogoo00Uoo`03001o
o`0000Yoo`03001oogoo00Uoo`03001oo`0000]oo`03001oogoo00Qoo`03001oo`0000]oo`03001o
ogoo00Uoo`03001oo`0000Yoo`03001oogoo00Uoo`03001oo`0000]oo`03001oogoo00Qoo`03001o
o`0000]oo`03001oogoo00Qoo`03001oo`0000]oo`03001oogoo00Uoo`03001oo`0000aoo`005Goo
00<007ooOol0;Woo00<007oo00002goo00<007ooOol02Goo00<007oo00002Woo00<007ooOol02Goo
00<007oo00005Woo00<007oo00005goo00<007oo00005Woo00<007oo00005Woo00<007oo00005Woo
00<007oo00005goo00<007oo000037oo000EOol00`00Oomoo`0^Ool00`00Ool0000;Ool00`00Oomo
o`09Ool2000;Ool00`00Oomoo`09Ool00`00Ool0000FOol00`00Ool0000GOol00`00Ool0000FOol0
0`00Ool0000FOol00`00Ool0000FOol00`00Ool0000GOol00`00Ool0000<Ool001Eoo`03001oogoo
02ioo`8000aoo`03001oogoo00Uoo`8001Moo`8001Moo`03001oo`0001Moo`8001Moo`8001Moo`80
01Moo`03001oo`0001Moo`8000eoo`005Goo0P00<7oo00<007ooOol02Woo00<007ooOol02Goo0P00
5goo0P005goo0P0067oo0P005goo0P005goo0P005goo0P0067oo0P003Goo000EOol00`00Oomoo`0_
Ool00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol2000HOol00`00
Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0FOol2000=Ool001Eoo`03001oogoo02moo`03001o
ogoo01Moo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Ioo`8001Qoo`03001oogoo01Io
o`03001oogoo01Ioo`03001oogoo01Ioo`8000eoo`005Goo00<007ooOol0;goo00<007ooOol05goo
00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol05Woo
00<007ooOol05Woo00<007ooOol05goo00<007ooOol02goo000EOol00`00Oomoo`0_Ool00`00Oomo
o`0GOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomo
o`0FOol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0;Ool001Eoo`80031oo`03001oogoo
01Moo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Moo`03001oogoo01Ioo`03001oogoo
01Ioo`03001oogoo01Ioo`03001oogoo01Moo`03001oogoo00]oo`005Goo00<007ooOol0;goo00<0
07ooOol05goo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo00<0
07ooOol05Woo00<007ooOol05Woo00<007ooOol05goo00<007ooOol02goo000EOol00`00Oomoo`0_
Ool00`00Oomoo`0GOol00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0F
Ool00`00Oomoo`0FOol00`00Oomoo`0FOol00`00Oomoo`0GOol00`00Oomoo`0;Ool001Eoo`03001o
ogoo04Uoo`03001oogoo01Ioo`03001oogoo01Ioo`03001oogoo01Moo`03001oogoo01Ioo`03001o
ogoo01Ioo`03001oogoo01Ioo`03001oogoo01Moo`03001oogoo00]oo`005Goo00<007ooOol0HWoo
00<007ooOol05Woo00<007ooOol05goo00<007ooOol05Woo00<007ooOol05Woo00<007ooOol05Woo
00<007ooOol05goo00<007ooOol02goo000EOol00`00Oomoo`3oOol9Ool001Eoo`800?moo`Yoo`00
5Goo00<007ooOol0ogoo2Goo000EOol00`00Oomoo`3oOol9Ool00001\
\>"],
  ImageRangeCache->{{{0, 287}, {176.938, 0}} -> {-3.38643, 0.254777, 
  0.158229, 0.00359051}}]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Repeat these steps for a set of different ",
  Cell[BoxData[
      \(TraditionalForm\`\[Mu]\)]],
  " values."
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Random Walk"
}], "Subsection"],

Cell[TextData[{
  "Here is a routine for the two-dimensional, ",
  StyleBox["n",
    FontSlant->"Italic"],
  "-step random walk with equal (unit) step lengths. Starting at"
}], "Text",
  CellTags->"Random walk"],

Cell[BoxData[
    \(TraditionalForm\`\(z = {0, 0}; \)\)], "Input"],

Cell[TextData[{

  "construct a routine for generating a uniformly distributed random number \

between ",

  Cell[BoxData[

      \(TraditionalForm\`{\(-1\), 1}\)]],

  ":"

}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`rand := Random[Real, {\(-1\), 1}]\)], "Input"],

Cell[TextData[{
  "Each time you enter ",
  Cell[BoxData[
      \(TraditionalForm\`rand\)]],
  " you get a different answer:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Table[rand, {5}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{0.730597682133928838`, 0.735073545049735876`, 
      \(-0.939383929368090342`\), 0.596999589049181977`, 
      0.480346142196171932`}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Then construct a routine called ",
  Cell[BoxData[
      \(TraditionalForm\`RandomStep\)]],
  " for generating a random 2 dimensional vector of unit length:"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`\[LeftDoubleBracketingBar]x_\[RightDoubleBracketingBar] := 
      \@\(x . x\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`Norm[x_] := 
      x\/\[LeftDoubleBracketingBar]x\[RightDoubleBracketingBar]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`RandomStep := Norm[{rand, rand}]\)], "Input"],

Cell[TextData[{
  "We introduce the (DoubleBracketingBar) notation ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftDoubleBracketingBar]x\[RightDoubleBracketingBar]\)]],
  " to find the length of a vector ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ".  Note the use of the ",
  Cell[BoxData[
      \(TraditionalForm\`Dot\)]],
  " product. ",
  Cell[BoxData[
      \(TraditionalForm
      \`\[LeftDoubleBracketingBar]x\[RightDoubleBracketingBar]\)]],
  " is a ",
  StyleBox["special symbol",
    FontSlant->"Italic"],
  " formed by ",
  Cell[BoxData[
      \(TraditionalForm\`\[EscapeKey]l || x\[EscapeKey]r || \)]],
  " or from a palette."
}], "Warning"],

Cell[TextData[{
  "For ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " steps form the cumulative sums (see ",
  ButtonBox["FoldList",
    ButtonData:>"FoldList",
    ButtonStyle->"Hyperlink"],
  " above):"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm
    \`RandomWalk[n_Integer] := FoldList[Plus, z, Table[RandomStep, {n}]]\)], 
  "Input"],

Cell["E.g., ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`RandomWalk[5]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"0", "0"},
            {\(-0.132268175000948717`\), \(-0.991213967759695435`\)},
            {\(-0.803502962329376302`\), \(-0.249969163204438871`\)},
            {\(-0.278328459322747168`\), "0.601025396937833722`"},
            {"0.60646012434363854`", "0.135032733676242067`"},
            {"1.59518928636272416`", "0.284747943902314748`"}
            },
          ColumnAlignments->{Decimal}], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["Now plot the steps by putting a line through all the points:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`\(Show[Graphics[Line[RandomWalk[500]]], Axes \[Rule] True, 
      AspectRatio \[Rule] Automatic, AspectRatio \[Rule] Automatic]; \)\)], 
  "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .71443 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.767988 0.0384749 0.0600407 0.0384749 [
[.19086 .04754 -9 -9 ]
[.19086 .04754 9 0 ]
[.38324 .04754 -9 -9 ]
[.38324 .04754 9 0 ]
[.57561 .04754 -6 -9 ]
[.57561 .04754 6 0 ]
[.96036 .04754 -3 -9 ]
[.96036 .04754 3 0 ]
[.75549 .15623 -18 -4.5 ]
[.75549 .15623 0 4.5 ]
[.75549 .25242 -6 -4.5 ]
[.75549 .25242 0 4.5 ]
[.75549 .3486 -18 -4.5 ]
[.75549 .3486 0 4.5 ]
[.75549 .44479 -12 -4.5 ]
[.75549 .44479 0 4.5 ]
[.75549 .54098 -24 -4.5 ]
[.75549 .54098 0 4.5 ]
[.75549 .63716 -12 -4.5 ]
[.75549 .63716 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .71443 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.19086 .06004 m
.19086 .06629 L
s
[(-15)] .19086 .04754 0 1 Mshowa
.38324 .06004 m
.38324 .06629 L
s
[(-10)] .38324 .04754 0 1 Mshowa
.57561 .06004 m
.57561 .06629 L
s
[(-5)] .57561 .04754 0 1 Mshowa
.96036 .06004 m
.96036 .06629 L
s
[(5)] .96036 .04754 0 1 Mshowa
.125 Mabswid
.03696 .06004 m
.03696 .06379 L
s
.07544 .06004 m
.07544 .06379 L
s
.11391 .06004 m
.11391 .06379 L
s
.15239 .06004 m
.15239 .06379 L
s
.22934 .06004 m
.22934 .06379 L
s
.26781 .06004 m
.26781 .06379 L
s
.30629 .06004 m
.30629 .06379 L
s
.34476 .06004 m
.34476 .06379 L
s
.42171 .06004 m
.42171 .06379 L
s
.46019 .06004 m
.46019 .06379 L
s
.49866 .06004 m
.49866 .06379 L
s
.53714 .06004 m
.53714 .06379 L
s
.61409 .06004 m
.61409 .06379 L
s
.65256 .06004 m
.65256 .06379 L
s
.69104 .06004 m
.69104 .06379 L
s
.72951 .06004 m
.72951 .06379 L
s
.80646 .06004 m
.80646 .06379 L
s
.84494 .06004 m
.84494 .06379 L
s
.88341 .06004 m
.88341 .06379 L
s
.92189 .06004 m
.92189 .06379 L
s
.99884 .06004 m
.99884 .06379 L
s
.25 Mabswid
0 .06004 m
1 .06004 L
s
.76799 .15623 m
.77424 .15623 L
s
[(2.5)] .75549 .15623 1 0 Mshowa
.76799 .25242 m
.77424 .25242 L
s
[(5)] .75549 .25242 1 0 Mshowa
.76799 .3486 m
.77424 .3486 L
s
[(7.5)] .75549 .3486 1 0 Mshowa
.76799 .44479 m
.77424 .44479 L
s
[(10)] .75549 .44479 1 0 Mshowa
.76799 .54098 m
.77424 .54098 L
s
[(12.5)] .75549 .54098 1 0 Mshowa
.76799 .63716 m
.77424 .63716 L
s
[(15)] .75549 .63716 1 0 Mshowa
.125 Mabswid
.76799 .07928 m
.77174 .07928 L
s
.76799 .09852 m
.77174 .09852 L
s
.76799 .11775 m
.77174 .11775 L
s
.76799 .13699 m
.77174 .13699 L
s
.76799 .17547 m
.77174 .17547 L
s
.76799 .1947 m
.77174 .1947 L
s
.76799 .21394 m
.77174 .21394 L
s
.76799 .23318 m
.77174 .23318 L
s
.76799 .27165 m
.77174 .27165 L
s
.76799 .29089 m
.77174 .29089 L
s
.76799 .31013 m
.77174 .31013 L
s
.76799 .32937 m
.77174 .32937 L
s
.76799 .36784 m
.77174 .36784 L
s
.76799 .38708 m
.77174 .38708 L
s
.76799 .40632 m
.77174 .40632 L
s
.76799 .42555 m
.77174 .42555 L
s
.76799 .46403 m
.77174 .46403 L
s
.76799 .48326 m
.77174 .48326 L
s
.76799 .5025 m
.77174 .5025 L
s
.76799 .52174 m
.77174 .52174 L
s
.76799 .56021 m
.77174 .56021 L
s
.76799 .57945 m
.77174 .57945 L
s
.76799 .59869 m
.77174 .59869 L
s
.76799 .61793 m
.77174 .61793 L
s
.76799 .0408 m
.77174 .0408 L
s
.76799 .02157 m
.77174 .02157 L
s
.76799 .00233 m
.77174 .00233 L
s
.76799 .6564 m
.77174 .6564 L
s
.76799 .67564 m
.77174 .67564 L
s
.76799 .69488 m
.77174 .69488 L
s
.76799 .71411 m
.77174 .71411 L
s
.25 Mabswid
.76799 0 m
.76799 .71443 L
s
0 0 m
1 0 L
1 .71443 L
0 .71443 L
closepath
clip
newpath
.5 Mabswid
.76799 .06004 m
.79504 .0874 L
.82958 .10435 L
.79883 .12748 L
.79116 .16518 L
.82531 .18291 L
.84612 .21526 L
.81773 .24123 L
.77995 .2485 L
.80298 .21768 L
.78827 .25323 L
.80152 .21711 L
.80626 .17893 L
.83077 .14927 L
.8689 .15442 L
.83768 .17692 L
.82841 .21426 L
.82853 .25273 L
.85724 .22712 L
.85498 .18871 L
.88267 .21542 L
.91345 .23851 L
.89458 .27204 L
.86062 .29012 L
.8803 .32318 L
.84272 .33141 L
.87437 .30953 L
.84541 .33486 L
.81968 .30626 L
.8225 .34463 L
.83446 .30806 L
.80705 .33507 L
.84544 .33763 L
.82087 .30803 L
.85739 .32013 L
.81893 .32099 L
.78437 .33791 L
.80145 .37239 L
.76322 .36801 L
.77969 .33324 L
.79975 .3004 L
.77455 .27133 L
.74895 .30005 L
.7189 .27602 L
.68538 .25713 L
.70814 .28815 L
.71098 .32652 L
.74934 .32358 L
.75034 .28512 L
.71186 .2852 L
Mistroke
.67636 .30003 L
.64052 .28604 L
.67783 .29541 L
.64395 .27717 L
.62022 .30746 L
.59044 .2831 L
.55761 .26304 L
.53232 .23404 L
.57047 .23906 L
.55367 .27368 L
.51524 .27188 L
.50506 .23478 L
.52811 .26558 L
.49435 .28404 L
.45882 .26927 L
.49659 .26193 L
.52796 .28421 L
.56201 .26629 L
.59969 .2585 L
.62016 .22592 L
.59261 .25278 L
.55414 .25276 L
.59241 .24886 L
.62816 .23463 L
.58996 .23922 L
.62564 .25361 L
.65315 .22671 L
.68294 .20236 L
.72058 .1944 L
.74915 .22017 L
.73324 .25521 L
.70629 .28267 L
.68917 .31712 L
.72318 .29914 L
.68568 .30776 L
.65785 .33432 L
.6394 .36809 L
.61049 .34271 L
.59723 .37882 L
.58868 .34131 L
.55383 .32501 L
.54749 .28706 L
.50902 .28782 L
.47212 .27691 L
.51056 .27855 L
.48813 .24729 L
.48677 .28574 L
.45728 .26103 L
.43975 .29528 L
.46623 .32319 L
Mistroke
.4943 .29688 L
.49564 .33534 L
.4948 .3738 L
.45927 .38857 L
.44929 .35141 L
.48179 .33082 L
.49962 .36491 L
.51082 .3281 L
.47686 .34618 L
.47013 .38406 L
.50306 .40396 L
.50425 .44242 L
.54233 .44789 L
.51265 .42341 L
.51178 .46187 L
.54944 .45395 L
.51363 .46805 L
.48409 .4434 L
.4823 .48183 L
.47849 .44355 L
.45843 .41072 L
.42764 .38764 L
.42935 .42607 L
.43021 .38761 L
.43141 .42606 L
.43194 .38759 L
.40171 .3638 L
.41444 .4001 L
.45274 .39644 L
.45398 .4349 L
.42726 .40722 L
.38893 .41055 L
.35863 .38683 L
.32102 .37874 L
.3449 .4089 L
.34777 .37053 L
.31145 .38324 L
.28215 .35831 L
.24371 .35994 L
.22719 .32519 L
.20184 .29624 L
.23289 .31897 L
.26552 .33935 L
.29935 .32103 L
.31159 .28456 L
.338 .31254 L
.37081 .33263 L
.34616 .36217 L
.37176 .33344 L
.33831 .35246 L
Mistroke
.37439 .36583 L
.40504 .34258 L
.44235 .35201 L
.47958 .34231 L
.45133 .36844 L
.42231 .34318 L
.40806 .37891 L
.37923 .35343 L
.38563 .39137 L
.424 .39424 L
.45377 .41861 L
.4543 .45708 L
.48177 .43014 L
.50128 .46331 L
.46319 .46877 L
.49171 .44295 L
.4554 .45565 L
.4739 .42192 L
.49399 .38911 L
.49196 .35068 L
.46499 .32325 L
.50336 .32046 L
.5198 .35524 L
.4819 .36188 L
.52027 .35899 L
.52144 .39745 L
.5069 .43307 L
.54528 .43568 L
.50807 .42593 L
.47543 .40556 L
.44239 .38584 L
.468 .35712 L
.43777 .33333 L
.40552 .35431 L
.39431 .39111 L
.42649 .37003 L
.45206 .34128 L
.42876 .31067 L
.43624 .27292 L
.44532 .31031 L
.45155 .34828 L
.42036 .3708 L
.38763 .35058 L
.41485 .32339 L
.38879 .29509 L
.42721 .29295 L
.45897 .31466 L
.48686 .28816 L
.52328 .30056 L
.50871 .33617 L
Mistroke
.47089 .34326 L
.48931 .30948 L
.51467 .33841 L
.47683 .33146 L
.47359 .29312 L
.48752 .25725 L
.4615 .22891 L
.49676 .2443 L
.45885 .25088 L
.4213 .2425 L
.4265 .28062 L
.46465 .2856 L
.43176 .26564 L
.39332 .26723 L
.36051 .28732 L
.38016 .25425 L
.40848 .2282 L
.38149 .25562 L
.40224 .28802 L
.37663 .25931 L
.34477 .23774 L
.37976 .25373 L
.41814 .25107 L
.38897 .22598 L
.38927 .18751 L
.35269 .19943 L
.31544 .20905 L
.28022 .22454 L
.24196 .22865 L
.20943 .2492 L
.18375 .27785 L
.22107 .2872 L
.18542 .27273 L
.21378 .29874 L
.19469 .33215 L
.22622 .35419 L
.25884 .3746 L
.27876 .34168 L
.299 .30897 L
.31588 .27439 L
.35391 .28019 L
.34156 .31662 L
.32596 .35179 L
.32981 .31351 L
.29187 .31988 L
.30717 .28457 L
.34273 .29927 L
.3812 .29854 L
.36014 .26634 L
.32191 .26197 L
Mistroke
.31453 .29973 L
.31711 .26134 L
.35275 .24685 L
.31666 .23351 L
.28196 .25014 L
.28994 .2125 L
.26498 .18322 L
.29206 .15589 L
.25707 .1399 L
.21937 .14759 L
.25456 .13205 L
.22356 .10926 L
.22739 .07098 L
.22477 .03259 L
.24464 .06553 L
.22923 .10079 L
.19976 .07606 L
.23822 .07504 L
.20449 .05652 L
.24212 .04849 L
.22 .01701 L
.2482 .04319 L
.22306 .07231 L
.25685 .0907 L
.29213 .07536 L
.25821 .09351 L
.29612 .08694 L
.32875 .10733 L
.33485 .06934 L
.30094 .05116 L
.26626 .06782 L
.24476 .09972 L
.20641 .10288 L
.19597 .06584 L
.22442 .09175 L
.23757 .05559 L
.20022 .04636 L
.17271 .07326 L
.1464 .10133 L
.12534 .06913 L
.12376 .10757 L
.08862 .12324 L
.05408 .10629 L
.08135 .13343 L
.05249 .15888 L
.04044 .19542 L
.0273 .15926 L
.06265 .14406 L
.03271 .16822 L
.07113 .17032 L
Mistroke
.0402 .1932 L
.07763 .18429 L
.10632 .20992 L
.10557 .24839 L
.11917 .2124 L
.13317 .24824 L
.0999 .26757 L
.07315 .23991 L
.03468 .24005 L
.02381 .27695 L
.04829 .30664 L
.08174 .28762 L
.08623 .24941 L
.06067 .27817 L
.09755 .26719 L
.11081 .23107 L
.09165 .1977 L
.12194 .17399 L
.16041 .17306 L
.17677 .20788 L
.19411 .24223 L
.17977 .27793 L
.21067 .25502 L
.24588 .27053 L
.24021 .23247 L
.24497 .27065 L
.27701 .29196 L
.31544 .29393 L
.28143 .31191 L
.3183 .30092 L
.32509 .26305 L
.28679 .2593 L
.31021 .22877 L
.34869 .22887 L
.37398 .25785 L
.35733 .29254 L
.35135 .33055 L
.38158 .30675 L
.41408 .28616 L
.44585 .30788 L
.43111 .34342 L
.46861 .33483 L
.50085 .35583 L
.51773 .3904 L
.55477 .40083 L
.59158 .38964 L
.55823 .40883 L
.5257 .38829 L
.54507 .42153 L
.56648 .38957 L
Mistroke
.60496 .38952 L
.64255 .38134 L
.64191 .41981 L
.66543 .38936 L
.67955 .35357 L
.65377 .325 L
.6882 .30782 L
.66908 .34122 L
.68556 .37598 L
.71714 .354 L
.7456 .37989 L
.72592 .34683 L
.68882 .33663 L
.65889 .3608 L
.66455 .39886 L
.68959 .42807 L
.7266 .43859 L
.69377 .41853 L
.66409 .39404 L
.69891 .4104 L
.73499 .42377 L
.69657 .42583 L
.72318 .45362 L
.76165 .45443 L
.78149 .42146 L
.7794 .45988 L
.74366 .47413 L
.78075 .46388 L
.76323 .42963 L
.76754 .46786 L
.74056 .49529 L
.74738 .45743 L
.76757 .42468 L
.7608 .46255 L
.79613 .4778 L
.80675 .44083 L
.77238 .42354 L
.73976 .40313 L
.71085 .42851 L
.68589 .45779 L
.72102 .4735 L
.73185 .51041 L
.75732 .53926 L
.72304 .55673 L
.68461 .55488 L
.69322 .51738 L
.66798 .54641 L
.63657 .56864 L
.67364 .55832 L
.71134 .566 L
Mistroke
.74453 .58546 L
.77323 .61109 L
.79421 .64334 L
.76244 .66505 L
.79226 .64073 L
.76419 .61441 L
.79995 .6286 L
.79325 .59072 L
.7985 .62883 L
.78653 .59226 L
.82125 .57568 L
.81921 .6141 L
.84943 .63791 L
.87061 .67004 L
.84359 .69742 L
.85938 .66234 L
.82888 .6858 L
.8409 .64925 L
.82422 .61457 L
.80417 .58173 L
.83813 .56365 L
.86406 .59207 L
.83986 .62198 L
.81835 .59008 L
.8001 .55621 L
.8143 .52045 L
.78532 .49514 L
.8164 .47246 L
.77852 .46571 L
.75728 .43364 L
.77981 .40245 L
.75099 .37696 L
.77759 .40476 L
.74929 .37869 L
.76434 .34328 L
.78809 .37355 L
.78226 .41158 L
.7523 .43572 L
.72544 .46327 L
.69603 .43846 L
.66579 .41468 L
.63272 .39501 L
.63929 .3571 L
.60894 .33345 L
.62751 .29976 L
.65286 .3287 L
.68399 .30608 L
.65751 .334 L
.66358 .296 L
.69479 .27351 L
Mistroke
.65633 .27426 L
.63898 .3086 L
.60621 .28843 L
.56929 .29925 L
.56193 .26148 L
.59961 .25373 L
.61697 .28807 L
.57917 .28089 L
.60343 .31076 L
.56539 .30497 L
.52883 .31694 L
.51413 .28138 L
.54267 .25557 L
.51111 .23357 L
.54013 .25882 L
.57809 .26509 L
.58154 .30341 L
.6115 .27927 L
.63856 .30663 L
.66923 .32986 L
.64167 .3567 L
.67413 .33605 L
.70962 .3212 L
.70333 .28324 L
.73608 .26304 L
.72923 .22518 L
.76635 .21507 L
.79437 .18871 L
.76762 .21636 L
.78651 .18284 L
.7962 .22008 L
.83348 .22959 L
.84019 .26748 L
.87445 .24997 L
.91291 .25089 L
.91547 .2125 L
.94739 .19103 L
.92265 .22049 L
.89088 .24218 L
.928 .23207 L
.94459 .19736 L
.97619 .17541 L
.93962 .16346 L
.90283 .17473 L
.88541 .14043 L
.85296 .11975 L
.86959 .15445 L
.89825 .12878 L
.92832 .15278 L
.9491 .12039 L
Mistroke
.97117 .1519 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{267.25, 190.875},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004;0000_Q000`40O003h00Oc7oo0P00?Goo003<
Ool00`00Oomoo`0lOol00<aoo`03001oogoo03aoo`00c7oo00<007ooOol0?7oo000jOol2002@Ool0
0`00Oomoo`0lOol0031oo`<000=oo`<00004Ool007oo000WOol30004Ool2000]Ool3000_Ool2000_
Ool3000;Ool0035oo`03001oogoo00Eoo`05001oo`00Ool0000WOol00`00Oomoo`02Ool01000Oomo
o`00;goo00<007ooOol0;7oo00<007ooOol0<Goo00<007ooOol027oo000ZOol50002Ool00`00Oomo
o`05Ool01P00Oomoo`00Ool001moo`D0009oo`03001oogoo009oo`04001oogoo000VOol50004Ool0
0`00Oomoo`0/Ool00`00Oomoo`0aOol00`00Oomoo`08Ool0035oo`03001oogoo009oo`<0009oo`80
009oo`03001oogoo02=oo`03001oogoo009oo`04001oogoo000/Ool3000_Ool00`00Oomoo`0^Ool3
000;Ool0035oo`03001oogoo009oo`03001oogoo009oo`03001oo`00009oo`03001oogoo029oo`03
001oogoo009oo`04001oogoo000/Ool00`00Oomoo`0_Ool00`00Oomoo`0^Ool00`00Oomoo`0;Ool0
031oo`8000Aoo`@00005Ool00000Ool00002Ool00`00Oomoo`0POol20005Ool2000]Ool4000^Ool2
000_Ool4000:Ool003]oo`04001oo`000003Ool00`00Oomoo`27Ool00`00Oomoo`0lOol003Eoo`@0
009oo`05001oo`00Ool00002Ool00`00Oomoo`27Ool00`00Oomoo`0lOol003Aoo`03001oogoo009o
o`T000eoo`<007Yoo`03001oogoo03aoo`00<goo00<007ooOol00goo200037oo0P000goo0P00N7oo
00<007ooOol0?7oo000bOol01000Oomoogoo0`000goo00@007ooOol000]oo`8000Moo`8007Ioo`03
001oogoo03aoo`00o`003000000:Ool00`00Oomoo`07Ool00`00Oomoo`07Ool00`00Oomoo`07Ool0
0`00Oomoo`05Ool01@00Ool007oo00001Goo1@000Woo00<007ooOol00goo0`001goo00<007ooOol0
0goo0P000Woo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol01goo00<007ooOol027oo00<007ooOol01goo00<007ooOol01goo00<007ooOol01goo00<0
07ooOol027oo00<007ooOol01goo0P0027oo00<007ooOol01goo00<007ooOol027oo00<007ooOol0
1goo00<007ooOol01goo00<007ooOol01goo0@000Goo000QOol00`00Oomoo`0;Ool00`00Oomoo`02
Ool20006Ool00`00Ool00002Ool00`00Oomoo`03Ool00`00Oomoo`0?Ool00`00Oomoo`1`Ool00`00
Ool0000lOol0025oo`03001oogoo00Yoo`03001oogoo00=oo`03001oo`0000Aoo`@00003Ool007oo
00Eoo`03001oogoo00moo`03001oogoo071oo`04001oogoo000kOol0025oo`8000]oo`03001oogoo
00Aoo``000Eoo`03001oogoo00=oo`8000]oo`03001oogoo071oo`05001oogooOol0000jOol0025o
o`03001oo`0000Uoo`03001oogoo00Eoo`04001oo`000003Ool00`00Oomoo`020004Ool00`00Oomo
o`02Ool2000<Ool00`00Oomoo`1aOol20003Ool00`00Oomoo`0gOol0025oo`03001oo`0000Qoo`03
001oogoo00Ioo`03001oogoo0080009oo`06001oogoo001oo`000Woo00<007ooOol00`003Woo00<0
07ooOol0LGoo00<007ooOol00goo00<007ooOol0=Woo000QOol01000Oomoo`001Woo00<007ooOol0
27oo00<007ooOol00P0000Eoo`00Oomoo`00009oo`D0009oo`L000Qoo`03001oogoo075oo`03001o
ogoo00Aoo`8003Ioo`008Goo00D007ooOomoo`0000Aoo`03001oogoo00Uoo`03001oogoo009oo`04
001oogoo0004Ool60007Ool20006Ool00`00Oomoo`1aOol00`00Oomoo`06Ool2000dOol0025oo`05
001oogooOol00003Ool00`00Oomoo`0:Ool00`00Oomoo`02Ool200000goo001oo`02Ool00`00Oomo
o`0=Ool20004Ool00`00Oomoo`1aOol00`00Oomoo`08Ool3000aOol0025oo`03001oogoo009oo`03
001oo`0000ioo`04001oogooOol7000BOol01000Oomoo`00M7oo0P0037oo0P00;goo000QOol00`00
Oomoo`03Ool00`00Oomoo`0=Ool5000IOol3001dOol00`00Oomoo`0<Ool2000^Ool000ioo`80011o
o`8001Uoo`03001oogoo01Uoo`03001oogoo079oo`03001oogoo00]oo`03001oogoo02ioo`003goo
0`002goo0`006goo0P00Sgoo00<007ooOol02Woo00<007ooOol0;goo000@Ool00`00Ool000020006
Ool2000POol00`00Oomoo`2<Ool00`00Oomoo`09Ool00`00Oomoo`0`Ool0015oo`04001oogooOol2
000017oo000000008goo00<007ooOol0Rgoo0P002Goo00<007ooOol027oo0P009goo000BOol00`00
Oomoo`02Ool00`00Oomoo`0UOol2002;Ool00`00Oomoo`07Ool00`00Oomoo`09Ool00`00Ool0000G
Ool00`00Oomoo`0<Ool001=oo`03001oogoo02]oo`03001oogoo08Qoo`03001oogoo00Ioo`03001o
ogoo00]oo`04001oo`00000EOol00`00Oomoo`0<Ool001Aoo`03001oogoo02]oo`03001oogoo08Mo
o`03001oogoo00Eoo`03001oogoo00aoo`05001oogooOol00006Ool2000;Ool00`00Ool0000=Ool0
01Eoo`03001oogoo02Yoo`8008Qoo`03001oogoo00Eoo`03001oogoo00eoo`04001oogooOol20003
Ool01000Oomoo`002Goo00D007ooOomoo`0000aoo`0057oo00<007ooOol0:Goo0P00RWoo0P001Woo
00<007ooOol03Goo00<007ooOol00goo00<007oo000017oo00<007ooOol01Goo00<007ooOol00goo
00<007ooOol02Goo000COol00`00Oomoo`0WOol30002Ool40026Ool00`00Oomoo`04Ool00`00Oomo
o`0?Ool00`00Oomoo`03Ool00`00Oomoo`04Ool20005Ool00`00Oomoo`03Ool00`00Oomoo`09Ool0
00moo`800003Ool007oo02Moo`L000Aoo`8008Aoo`03001oogoo00Aoo`03001oogoo00moo`03001o
ogoo009oo`8000Qoo`05001oogooOol00007Ool00`00Oomoo`08Ool000eoo`80009oo`03001oogoo
02Ioo`<000]oo`<006eoo`@000=oo`8000=oo`<000Eoo`03001oogoo00Aoo`03001oogoo00Moo`@0
00Eoo`04001oogoo0002Ool00`00Oomoo`06Ool00`00Ool00009Ool00`00Oomoo`07Ool000Yoo`@0
009oo`03001oogoo03Qoo`8006aoo`03001oogoo00=oo`8000Ioo`03001oogoo009oo`03001oogoo
00Aoo`03001oogoo00Moo`04001oogooOol600000goo001oo`02Ool00`00Oomoo`07Ool00`00Oomo
o`09Ool00`00Oomoo`06Ool000Qoo`800003Ool00000009oo`03001oogoo03]oo`03001oogoo06Yo
o`03001oogoo00Yoo`03001oogoo009oo`<000Aoo`03001oogoo00Ioo`03001oogoo00Moo`8000Eo
o`03001oogoo01]oo`001goo00@007ooOol000=oo`03001oogoo03]oo`03001oogoo06aoo`03001o
ogoo00Ioo`<000Eoo`03001oogoo00=oo`03001oogoo00Ioo`03001oogoo00Moo`03001oogoo00Io
o`03001oogoo01Yoo`001goo00<007oo000017oo00<007ooOol0>Woo00<007ooOol0JWoo00@007oo
Ool000Qoo`03001oogoo00Eoo`03001oogoo00=oo`03001oogoo00Eoo`03001oogoo00Ioo`8000Uo
o`03001oogoo00Moo`@000moo`001goo2000>goo00<007ooOol0K7oo0P002Goo100017oo00<007oo
Ool00goo0P001Goo00<007ooOol01Woo00<007ooOol02Woo00<007ooOol00goo0`0017oo0`0037oo
0008Ool00`00Oomoo`02Ool00`00Ool00004000eOol00`00Oomoo`20Ool00`00Oomoo`05Ool20002
Ool00`00Oomoo`05Ool2000=Ool00`00Oomoo`03000:Ool30009Ool000Qoo`03001oogoo009oo`05
001oogooOol0000=Ool<000MOol00`00Oomoo`21Ool20008Ool30006Ool00`00Oomoo`0>Ool2000@
Ool20007Ool000Qoo`05001oogooOol00002Ool2000=Ool00`00Oomoo`09Ool00`00Oomoo`0JOol0
0`00Oomoo`22Ool00`00Oomoo`07Ool00`00Oomoo`020003Ool00`00Oomoo`0POol00`00Oomoo`07
Ool000Uoo`06001oogoo001oo`003Woo00<007ooOol02goo00<007ooOol067oo00<007ooOol0Pgoo
00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol0025oo`03001oogoo00Qo
o`002Goo00<007oo00000P0017oo10001Goo0P003Woo00<007ooOol067oo00<007ooOol07Goo0P00
I7oo00<007ooOol00Woo00<007ooOol00Woo00<007ooOol00Woo00@007ooOol001moo`8000]oo`00
2Goo00@007oo001oo`D000Aoo`05001oogooOol0000AOol00`00Oomoo`0HOol00`00Oomoo`0IOol3
00000goo001oo`1SOol01000Oomoogoo10000Woo00<007ooOol00goo0P001Goo00<007ooOol05Goo
0`003Goo000:Ool3000:Ool00`00Ool0000COol00`00Oomoo`0HOol00`00Oomoo`0FOol20004Ool0
0`00Oomoo`1COol4000;Ool20002Ool30003Ool00`00Oomoo`04Ool00`00Oomoo`03Ool2000EOol0
0`00Ool0000>Ool000Yoo`03001oogoo00]oo`8001=oo`03001oogoo01Uoo`03001oogoo019oo`<0
00Ioo`03001oogoo04ioo`D000Aoo`03001oogoo00Qoo`03001oogoo00@000=oo`03001oogoo00Ao
o`03001oogoo00=oo`03001oo`00019oo`800003Ool007oo00ioo`0067oo00<007oo00004goo00<0
07ooOol06Goo00<007ooOol03Woo0`002Goo00<007ooOol0BWoo10002Woo00<007ooOol01goo00<0
07oo00000P0000Eoo`00Oomoo`0000Moo`8000Aoo`04001oogoo000@Ool00`00Oomoo`02000?Ool0
01Uoo`03001oo`00019oo`03001oogoo01Yoo`03001oogoo00Qoo`D000aoo`03001oogoo04Uoo`03
001oogoo00eoo`03001oogoo00Ioo`04001oo`000002Ool01000Oomoo`001goo00<007oo00000goo
00D007ooOomoo`0000eoo`80009oo`80011oo`006Goo00@007ooOol0019oo`03001oogoo01Yoo`03
001oogoo00Aoo`<0015oo`03001oogoo04Qoo`03001oogoo00moo`03001oogoo00Eoo`<000=oo`04
001oogoo0006Ool01000Oomoo`000goo00<007ooOol00Woo00<007ooOol02Goo00L007ooOomoo`00
Ool0000@Ool001Yoo`03001oo`00009oo`03001oogoo00eoo`03001oogoo01]oo`03001oogoo00<0
01Aoo`03001oogoo04Moo`03001oogoo015oo`03001oogoo00Aoo`8000Eoo`03001oo`0000Ioo`05
001oogooOol00003Ool00`00Oomoo`02Ool00`00Oomoo`07Ool01`00Oomoogoo001oo`00015oo`00
6goo0P000Woo00<007ooOol03Woo00<007ooOol06Woo0`005goo00<007ooOol0AWoo00<007ooOol0
4goo00<007ooOol010001Woo00<007oo00001Woo00@007ooOomoo`80009oo`03001oogoo00=oo`80
00Moo`06001oogoo001oo`004Woo000KOol20002Ool2000?Ool00`00Oomoo`0HOol3000IOol00`00
Oomoo`15Ool00`00Oomoo`0BOol50003Ool00`00Oomoo`04Ool30006Ool01000Oomoo`0017oo00<0
07ooOol01Goo00<007ooOol017oo0`000Woo00<007ooOol047oo000LOol01@00Ool007oo000047oo
00<007ooOol04Goo1P0000=oo`00Ool06Goo00<007ooOol0A7oo00<007ooOol04Goo0P000goo00<0
07ooOol00Woo00<007ooOol01Goo00<007oo00000P000goo00<007oo00001Goo00<007ooOol01Woo
0P0017oo00D007ooOomoo`0001=oo`0077oo00D007oo001oo`00011oo`03001oogoo00]oo`H000Mo
o`03001oogoo00=oo`/000Yoo`8000=oo`03001oogoo00]oo`8002Qoo`8000Moo`03001oogoo019o
o`05001oogooOol00005Ool00`00Oomoo`04Ool20004Ool50005Ool2000:Ool00`00Oomoo`020003
Ool00`00Oomoo`0AOol001aoo`<0009oo`03001oogoo00eoo`03001oogoo00Yoo`03001oo`0000]o
o`03001oogoo00=oo`03001oogoo00Moo`03001oogoo00Yoo`04001oo`00000=Ool01000Ool00000
9Goo00<007oo00001Woo00<007ooOol04goo00D007ooOomoo`0000Eoo`03001oogoo00Aoo`8000Mo
o`8000Aoo`03001oogoo00]oo`800003Ool007oo008001Aoo`0077oo0P000goo00<007ooOol03Woo
00<007ooOol01goo0P000Woo00<007ooOol02Goo00<007ooOol00Woo00<007oo00000`001Woo00<0
07ooOol02Woo0P003goo00<007ooOol00P001Woo00@007oo000000=oo`H000moo`H000=oo`03001o
ogoo01Aoo`04001oogoo0006Ool20004Ool20007Ool30003Ool00`00Oomoo`0;Ool00`00Oomoo`03
000FOol000Uoo`/000Qoo`8000Aoo`03001oogoo00eoo`03001oogoo00Ioo`03001oogoo009oo`03
001oogoo00Uoo`04001oogooOol30004Ool300001Goo000007oo00002Woo10003goo00@007ooOomo
o`8000Aoo`05001oogooOol00002Ool00`00Oomoo`03Ool50005Ool5000017oo0000000017oo00<0
07ooOol05Goo00@007ooOol000Ioo`03001oogoo009oo`03001oo`0000Ioo`04001oo`000002Ool0
0`00Oomoo`0;Ool6000GOol000Uoo`03001oogoo00Moo`03001oogoo00Ioo`8000Aoo`03001oogoo
00ioo`03001oogoo00=oo`8000Eoo`03001oogoo00Qoo`03001oogoo00<000Uoo`H000Qoo`8000=o
o`03001oogoo00@000Uoo`03001oogoo009oo`80009oo`8000=oo`04001oogoo0008Ool00`00Oomo
o`05Ool40006Ool00`00Oomoo`0FOol01000Oomoo`001Woo00<007ooOol00Woo0P0017oo0`000Woo
00@007oo000000eoo`8000=oo`8001Moo`002Goo00<007ooOol027oo00<007ooOol01Goo00<007oo
Ool00goo00<007ooOol03Woo00<007ooOol00Woo00<007ooOol01Goo00<007ooOol027oo0`0000=o
o`00Ool02goo1P001Goo0P001Goo00<007oo00000goo1@001Goo1`000Woo0P000goo0P0000=oo`00
Ool01Goo00<007ooOol01Goo1P0017oo00<007ooOol067oo10001Goo00H007ooOomoo`00Ool50005
Ool00`00Ool0000COol00`00Oomoo`0FOol000Qoo`03001oogoo00Yoo`03001oo`0000Aoo`03001o
ogoo00=oo`8000ioo`03001oogoo009oo`03001oogoo00Ioo`03001oogoo00Qoo`04001oogoo000;
Ool20004Ool500000goo00000002Ool70008Ool700000goo001oo`04Ool00`00Ool00003Ool20000
0goo001oo`04Ool00`00Ool000060002Ool00`00Oomoo`0200000goo001oo`0JOol20002Ool00`00
Oomoo`02Ool00`00Oomoo`040009Ool30008Ool<000HOol000Qoo`03001oogoo00]oo`8000=oo`03
001oogoo009oo`80011oo`03001oogoo009oo`<000Moo`03001oogoo00Yoo`03001oogoo00Ioo`<0
00Moo`80009oo`D000Ioo`03001oogoo00eoo`<000Aoo`03001oo`0000Aoo`800003Ool007oo00h0
00Eoo`03001oogoo01Yoo`05001oogooOol00004Ool30002Ool00`00Oomoo`08Ool00`00Ool00006
Ool2000:Ool00`00Oomoo`0GOol000Qoo`03001oogoo00]oo`8000=oo`03001oogoo0080019oo`05
001oogooOol00003Ool20005Ool00`00Oomoo`09Ool00`00Oomoo`05Ool2000<Ool00`00Ool0000:
Ool00`00Oomoo`0>Ool00`00Ool00004Ool00`00Ool00004Ool40002Ool00`00Oomoo`08000FOol2
000:Ool50005Ool00`00Oomoo`0?Ool00`00Oomoo`02Ool2000;Ool00`00Oomoo`0HOol000Moo`03
001oogoo00]oo`800007Ool007ooOol007oo00004goo00D007ooOomoo`0000Ioo`8000=oo`03001o
ogoo00Qoo`H0009oo`L000Qoo`<000Yoo`03001oogoo00Ioo`8000Ioo`D0009oo`04001oogoo0002
Ool00`00Oomoo`02Ool:0003Ool00`00Oomoo`0COol01000Ool000001goo00@007oo000000Moo`03
001oogoo011oo`04001oogoo000<Ool00`00Oomoo`0IOol000Moo`03001oogoo00Yoo`03001oo`00
009oo`@001Aoo`04001oo`000009Ool01000Oomoo`0047oo1@0017oo1@000Woo00<007oo00000P00
1Woo1`001Goo00@007oo001oo`D0009oo`05001oo`00Ool00002Ool30006Ool60006Ool00`00Oomo
o`0DOol00`00Oomoo`020004Ool00`00Ool000050004Ool00`00Oomoo`0@Ool3000=Ool00`00Oomo
o`0IOol000Moo`03001oogoo00Uoo`05001oogoo001oo`03000FOol3000;Ool3000BOol30008Ool0
0`00Oomoo`020002Ool70004Ool01000Oomoo`000goo00<007oo00000P000goo0P000goo00@007oo
001oo`@000Eoo`H00003Ool007oo00Ioo`03001oogoo01Aoo`05001oogooOol00002Ool00`00Ool0
000:Ool00`00Oomoo`0@Ool00`00Oomoo`0<Ool00`00Oomoo`0JOol000Ioo`03001oogoo00Uoo`03
001oogoo00<001Qoo`<000ioo`80015oo`03001oo`0000Uoo`<000=oo`<000Qoo`03001oogoo00<0
0003Ool007oo009oo`80009oo`8000=oo`03001oo`0000`0009oo`04001oo`000008Ool00`00Oomo
o`0>Ool70003Ool4000;Ool3000MOol2000MOol000Ioo`03001oogoo00Qoo`@00003Ool007oo01Qo
o`D000ioo`03001oogoo00ioo`H000Moo`800003Ool00000009oo`03001oogoo00Ioo`04001oogoo
0002Ool00`00Oomoo`03Ool60003Ool00`00Oomoo`020004Ool00`00Oomoo`04Ool00`00Oomoo`02
0007Ool00`00Oomoo`06Ool200000goo000000030003Ool01000Oomoo`000goo10002goo0`006goo
0P007goo0006Ool00`00Oomoo`07Ool20003Ool00`00Oomoo`0LOol4000<Ool2000>Ool20004Ool5
0002Ool30005Ool00`00Oomoo`05Ool40002Ool30005Ool:0002Ool01000Ool000001goo00<007oo
Ool01@000goo0`001goo00@007oo000000Ioo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo
00Qoo`04001oogoo000HOol2000QOol000Moo`03001oogoo00]oo`03001oogoo01eoo`03001oo`00
008000aoo`8000Uoo`D000Qoo`03001oo`00008000Moo`03001oogoo00Ioo`03001oo`0000D000Ao
o`<00004Ool000000002Ool01@00Oomoogoo00002Goo00<007ooOol00P000Woo1`001Woo00D007oo
Ool007oo0080009oo`8000Ioo`d000=oo`8000=oo`03001oogoo01Aoo`03001oogoo025oo`0027oo
00<007ooOol02Goo0P0087oo00D007ooOomoo`0000eoo`03001oogoo00Ioo`03001oo`00008000Qo
o`03001oo`00009oo`03001oogoo00Eoo`03001oo`00008000=oo`04001oo`000003Ool20003Ool0
1000Ool000000goo300017oo00@007ooOomoo`8000=oo`H000Aoo`D000=oo`8000Ioo`@000Ioo`80
009oo`06001oogoo001oo`0017oo00<007ooOol04Goo0P0097oo0009Ool00`00Oomoo`07Ool00`00
Oomoo`0QOol00`00Oomoo`0?Ool800000goo000000040005Ool00`00Ool00003Ool00`00Oomoo`05
Ool900000goo00000007Ool00`00Ool00002Ool30003Ool00`00Oomoo`05Ool00`00Oomoo`03Ool0
1@00Oomoo`00Ool00`0000Moo`00Oomoo`00Ool00002Ool01000Oomoogoo20000goo0P0000Aoo`00
000000Qoo`05001oo`00Ool00002Ool20004Ool00`00Oomoo`0?Ool00`00Oomoo`0TOol000Yoo`03
001oogoo00Aoo`80029oo`800003Ool007oo01Ioo`H0009oo`<0009oo`03001oo`0000Aoo`03001o
ogoo00D000Eoo`<00003Ool007oo00Moo`8000Ioo`800003Ool007oo00Ioo`03001oogoo00=oo`03
001oo`0000@000=oo`800006Ool00000001oo`000goo00@007ooOomoo`L000=oo`<000Uoo`<000=o
o`03001oogoo00Aoo`03001oogoo00ioo`03001oogoo02Aoo`002goo00@007ooOomoo`8002Aoo`05
001oo`00Ool0000FOol500000goo001oo`03Ool;00000goo0000000:Ool30008Ool00`00Oomoo`02
Ool00`00Oomoo`02Ool30007Ool00`00Oomoo`02Ool200001Goo000007oo00001Goo00<007ooOol0
0P0017oo00D007ooOomoo`00009oo`03001oogoo00=oo`05001oo`00001oo`030006Ool00`00Oomo
o`02Ool00`00Oomoo`05Ool00`00Oomoo`0>Ool00`00Oomoo`0SOol000aoo`03001oo`0002Moo`04
001oo`00000EOol300000goo00000002Ool00`00Oomoo`02Ool00`00Ool00007Ool30009Ool00`00
Oomoo`020006Ool20003Ool20006Ool20006Ool00`00Oomoo`05Ool01@00Oomoogoo00001Goo00<0
07oo00000P000Woo00<007ooOol00Woo00<007ooOol01Woo1P0027oo00<007ooOol00Woo00<007oo
Ool01Goo00<007ooOol03goo00<007ooOol08Woo000=Ool00`00Oomoo`0WOol200000goo001oo`0B
Ool50005Ool01`00Oomoogoo001oo`0000Eoo`8000=oo`03001oogoo00Ioo`04001oogooOol30003
Ool00`00Ool00002Ool00`00Ool00007Ool00`00Oomoo`04Ool00`00Ool000070003Ool00`00Oomo
o`03Ool200000goo000000020003Ool00`00Oomoo`03Ool500000goo0000000:Ool00`00Oomoo`02
Ool00`00Oomoo`04Ool00`00Oomoo`04Ool20002Ool00`00Oomoo`05Ool00`00Oomoo`0ROol003Mo
o`80009oo`8000moo`D000Qoo`06001oogoo001oo`0017oo00<007ooOol017oo00<007ooOol01Goo
00H007ooOomoo`00Ool2000027oo001oogoo001oo`00Ool20006Ool20005Ool30008Ool50005Ool0
0`00Oomoo`030003Ool00`00Oomoo`02Ool200001Woo000007oo001oo`8000Uoo`03001oogoo009o
o`8000Eoo`03001oogoo00Aoo`03001oo`00008000Qoo`80029oo`00=goo00<007oo00000goo00<0
07ooOol02goo0P0000Aoo`00000000Aoo`<0009oo`80009oo`05001oogooOol00008Ool00`00Oomo
o`04Ool00`00Oomoo`020002Ool20003Ool20002Ool20006Ool20002Ool300000goo001oo`0AOol0
0`00Oomoo`02Ool01P00Ool00000Ool0009oo`<00003Ool007oo0080009oo`8000Uoo`03001oogoo
009oo`03001oogoo00=oo`03001oogoo00Eoo`@00003Ool0000000Eoo`03001oo`00029oo`00=Woo
00D007ooOomoo`0000=oo`8000ioo`03001oo`0000@0009oo`04001oogooOol200000goo001oo`02
000:Ool00`00Oomoo`04Ool01000Ool000000goo00D007ooOomoo`00009oo`03001oo`0000Eoo`03
001oogoo008000Eoo`03001oogoo00ioo`03001oogoo00=oo`04001oogooOol60002Ool20004Ool2
0009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`06Ool40003Ool300001Goo001oogoo
00008Woo000eOol00`00Oomoo`03Ool00`00Oomoo`02Ool00`00Oomoo`0:Ool30007Ool01P00Oomo
ogoo001oo`<000eoo`03001oogoo00Aoo`800003Ool007oo009oo`04001oo`000002Ool60002Ool0
0`00Oomoo`07Ool00`00Oomoo`0>Ool00`00Oomoo`04Ool00`00Oomoo`050002Ool00`00Oomoo`03
Ool30009Ool00`00Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`04Ool=0004Ool00`00Oomoo`0O
Ool003Eoo`03001oogoo00Aoo`03001oogoo009oo`03001oogoo00Qoo`8000Uoo`04001oogoo0002
Ool4000=Ool00`00Oomoo`03Ool200000goo001oo`02Ool60002Ool01000Ool000000Woo00<007oo
Ool01goo0P003Woo00<007ooOol01Woo0`0000=oo`0000000Woo00<007ooOol00Woo0P000Woo2`00
17oo00D007ooOomoo`0000Eoo`800004Ool00000Ool20004Ool20004Ool3000POol003Aoo`03001o
ogoo00Eoo`03001oogoo00=oo`8000Ioo`<000Yoo`04001oogoo0002Ool01@00Oomoogoo00002goo
00<007ooOol017oo0P0000=oo`00Ool00goo00@007oo000000=oo`03001oogoo00<000aoo`8000ao
o`03001oogoo00Moo`H00003Ool007oo00<001=oo`80009oo`03001oogoo00<0009oo`07001oo`00
Ool007oo00000Woo1`008goo000cOol20008Ool00`00Oomoo`04Ool00`00Oomoo`02Ool01000Oomo
o`002Woo00<007oo000027oo0P0027oo00<007ooOol017oo1@001Goo1@0000=oo`00Ool010003Woo
0`0027oo0P002Woo0`000Woo0`005Woo00D007ooOol007oo008000Aoo`03001oogoo008000=oo`@0
02Qoo`00=Goo00<007ooOol01Goo00<007ooOol01Goo00@007oo0000009oo`03001oogoo00Qoo`03
001oo`0000Moo`@000Moo`03001oogoo00Aoo`80009oo`80009oo`D00003Ool007oo00L0015oo`80
00Qoo`03001oogoo00Qoo`03001oogoo0080009oo`@0019oo`03001oogoo008000Eoo`/002Yoo`00
=Woo0P001Woo00<007ooOol01Goo00D007ooOomoo`0000]oo`03001oo`0000Eoo`800003Ool00000
00Moo`03001oogoo00Aoo`04001oo`00Ool5000017oo000007oo1`000Woo0`004Woo00<007ooOol0
1Woo00<007ooOol01Woo00<007oo00000P000Woo00@007ooOomoo`@0009oo`8000=oo`<000Eoo`05
001oo`00Ool00009Ool2000_Ool003Qoo`03001oogoo00Aoo`03001oogoo00Qoo`03001oogoo00Uo
o`8000Eoo`03001oogoo008000Moo``000=oo`03001oo`00009oo`D00003Ool007oo009oo`8001=o
o`03001oogoo00=oo`80009oo`03001oogoo00Aoo`<00005Ool00000Ool00004Ool01000Oomoogoo
10001Woo00@007ooOomoo`800005Ool007ooOol00008Ool00`00Oomoo`0^Ool003Uoo`8000Aoo`03
001oogoo00Moo`03001oogoo00Yoo`8000=oo`80009oo`8000Moo`8000Aoo`H000=oo`H00004Ool0
07ooOol30003Ool00`00Ool0000BOol00`00Oomoo`03Ool00`00Ool00002Ool00`00Oomoo`02Ool2
0004Ool20006Ool00`00Oomoo`03Ool20005Ool01000Oomoogoo10000Woo00<007ooOol0=goo000k
Ool00`00Oomoo`02Ool00`00Oomoo`06Ool00`00Oomoo`0:Ool01000Oomoogoo0P000goo00<007oo
Ool01Goo0P0017oo00<007oo00000goo1@000Woo00<007ooOol00P000goo0`0000Eoo`00Oomoo`00
01=oo`05001oogooOol00003Ool01000Oomoo`000Woo0P001Goo0P001Woo00<007ooOol017oo00<0
07ooOol00`000goo00@007oo000000Aoo`03001oogoo03Ioo`00?7oo0P000Woo00<007ooOol01Goo
00<007ooOol04Goo0`001Woo0`0000Eoo`00Oomoo`00009oo`03001oogoo009oo`800003Ool007oo
009oo`800003Ool007oo009oo`800004Ool00000Ool3000BOol01@00Oomoogoo000017oo0P0000Eo
o`00001oo`0000Aoo`04001oo`000006Ool00`00Ool000020002Ool00`00Ool00005Ool01000Ool0
000017oo00<007ooOol0=Woo000nOol200000goo0000000:000@Ool40004Ool00`00Ool00002Ool3
00000goo001oo`03Ool300000goo001oo`02Ool200000goo001oo`02Ool9000BOol01000Oomoo`00
1goo00@007oo000000Aoo`05001oogooOol00003Ool50003Ool01000Ool007oo100000Moo`00Oomo
o`00Ool00004Ool00`00Oomoo`0eOol0041oo`8000Eoo`03001oogoo00=oo`03001oogoo00aoo`03
001oogoo009oo`800003Ool00000009oo`03001oogoo00@0009oo`<0009oo`04001oo`00Ool20002
Ool00`00Ool000060003Ool00`00Oomoo`0@Ool01000Oomoo`0027oo0`000goo00@007ooOomoo`80
00Ioo`03001oogoo00=oo`03001oo`0000Eoo`06001oogoo001oo`0017oo00<007ooOol0=Goo0012
Ool01@00Oomoogoo00001goo00<007ooOol04Woo00<007oo00000goo00@007oo001oo`800004Ool0
07oo0004Ool40003Ool01000Oomoogoo0P0000=oo`0000000goo00<007ooOol047oo00@007ooOol0
00Uoo`03001oogoo009oo`07001oogooOol007oo00000goo0P001goo00<007oo000017oo00<007oo
0000100017oo00<007ooOol0=7oo0013Ool200000goo001oo`07Ool2000:Ool20008Ool00`00Oomo
o`02Ool200000goo000000030006Ool20003Ool00`00Oomoo`02Ool20003Ool01000Oomoo`004goo
0P002Goo00<007ooOol00goo00L007ooOomoo`00Ool00002Ool00`00Oomoo`08Ool20003Ool01@00
Oomoogoo00000Woo1P00=Woo0015Ool00`00Oomoo`09Ool00`00Oomoo`04Ool300000goo001oo`07
Ool00`00Oomoo`03Ool300000goo001oo`07Ool20003Ool00`00Oomoo`02Ool20003Ool01000Oomo
o`004goo0P002Goo00<007ooOol00goo00@007ooOol0009oo`03001oo`0000aoo`80009oo`05001o
ogooOol00004Ool00`00Oomoo`02000eOol0059oo`03001oogoo00@000=oo`03001oogoo00Moo`0;
001oogooOol007oo001oo`00Ool00006Ool00`00Ool00003Ool00`00Oomoo`0200000goo001oo`02
Ool01000Oomoo`004goo00<007ooOol027oo00<007ooOol00goo00@007ooOol000=oo`03001oogoo
00aoo`04001oo`000003Ool00`00Oomoo`02Ool00`00Oomoo`0gOol005=oo`<000=oo`D000Qoo`06
001oogooOol007oo0P000goo00<007ooOol00Woo00@007ooOol000=oo`<000=oo`03001oogoo009o
o`03001oo`0001ioo`<000=oo`04001oogoo000COol01000Ool000000Woo00<007ooOol00Woo00<0
07ooOol0=goo001FOol00`00Oomoo`03Ool00`00Ool000020005Ool01000Oomoogoo0P0000=oo`00
Ool00goo00<007ooOol00P000goo1@0017oo00<007ooOol00Woo00<007oo00006Goo1P0000=oo`00
Ool00goo0P005goo0P0000=oo`0000000goo00<007ooOol0=goo001GOol00`00Oomoo`02Ool00`00
Oomoo`02Ool00`00Oomoo`02Ool00`00Oomoo`020002Ool01000Oomoogoo0`000goo0P0000=oo`00
Ool00goo00D007ooOomoo`0000Eoo`@000Uoo`h000Aoo`04001oogoo0004Ool2000HOol30004Ool0
0`00Oomoo`0gOol005Qoo`04001oogoo0006Ool01000Oomoogoo3P001Goo0P001Goo0P0000=oo`00
Ool01Goo1@001goo00<007oo00000`0037oo00@007ooOol000Aoo`8001Uoo`8000Aoo`03001oogoo
03Moo`00F7oo00@007ooOol000Moo`03001oogoo00Qoo`03001oogoo00P0009oo`03001oogoo00Ao
o`8000Ioo`03001oo`00009oo`<000=oo`D000ioo`800003Ool007oo00=oo`04001oo`00000HOol2
0002Ool00`00Oomoo`0hOol005Uoo`03001oo`0000Qoo`03001oogoo00Moo`H0009oo`03001oo`00
00=oo`8000Aoo`03001oo`0000Eoo`04001oogoo0003Ool500000goo001oo`0AOol20003Ool20002
Ool3000FOol300000goo001oo`0iOol005Yoo`8000Uoo`03001oogoo00Uoo`@0009oo`8000Eoo`80
0003Ool007oo009oo`05001oogooOol00003Ool00`00Oomoo`02Ool5000COol00`00Ool000020002
Ool01P00Oomoo`00Ool000eoo`8000Ioo`03001oo`00008003Yoo`00Fgoo00<007ooOol027oo00<0
07ooOol00goo200000Aoo`00Oomoo`8000Ioo`03001oogoo009oo`05001oogooOol00004Ool00`00
Oomoo`02Ool2000EOol00`00Oomoo`020003Ool01@00Oomoo`00Ool00P002Woo00<007ooOol00P00
17oo0P0000=oo`000000>Woo001WOol50006Ool02@00Oomoogoo001oo`00Ool00005Ool30002Ool0
1@00Oomoogoo00001Goo00D007ooOomoo`0001Ioo`03001oo`00009oo`80009oo`04001oogoo0002
Ool30006Ool00`00Oomoo`03Ool20002Ool00`00Ool00002000jOol0079oo`8000=oo`800003Ool0
07oo00=oo`07001oogooOol007oo00000Woo00<007ooOol017oo00@007ooOol001Moo`8000Eoo`80
0005Ool007ooOol00004Ool30002Ool00`00Oomoo`06Ool00`00Ool00002000lOol0079oo`03001o
o`0000=oo`04001oogoo0003Ool00`00Oomoo`02Ool20002Ool00`00Oomoo`05Ool00`00Ool0000G
Ool00`00Oomoo`06Ool00`00Ool00002Ool20005Ool30009Ool3000mOol0079oo`04001oogoo0002
Ool01000Oomoo`000Woo00<007ooOol017oo1@001goo00<007ooOol087oo00<007oo00000goo0P00
0Woo1P001goo1@00>goo001bOol01`00Oomoogoo001oo`0000=oo`03001oo`0000Moo`D002Yoo`X0
00]oo`@00003Ool0000003Yoo`00Mgoo0P0017oo00@007oo000000Eoo`<0009oo`D002Moo`03001o
ogoo00D000Yoo`@00004Ool00000Ool2000hOol007Qoo`03001oogoo009oo`800003Ool007oo00Ao
o``002Ioo`03001oogoo00H000Moo`H00003Ool007oo009oo`03001oogoo03Eoo`00N7oo00@007oo
Oomoo`<0009oo`03001oogoo009oo`03001oo`0000Aoo`03001oogoo02Uoo`@00003Ool000000080
00=oo`800003Ool0000000@00003Ool007oo00=oo`8003Eoo`00N7oo00<007ooOol00P0000=oo`00
Ool00`000goo100017oo00<007ooOol0:Goo0P0000Aoo`00Ool000Aoo`05001oogoo001oo`040002
Ool00`00Oomoo`04Ool00`00Oomoo`0bOol007Qoo`04001oogoo0003Ool40005Ool00`00Ool00005
000YOol01@00Oomoo`00Ool00P0017oo00<007oo00000P000Woo1@001Woo00<007ooOol0<Woo001h
Ool01000Ool007oo1@000Woo00<007ooOol00Woo00<007ooOol017oo0P009goo00<007ooOol00Woo
00<007oo000017oo0P0000=oo`0000000Woo0`0000=oo`00Ool01Goo00<007ooOol0<Woo001hOol4
0003Ool20002Ool20003Ool00`00Oomoo`05Ool3000TOol00`00Oomoo`04Ool@00000goo001oo`04
Ool00`00Oomoo`0cOol007Qoo`8000Aoo`<000=oo`80009oo`03001oogoo00H002Eoo`8000Ioo`80
00=oo`04001oo`000003Ool00`00Ool000030005Ool00`00Oomoo`0cOol007eoo`04001oo`000003
Ool01000Ool007oo0`0000=oo`000000:Woo0P001Woo00<007oo00000goo00P007ooOomoo`00Ool0
07oo0P001Goo00<007ooOol0<goo001lOol00`00Oomoo`0700000goo001oo`03000^Ool30004Ool0
0`00Oomoo`02Ool01000Oomoogoo2@0000=oo`00Ool0=Goo001kOol60007Ool00`00Oomoo`0bOol2
0007Ool00`00Oomoo`050005Ool5000cOol0081oo`03001oogoo03aoo`03001oogoo00Aoo`@00004
Ool00000Ool30003Ool01000Oomoogoo0P00<Goo0020Ool00`00Oomoo`0lOol00`00Oomoo`03Ool2
0003Ool00`00Ool00004Ool30003Ool00`00Oomoo`0aOol0081oo`03001oogoo03aoo`03001oogoo
00=oo`05001oogooOol00002Ool00`00Oomoo`04Ool01000Ool00000=7oo0020Ool00`00Oomoo`0m
Ool00`00Oomoo`02Ool01000Oomoo`000goo0P001Woo00<007ooOol0=7oo0030Ool00`00Oomoo`02
Ool00`00Ool00004Ool00`00Oomoo`03Ool2000gOol00<1oo`03001oogoo009oo`8000Eoo`03001o
ogoo009oo`03001oogoo03Moo`00`Goo00D007ooOomoo`0000Ioo`04001oogooOol2000iOol00<5o
o`03001oogoo00Qoo`03001oogoo00=oo`03001oogoo03Ioo`00`Goo00<007ooOol027oo0P001Goo
00<007ooOol0=Goo0032Ool00`00Oomoo`07Ool00`00Oomoo`05Ool00`00Oomoo`0dOol00<9oo`03
001oogoo00Moo`03001oogoo00Ioo`03001oogoo03=oo`00`Woo00<007ooOol01goo00<007ooOol0
1goo00<007ooOol0<Woo002hOol00`00Oomoo`08Ool00`00Oomoo`06Ool00`00Oomoo`08Ool00`00
Oomoo`0aOol00;Qoo`03001oogoo00Uoo`03001oogoo00Eoo`8000Yoo`03001oogoo031oo`00]goo
0P0037oo00<007ooOol017oo00<007ooOol02Goo00<007ooOol0<7oo002fOol2000>Ool00`00Oomo
o`03Ool00`00Oomoo`08Ool00`00Oomoo`0aOol00;9oo`@00003Ool0000000<000=oo`8000=oo`@0
00Aoo`03001oogoo00Qoo`03001oogoo035oo`00/goo0P000Woo00<007oo00001Goo0P001Woo0P00
0goo00<007ooOol01goo00<007ooOol0<Woo002cOol01@00Oomoogoo00000Woo00<007ooOol02Woo
0`000Woo0`001goo00<007ooOol0<Woo002bOol20003Ool01@00Oomoogoo000027oo100017oo00<0
07ooOol01goo00<007ooOol0<Woo002`Ool200001goo001oogoo001oo`00009oo`03001oogoo00Io
o`8000Ioo`03001oogoo00Ioo`03001oogoo03=oo`00[goo00<007ooOol00P000Woo00<007ooOol0
0P0027oo1@0017oo00<007ooOol01Woo00<007ooOol0<goo002^Ool00`00Oomoo`05Ool60005Ool2
0009Ool00`00Oomoo`05Ool00`00Oomoo`0dOol00:aoo`8000=oo`H000Eoo`D000]oo`03001oogoo
00Eoo`03001oogoo03Aoo`00Zgoo00<007ooOol00`001Woo1@0047oo0P001goo00<007ooOol01Goo
0P00;7oo002ZOol4000>Ool3000=Ool00`00Oomoo`06Ool00`00Oomoo`03Ool200000goo001oo`0[
Ool00:Uoo`8001Aoo`8000]oo`03001oogoo00Moo`03001oogoo008000Aoo`03001oogoo02Uoo`00
`Goo0P002Goo00<007ooOol027oo0P001goo00<007ooOol0:7oo0033Ool00`00Oomoo`06Ool00`00
Oomoo`07Ool200000goo00000006Ool00`00Oomoo`0WOol00<Aoo`8000Ioo`8000Moo`06001oo`00
001oo`001goo00<007ooOol09Woo0036Ool00`00Oomoo`03Ool00`00Oomoo`05Ool3000017oo001o
o`0027oo00<007ooOol09Goo0037Ool00`00Oomoo`02Ool00`00Oomoo`03Ool20002Ool00`00Oomo
o`020009Ool00`00Oomoo`0TOol00<Qoo`05001oogooOol00004Ool00`00Ool00003Ool01000Ool0
00002Woo00<007ooOol08goo0039Ool01000Oomoo`0017oo00<007oo00000goo00@007ooOol000Yo
o`03001oogoo02=oo`00bWoo00@007oo000000=oo`03001oo`0000Aoo`800003Ool007oo00Moo`03
001oogoo02Aoo`00bgoo0P001Goo0P001Goo00<007oo00001goo00<007ooOol09Goo003<Ool00`00
Oomoo`03Ool20005Ool01000Oomoo`001Goo00<007ooOol09Woo003<Ool20004Ool20005Ool20002
Ool00`00Oomoo`02Ool00`00Oomoo`0VOol00<]oo`<000Eoo`8000Aoo`<00003Ool007oo009oo`03
001oogoo02Moo`00c7oo0`0017oo0P001Woo00H007ooOol007oo000ZOol00<aoo`800005Ool00000
001oo`020007Ool01000Oomoo`00:goo003<Ool01000Ool000000Woo0`001goo0`00;7oo002nOol3
0003Ool30005Ool00`00Oomoo`020003Ool00`00Oomoo`06Ool00`00Ool0000[Ool00;moo`03001o
ogoo00Eoo`03001oogoo009oo`04001oogooOol2000;Ool01000Oomoo`00:Woo002oOol00`00Oomo
o`05Ool00`00Oomoo`02Ool30002Ool00`00Oomoo`09Ool01@00Oomoogoo0000:Goo002oOol00`00
Oomoo`02Ool30005Ool00`00Oomoo`02Ool2000;Ool01000Oomoo`00:Goo002oOol00`00Oomoo`02
Ool00`00Oomoo`05Ool01P00Oomoogoo001oo`8000Yoo`05001oogooOol0000XOol00;ioo`8000Ao
o`@000Aoo`03001oogoo00<000eoo`05001oogooOol0000WOol00<aoo`@000moo`05001oogooOol0
000WOol00<aoo`80015oo`03001oogoo009oo`03001oogoo02Aoo`00bgoo0P004Goo00<007ooOol0
17oo00<007ooOol08goo003:Ool00`00Ool0000AOol00`00Oomoo`02Ool3000UOol00<aoo`03001o
ogoo00moo`09001oogooOol007oo001oo`0002Aoo`00c7oo00<007ooOol03Woo00L007ooOomoo`00
Ool00003Ool00`00Oomoo`0QOol00<aoo`8000moo`04001oo`000002Ool01000Oomoo`0097oo003<
Ool00`00Oomoo`0>Ool20003Ool01000Oomoo`009Goo003<Ool00`00Oomoo`0=Ool20004Ool00`00
Ool0000VOol00<aoo`03001oogoo00eoo`03001oogoo00=oo`8002Moo`00c7oo00<007ooOol04Woo
0P00:7oo003<Ool2000COol00`00Oomoo`0WOol00<aoo`03001oogoo015oo`03001oogoo02Qoo`00
c7oo00<007ooOol0?7oo003<Ool00`00Oomoo`0lOol00<aoo`03001oogoo03aoo`00c7oo0P00?Goo
0000\
\>"],
  ImageRangeCache->{{{0, 266.25}, {189.875, 0}} -> {-19.9843, -1.56061, 
  0.0977955, 0.0977955}}]
}, Open  ]],

Cell[TextData[{
  "The heart of ",
  Cell[BoxData[
      \(TraditionalForm\`RandomWalk\)]],
  " is the realisation that"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`FoldList[Plus, a, {b, c, d}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{a, a + b, a + b + c, a + b + c + d}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "forms the ",
  StyleBox["cumulative sum",
    FontSlant->"Italic"],
  " (see ",
  ButtonBox["FoldList",
    ButtonData:>"FoldList",
    ButtonStyle->"Hyperlink"],
  " above).  This syntax trivially generalises to more dimensions:"
}], "Text",
  CellTags->{"Syntax", "cumulative sum"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`FoldList[Plus, {a, b}, {{c, d}, {e, f}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {"a", "b"},
            {\(a + c\), \(b + d\)},
            {\(a + c + e\), \(b + d + f\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Find the last point reached (using ",
  Cell[BoxData[
      \(TraditionalForm\`Last\)]],
  ") for ",
  Cell[BoxData[
      \(TraditionalForm\`RandomWalk[100]\)]],
  ". Compute the length of this vector (",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", the distance from the origin)  using ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftDoubleBracketingBar]\ \
\[RightDoubleBracketingBar]\)]],
  ". Repeat this operation 100 times (using ",
  Cell[BoxData[
      \(TraditionalForm\`Table\)]],
  ") to produce a list of lengths. Compute the mean and standard deviation  \
of these lengths (look up ",
  Cell[BoxData[
      \(TraditionalForm\`Mean\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`StandardDeviation\)]],
  ")."
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Generalise ",
  Cell[BoxData[
      \(TraditionalForm\`RandomStep\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`RandomWalk\)]],
  " works in 3 dimensions. Show a graphic of ",
  Cell[BoxData[
      \(TraditionalForm\`RandomWalk[500]\)]],
  ". (",
  StyleBox["Hint",
    FontSlant->"Italic"],
  ": you need to replacing ",
  Cell[BoxData[
      \(TraditionalForm\`Graphics\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`Graphics3D\)]],
  " and delete the other options  in the above code)"
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Pattern-matching and Replacement Rules"
}], "Section"],

Cell[TextData[{
  "When simplifying expressions by hand one naturally tends to apply  \
transformation rules as required.  In addition, humans are very good at  \
pattern-recognition.  ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", includes replacement rules and ",
  StyleBox["pattern-matching",
    FontSlant->"Italic"],
  " operations in a natural way."
}], "Text",
  CellTags->{"replacement rules", "pattern-matching"}],

Cell[TextData[
"Pattern-matching is a simple and elegant way to write programs, often  \
without requiring functional or procedural methods \[LongDash] although these \
can be also used. It is probably best explained by giving a number of   \
examples. Consider the replacement rule:"], "Text"],

Cell[BoxData[
    \(TraditionalForm\`Clear[x, y, z]\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{x, y, z} /. x \[Rule] 2\ x\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{2\ x, y, z}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\` /. \)]],
  " shorthand denotes the infix form of the ",
  Cell[BoxData[
      \(TraditionalForm\`ReplaceAll\)]],
  " operator, whilst ",
  Cell[BoxData[
      \(TraditionalForm\` \[Rule] \)]],
  " is the ",
  StyleBox["infix",
    FontSlant->"Italic"],
  " form of ",
  Cell[BoxData[
      \(TraditionalForm\`Rule\)]],
  ". In this case there was only one (exact) match."
}], "Text",
  CellTags->{"Infix operator", "ReplaceAll", "Rule", "Shorthand"}],

Cell[TextData[{
  "If we introduce a generic variable ",
  Cell[BoxData[
      \(TraditionalForm\`x_\)]],
  ":"
}], "Text",
  CellTags->{"Generic variable", "Blank", "_"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{x, y, z} /. x_ \[Rule] 2\ x\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{2\ x, 2\ y, 2\ z}\)], "Output"]
}, Open  ]],

Cell[TextData[{

  "we see that it matches ",

  Cell[BoxData[

      \(TraditionalForm\`x\)]],

  ", ",

  Cell[BoxData[

      \(TraditionalForm\`y\)]],

  ", and ",

  Cell[BoxData[

      \(TraditionalForm\`z\)]],

  ". "

}], "Text"],

Cell[TextData[

"In the following sub-sections a number of examples \[LongDash] ranging from \

elementary to quite sophisticated \[LongDash] are used to illustrate various \

aspects of pattern-matching and replacement rules.  "], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Predicates"
}], "Subsection"],

Cell[TextData[{
  "Part of the power of pattern-matching lies in its ability to compactly   \
represent more complicated patterns. Also, one can combine pattern-matching \
with ",
  StyleBox["predicate",
    FontSlant->"Italic"],
  " or ",
  StyleBox["testing operators",
    FontSlant->"Italic"],
  " using ",
  Cell[BoxData[
      \(TraditionalForm\` /; \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`?\)]],
  "."
}], "Text",
  CellTags->{
  "Infix operator", "Shorthand", "Condition", "Pattern-matching", "?", 
    "Predicates"}],

Cell[TextData[{
  "For example, here we convert all numbers less than ",
  Cell[BoxData[
      \(TraditionalForm\`3\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`0\)]],
  ":"
}], "Text",
  CellTags->"Tests"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{1, 2, 3, 4, 5} /. x_ /; x < 3 \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{0, 0, 3, 4, 5}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Set all numbers in the list ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, 3, 4, 5}\)]],
  " that are greater than 2 to 0"
}], "BeginEndQuestion"],

Cell[TextData[{
  "By convention, names of built-in testing ",
  StyleBox["predicates",
    FontSlant->"Italic"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " end in ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " (there are a few other built-in functions whose names end in ",
  Cell[BoxData[
      \(TraditionalForm\`Q\)]],
  " that are not predicates). "
}], "Text",
  CellTags->{"Predicates", "ReadProtected"}],

Cell[TextData[{
  "In general, built-in predicates return the Boolean values ",
  Cell[BoxData[
      \(TraditionalForm\`True\)]],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`False\)]],
  ". For example,"
}], "Text",
  CellTags->"Boolean"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`VectorQ[{a, b}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here we use ",
  Cell[BoxData[
      \(TraditionalForm\`\(?PrimeQ\)\)]],
  " (this is ",
  StyleBox["not",
    FontSlant->"Italic"],
  " finding out information on ",
  Cell[BoxData[
      \(TraditionalForm\`PrimeQ\)]],
  " \[LongDash] instead it is a syntax for applying a test) to identify all   \
prime numbers in a list and then use a replacement rule to square them:"
}], "Text",
  CellTags->"PrimeQ"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`{1, 2, 3, 4, 5} /. x_?PrimeQ \[Rule] x\^2\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{1, 4, 9, 4, 25}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Zero out all odd numbers in the list ",
  Cell[BoxData[
      \(TraditionalForm\`{1, 2, 3, 4, 5}\)]]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "ReplaceList"
}], "Subsection"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`ReplaceList\)]],
  " is a very useful pattern-matching tool. Consider:"
}], "Text",
  CellTags->"pattern-matching"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`ReplaceList[{a, b, c}, {x_, y_} \[RuleDelayed] {{x}, {y}}]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here, the pattern ",
  Cell[BoxData[
      \(TraditionalForm\`{x_, y_}\)]],
  " cannot match the expression ",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c}\)]],
  " so we get an empty list as output. However, if the pattern ",
  Cell[BoxData[
      \(TraditionalForm\`_\)]]
}], "Text",
  CellTags->{"Blank", "_"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?_\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"_ or Blank[ ] is a pattern object that can stand for any Mathematica \
expression. _h or Blank[h] can stand for any expression with head h."\)], 
  "Print"]
}, Open  ]],

Cell[TextData[{
  "is replaced by the pattern",
  StyleBox[" ", "Input"],
  Cell[BoxData[
      \(TraditionalForm\`__\)]]
}], "Text",
  CellTags->{"BlankSequence", "__"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?__\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"__ (two _ characters) or BlankSequence[ ] is a pattern object that can \
stand for any sequence of one or more Mathematica expressions. __h or \
BlankSequence[h] can stand for any sequence of one or more expressions, all \
of which have head h."\)], "Print"]
}, Open  ]],

Cell["\<\
in one of the pattern variables, then there is one possible match:\
\>", "Text",
  CellTags->"Pattern variables"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`ReplaceList[{a, b, c}, {x__, y_} \[RuleDelayed] {{x}, {y}}]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\({a, b}\), \({c}\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell["The general pattern involving ___", "Text",
  CellTags->{"BlankNullSequence", "___"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?___\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"___ (three _ characters) or BlankNullSequence[ ] is a pattern object \
that can stand for any sequence of zero or more Mathematica expressions. ___h \
or BlankNullSequence[h] can stand for any sequence of expressions, all of \
which have head h."\)], "Print"]
}, Open  ]],

Cell["takes into account all possible matches:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`ReplaceList[{a, b, c}, {x___, y___} \[RuleDelayed] {{x}, {y}}]\)], 
  "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"(", GridBox[{
            {\({}\), \({a, b, c}\)},
            {\({a}\), \({b, c}\)},
            {\({a, b}\), \({c}\)},
            {\({a, b, c}\), \({}\)}
            }], ")"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use this idea to construct a list of all two-element subsets of the list \
",
  Cell[BoxData[
      \(TraditionalForm\`{a, b, c, d}\)]],
  ". "
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Number Puzzle"
}], "Subsection"],

Cell["For the sequence", "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(seq = {6, 44, 30, 15, 24, 12, 33, 23, 18, 8};\)\)], 
  "Input"],

Cell[TextData[{
  "it is easy to construct a (user-defined) pattern which uses a test (in  \
this case ",
  Cell[BoxData[
      \(TraditionalForm\`Equal\)]],
  ") to find (the first) four numbers totalling to ",
  Cell[BoxData[
      \(TraditionalForm\`100\)]],
  ":"
}], "Text",
  CellTags->{"Tests", "User-defined rules", "Pattern-matching"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm
    \`seq /. {___, a_, ___, b_, ___, c_, ___, d_, ___} \[RuleDelayed] 
        {a, b, c, d} /; a + b + c + d == 100\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`{44, 15, 23, 18}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Find three numbers in ",
  Cell[BoxData[
      \(TraditionalForm\`seq\)]],
  " whose square sums to ",
  Cell[BoxData[
      \(TraditionalForm\`1269\)]]
}], "BeginEndQuestion"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  Cell[BoxData[
      \(TraditionalForm\`ReplaceList\)]],
  " to find ",
  StyleBox["all",
    FontSlant->"Italic"],
  " sets of four numbers that total to ",
  Cell[BoxData[
      \(TraditionalForm\`100\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`seq\)]],
  "."
}], "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Association"
}], "Section"],

Cell[TextData[{

  "The Object-Oriented Programming (OOP) idea of association is very powerful \

 and incorporated into the ",

  StyleBox["Mathematica ",

    FontSlant->"Italic"],

  "language in a natural way. Often, a  definition or rule should be \

associated with a particular object rather than with a general operation."

}], "Text",

  CellTags->{"Object-Oriented Programming", "Association"}],

Cell["If one enters:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`g[a_] + g[b_] := g[a + b]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \(SetDelayed::"write"\), \( : \ \), 
        "\<\"Tag \\!\\(TraditionalForm\\`Plus\\) in \
\\!\\(TraditionalForm\\`\\(\\(g(a_)\\) + \\(g(b_)\\)\\)\\) is \
Protected.\"\>"}], TraditionalForm]], "Message"],

Cell[BoxData[
    \(TraditionalForm\`$Failed\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "an error message is generated indicating that Plus\[LongDash]the top-level \
 operator on the left-hand side\[LongDash]is a built-in protected operator \
and  that this input is effectively trying to attach a rule to ",
  Cell[BoxData[
      \(TraditionalForm\`Plus\)]],
  ".  In this situation, what the user really wants is to be able to ",
  StyleBox["associate",
    FontSlant->"Italic"],
  " a specific (user-defined) rule whenever an expression involving a sum of \
",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " functions arises.  The mechanism for handling this is the association \
operation which has the shorthand syntax"
}], "Text",
  CellTags->{"Association", "User-defined rules", "Protected"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?/:\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`"f/: lhs = rhs assigns rhs to be the value of lhs, and associates the \
assignment with the symbol f."\)], "Print"]
}, Open  ]],

Cell["After entering", "Text"],

Cell[BoxData[
    \(TraditionalForm\`g /: g[a_] + g[b_] := g[a + b]\)], "Input"],

Cell[TextData[{
  "the rule is associated with ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " (instead of being associated with ",
  Cell[BoxData[
      \(TraditionalForm\`+\)]],
  ") using the syntax ",
  Cell[BoxData[
      \(TraditionalForm\`\(g /: \)\)]]
}], "Text",
  CellTags->"Association"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?g\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Global`g"\)], "Print"],

Cell[BoxData[
    FormBox[
      InterpretationBox[
        StyleBox[\(g[a_]\  + \ g[b_]\  ^:= \ g[a\  + \ b]\),
          ShowStringCharacters->True,
          NumberMarks->True],
        InputForm[ 
          Definition[ g]],
        Editable->True,
        AutoDelete->True], TraditionalForm]], "Print"]
}, Open  ]],

Cell["\<\
This rule is applied repeatedly to expressions until they no longer change.  \
For example,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`g[a] + g[b] + g[c]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`g(a + b + c)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This uses pattern-matching \[LongDash] and the associativity (",
  Cell[BoxData[
      \(TraditionalForm\`Orderless\)]],
  ")  property of ",
  Cell[BoxData[
      \(TraditionalForm\`+\)]],
  ":"
}], "Text",
  CellTags->{"Associativity", "Orderless", "Pattern-matching"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Attributes[Plus]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm
    \`{Flat, Listable, NumericFunction, OneIdentity, Orderless, Protected}
      \)], "Output"]
}, Open  ]],

Cell["\<\
since the rule above was only defined for the sum of two terms.\
\>", "Text",
  CellTags->"Trace"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Use ",
  Cell[BoxData[
      \(TraditionalForm\`Trace\)]],
  " to examine the computation of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " in  ",
  Cell[BoxData[
      \(TraditionalForm\`g[a] + g[b] + g[c] + g[d] + g[e]\)]]
}], "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Simple Programming"
}], "Section"],

Cell[TextData[
"In Notebooks one can do computation without writing programs by forming a  \
collection of basic functions,  selecting the range of cells, and updating  \
the cells \[LongDash] similar to working in a spreadsheet.  Then, if \
required, cutting, pasting, and copying can be used to construct a more \
robust and  general procedure. Here is an example of this approach."], "Text",\

  CellTags->{"Notebooks", "Front end"}],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Sequence of Steps"
}], "Subsection"],

Cell[TextData[{
  "The sequence of steps below displays 10 randomly chosen points in the \
interval ",
  Cell[BoxData[
      \(TraditionalForm\`\([0, 1]\)\ \[Times]\ \([0, 1]\)\)]],
  ":"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`\(Table[Random[], {10}, {2}];\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`\(Point /@ %;\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(Show[Graphics[{PointSize[0.03], %}], 
        AspectRatio \[Rule] Automatic, PlotRange \[Rule] All];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9844 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00705397 1.03904 -0.0725642 1.03904 [
[ 0 0 0 0 ]
[ 1 .9844 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.03 w
.45587 .58248 Mdot
.64012 .74517 Mdot
.8007 .90334 Mdot
.49021 .3997 Mdot
.97619 .67871 Mdot
.74725 .59958 Mdot
.10707 .84094 Mdot
.02381 .24275 Mdot
.96449 .02344 Mdot
.71759 .96096 Mdot
0 0 m
1 0 L
1 .9844 L
0 .9844 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 283.5},
  ImageMargins->{{62, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004P00016a000`40O003h00Oogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo57oo10002Goo003oOolCOol60008Ool00?mooa9oo`P000Moo`00ogoo4Woo
20001goo003oOolBOol80007Ool00?mooa9oo`P000Moo`00ogoo4goo1P0027oo003oOolDOol40009
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`001Goo1000ogoo67oo0004Ool6003oOolGOol000=oo`P00?mo
oaIoo`000goo2000ogoo5Woo0003Ool8003oOolFOol000=oo`P00?mooaIoo`0017oo1P00ogoo5goo
0005Ool4003oOolHOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00RWoo1000TWoo0029Ool6002AOol008Qoo`P0091oo`00R7oo2000T7oo0028Ool8
002@Ool008Qoo`P0091oo`00RGoo1P00TGoo002:Ool4002BOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQ
Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00
ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0085oo`@009]oo`00P7oo1P00VWoo
001oOol8002IOol007moo`P009Uoo`00Ogoo2000VGoo001oOol8001=Ool40018Ool0081oo`H004eo
o`H004Moo`00PGoo1000CGoo2000AWoo003BOol80016Ool00=9oo`P004Ioo`00dWoo2000AWoo003C
Ool60017Ool00=Aoo`@004Qoo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo5goo10001Woo003oOolFOol60005Ool00?mooaEoo`P000Ao
o`00ogoo5Goo200017oo003oOolEOol80004Ool00?mooaEoo`P000Aoo`00ogoo5Woo1P001Goo003o
OolGOol40006Ool00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo002eOol4001WOol00;Aoo`H006Io
o`00/goo2000IGoo002cOol8001UOol00;=oo`P006Eoo`00/goo2000IGoo002dOol6001VOol00;Eo
o`@006Moo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo
8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol0
0?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo000LOol4003oOol1Ool001]oo`H0
0?moo`006Woo2000oWoo000JOol8003nOol001Yoo`P00?ioo`006Woo2000oWoo000KOol6003oOol0
01aoo`@00?moo`5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5o
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003TOol4000hOol00>=oo`H003Moo`00hWoo
2000=Woo003ROol8000fOol00>9oo`P003Ioo`00hWoo2000=Woo003SOol6000gOol00>Aoo`@003Qo
o`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003oOolQOol00?moob5oo`00ogoo8Goo003o
OolQOol00?moob5oo`00c7oo1000D7oo003;Ool6001?Ool00<Yoo`P004ioo`00bWoo2000CWoo003:
Ool8001>Ool00<Yoo`P004ioo`00bgoo1P00Cgoo003<Ool4001@Ool00?moob5oo`00ogoo8Goo0000
\
\>"],
  ImageRangeCache->{{{0, 287}, {282.5, 0}} -> {-0.00683258, 0.069833, \
0.00335371, 0.00335371}}]
}, Open  ]],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Modify the parameters in these three cells to generate ",
  Cell[BoxData[
      \(TraditionalForm\`100\)]],
  ", two-dimensional points, of size ",
  Cell[BoxData[
      \(TraditionalForm\`0.01\)]],
  "."
}], "BeginEndQuestion"],

Cell["This approach is analogous to using a spreadsheet.", "Text",

  CellTags->"spreadsheet"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Converting a Sequence of Steps into a Module"
}], "Subsection"],

Cell[TextData[{
  "To convert these steps into a program, we collect the above steps together \
into a ",
  StyleBox["Module", "InlineInputTraditionalForm"],
  " and introduce a (dummy) local variable (",
  StyleBox["pts", "InlineInputTraditionalForm"],
  "):"
}], "Text"],

Cell[BoxData[
    \(TraditionalForm\`RandomPointPlot[n_, s_:  0.03] := 
      Module[{pts}, \n\t\tpts = Table[Random[], {n}, {2}]; \n\t\tpts = 
          Point /@ pts; \n\t\tShow[Graphics[{PointSize[s], pts}], 
          AspectRatio \[Rule] Automatic, PlotRange \[Rule] All];]\)], "Input"],

Cell[TextData[{
  
  CounterBox["Exercise"],
  ". Run this program to produce 200 random points of size 0.05."
}], "BeginEndQuestion"],

Cell[TextData[{
  "A good approach to programming in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is to first find the appropriate \"sequence of steps\" and then, when \
everything is working well and has been tested in all the cases of interest, \
convert these steps into a procedure as shown in this example."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Blocks and Modules \[LongDash] Variable Scoping"
}], "Section",
  CellTags->{"Block", "Module", "Variable scoping"}],

Cell[TextData[{
  "In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " there are two special programming constructs \[LongDash] ",
  StyleBox["Block", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["Module", "InlineInputTraditionalForm"],
  " \[LongDash] which, like their names suggest, are used to delimit blocks \
of  code. The variables contained within these delimiters are local \
\[LongDash] in  the sense illustrated below. The following simple example \
clearly shows the  difference between ",
  StyleBox["Block", "InlineInputTraditionalForm"],
  " and ",
  StyleBox["Module", "InlineInputTraditionalForm"],
  "."
}], "Text"],

Cell[TextData[{
  "This assignment focuses on the elements of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " and not on how to write complete ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programs. An excellent introduction to programming in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is found in [Maeder]."
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Block"
}], "Subsection"],

Cell["Define", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`m = i\^2\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`i\^2\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In a ",
  Cell[BoxData[
      \(TraditionalForm\`Block\)]],
  ", the local value of ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " is used in the body:"
}], "Text",
  CellTags->"Block"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Block[{i = a}, i + m]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`a\^2 + a\)], "Output"]
}, Open  ]],

Cell["Trace clearly shows the sequence of steps:", "Text",

  CellTags->"Tracing computations"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Trace[Block[{i = a}, i + m]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          TagBox[\(Block[{i = a}, i + m]\),
            HoldForm], ",", 
          RowBox[{"{", 
            RowBox[{
              TagBox[\(i = a\),
                HoldForm], ",", 
              TagBox["a",
                HoldForm]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                  TagBox["i",
                    HoldForm], ",", 
                  TagBox["a",
                    HoldForm]}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{
                  TagBox["m",
                    HoldForm], ",", 
                  TagBox[\(i\^2\),
                    HoldForm], ",", 
                  RowBox[{"{", 
                    RowBox[{
                      TagBox["i",
                        HoldForm], ",", 
                      TagBox["a",
                        HoldForm]}], "}"}], ",", 
                  TagBox[\(a\^2\),
                    HoldForm]}], "}"}], ",", 
              TagBox[\(a\^2 + a\),
                HoldForm]}], "}"}], ",", 
          TagBox[\(a\^2 + a\),
            HoldForm]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Block\)]],
  " localises the values of a variable but not the symbol itself. This is  \
called ",
  StyleBox["dynamic scoping",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Dynamic scoping"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Module"
}], "Subsection"],

Cell[TextData[{
  "In a ",
  Cell[BoxData[
      \(TraditionalForm\`Module\)]],
  ", the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " that appears explicitly in the body is treated as a local  variable:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Module[{i = a}, i + m]\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`i\^2 + a\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "In other words, the ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " inside the ",
  Cell[BoxData[
      \(TraditionalForm\`Module\)]],
  " is different to the external ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  ": "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`Trace[Module[{i = a}, i + m]]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{"{", 
        RowBox[{
          TagBox[\(Module[{i = a}, i + m]\),
            HoldForm], ",", 
          RowBox[{"{", 
            RowBox[{
              TagBox[\(i$25 = a\),
                HoldForm], ",", 
              TagBox["a",
                HoldForm]}], "}"}], ",", 
          RowBox[{"{", 
            RowBox[{
              RowBox[{"{", 
                RowBox[{
                  TagBox["i$25",
                    HoldForm], ",", 
                  TagBox["a",
                    HoldForm]}], "}"}], ",", 
              RowBox[{"{", 
                RowBox[{
                  TagBox["m",
                    HoldForm], ",", 
                  TagBox[\(i\^2\),
                    HoldForm]}], "}"}], ",", 
              TagBox[\(i\^2 + a\),
                HoldForm]}], "}"}], ",", 
          TagBox[\(i\^2 + a\),
            HoldForm]}], "}"}], TraditionalForm]], "Output"]
}, Open  ]],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`Module\)]],
  " localises the symbols. This is called ",
  StyleBox["lexical scoping",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"Lexical scoping"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  ".",
  
  CounterBox["Subsection"],
  " ",
  "Block or Module?"
}], "Subsection"],

Cell[TextData[{
  "The question arises as to when one should use ",
  StyleBox["Block", "InlineInputTraditionalForm"],
  " and when one should use ",
  StyleBox["Module", "InlineInputTraditionalForm"],
  ". The answer is that most of the time one should use ",
  StyleBox["Module", "InlineInputTraditionalForm"],
  ". A  particular application that requires ",
  StyleBox["Block", "InlineInputTraditionalForm"],
  " instead of ",
  StyleBox["Module", "InlineInputTraditionalForm"],
  " is when temporarily changing the value of a system variable. Consider the \
following recursive procedure for computing factorial:"
}], "Text",
  CellTags->{"Block", "System variable"}],

Cell[BoxData[
    \(TraditionalForm
    \`fac[n_] := \n
      Module[{h, m}, \n\t\th[0] = 1; \n\t\th[m_] := \(h[m] = m\ h[m - 1]\); \n
        \t\th[n]\n]\)], "Input"],

Cell["Everything seems to work fine:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`fac[20] \[Equal] \(20!\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Note also that ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is \"hidden\":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(?h\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`"Global`h"\)], "Print"]
}, Open  ]],

Cell["However, when we try a larger number we run into a problem:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`fac[256]\)], "Input"],

Cell[BoxData[
    FormBox[
      RowBox[{
      \($RecursionLimit::"reclim"\), \(\(:\)\(\ \)\), 
        "\<\"Recursion depth of \\!\\(TraditionalForm\\`256\\) exceeded.\"\>"}
        ], TraditionalForm]], "Message"],

Cell[BoxData[
    \(TraditionalForm
    \`357424073059517772549617613200513593815742300116452341608189854323862271\
897144828907266788066854753520989952225973576794232165347789040198050953870207\
260844033182221901403661017781336511164400078320361654800476378209198969436021\
443628828052542013698469042841241989029908939237604384591086873049611724273950\
445938673983108115411264444046974224702585514482003424525292168171284646705625\
811432128792386236776192335943192681259517060079753510256640000000000000000000\
00000000000000000000000000000000000000000000\ Hold[4\ \(h$27(4 - 1)\)]\)], 
  "Output"]
}, Open  ]],

Cell[TextData[{
  "It is apparent that we have hit a recursion limit.  This is controlled by  \
the ",
  StyleBox["global variable,",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`$RecursionLimit\)]],
  ":"
}], "Text",
  CellTags->{"$RecursionLimit", "global variable"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`$RecursionLimit\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`256\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Here is a modified routine (overwriting the previous one) which uses ",
  StyleBox["Block", "InlineInputTraditionalForm"],
  " to temporarily change the recursion limit and ",
  StyleBox["Module", "InlineInputTraditionalForm"],
  " to do the computation:"
}], "Text",
  CellTags->{"Block", "Module"}],

Cell[BoxData[
    \(TraditionalForm
    \`\(fac[n_] := \n
      Block[{$RecursionLimit = \[Infinity]}, \n\t\t
        Module[{h, m}, \n\t\t\th[0] = 1; \n\t\t\t
          h[m_] := \(h[m] = m\ h[m - 1]\); \n\t\t\th[n]\n\t\t]\n]\ \)\)], 
  "Input"],

Cell["Now we have no problems with a much larger calculation:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`\(\ fac[500] == \(500!\)\)\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "and the global ",
  StyleBox["$RecursionLimit", "InlineInputTraditionalForm"],
  " keeps its usual value: "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(TraditionalForm\`$RecursionLimit\)], "Input"],

Cell[BoxData[
    \(TraditionalForm\`256\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Title"],
  ".",
  
  CounterBox["Section"],
  " ",
  "Summary"
}], "Section"],

Cell[TextData[{
  "To summarise, here are some basic points relevant to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming:"
}], "Text"],

Cell[TextData[{
  "Because the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " language is high level, coding is often a straightforward transliteration \
 of the problem. "
}], "BulletedList",
  CellTags->"Natural implementation"],

Cell[TextData[{
  "Coding in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " syntax often forces one to really understand the problem definition or \
algorithm: implicit and side conditions need to be brought out and sign  \
conventions made explicit. "
}], "BulletedList",
  CellTags->"Mathematica syntax"],

Cell[TextData[{
  "In standard mathematical notation, it is common to suppress the functional \
dependence of some variables and to use the same symbol to mean several \
things depending on context.  The use of the ",
  Cell[BoxData[
      \(TraditionalForm\` = \)]],
  " sign is a good example of the latter: It can mean assignment, equality, \
or equivalence.  In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " there are unique symbols for each of these shades of meaning (",
  Cell[BoxData[
      \(TraditionalForm\` = \)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\` == \)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\` \[Congruent] \)]],
  ") and the potential for confusion is thus greatly reduced."
}], "BulletedList",
  CellTags->"Functional dependence"],

Cell["\<\
Use built-in functions, or functions in the standard packages, where \
possible.\
\>", "BulletedList",
  CellTags->"Built-in functions"],

Cell[TextData[{
  "For user-defined variables and procedures, use full and descriptive names. \
 There is little advantage in using abbreviated names, especially as ",
  StyleBox["Command Completion", "Menu"],
  " in the front end works with both built-in and user-defined names."
}], "BulletedList",
  CellTags->{
  "Full names", "Descriptive names", "User-defined rules", 
    "Command Completion"}],

Cell[TextData[{
  "Working with lists and matrices (",
  Cell[BoxData[
      \(TraditionalForm\`List\)]],
  " structures) is often more efficient than procedural operations. However,  \
since many algorithms or formulae are expressed in terms of operators like  \
\[Sum], \[Product], ",
  StyleBox["etc.",
    FontSlant->"Italic"],
  ", one first has to translate these into operations on lists."
}], "BulletedList",
  CellTags->{"List", "Efficiency", "Procedural programming"}],

Cell[TextData[{
  "Functional programming \[LongDash] ",
  StyleBox["i.e.",
    FontSlant->"Italic"],
  ", programming using a high level of abstraction \[LongDash] is very \
powerful.  However, overuse of functional programming can obscure the \
algorithm. Users from procedural backgrounds may find functional programming \
hard to get used to; nevertheless, a large number of algorithms should be \
coded functionally and learning functional programming is well worth the  \
effort."
}], "BulletedList",
  CellTags->"Functional programming"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{956, 721},
WindowMargins->{{-2, Automatic}, {Automatic, 1}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
CharacterEncoding->"MacintoshAutomaticEncoding",
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["\<\
Style Definitions for 
Computational Physics\
\>", "Subtitle",
    CellMargins->{{0, Inherited}, {Inherited, 0}},
    CellFrameMargins->{{20, 4}, {8, 20}},
    FontSize->36,
    FontWeight->"Bold",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[StyleData[All, "Working"],
    ScreenStyleEnvironment->"Working",
    PrintingStyleEnvironment->"Printout",
    CellBracketOptions->{"Color"->RGBColor[0.115343, 0.350561, 0.362966]},
    ShowCellLabel->True,
    CellFrameLabelMargins->6,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    ScreenStyleEnvironment->"Presentation",
    PrintingStyleEnvironment->"Printout",
    CellFrameMargins->{{30, 4}, {8, 8}},
    Magnification->1.25],
  
  Cell[StyleData[All, "Printout"],
    ScreenStyleEnvironment->"Printout",
    PrintingStyleEnvironment->"Printout",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{24, 74}, {72, 72}},
    "PrintRegistrationMarks"->False,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    ShowCellBracket->False],
  
  Cell[StyleData[All, "Production"],
    ScreenStyleEnvironment->"Production",
    PrintingStyleEnvironment->"Production",
    PageWidth->PaperWidth,
    PrintingOptions->{"PrintingMargins"->{{0, 0}, {82, 56}},
    "PageSize"->{486, 711},
    "PrintRegistrationMarks"->True,
    "FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], Inherited, Cell[ 
          "Paul Abbott", "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], Inherited, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PageFooters->{{Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}, {
        Cell[ 
            TextData[ {"Computational Physics ", 
              CounterBox[ "Page"]}], "Footer"], Inherited, Inherited}},
    CellFrameLabelMargins->6,
    CommonDefaultFormatTypes->{"Input"->TraditionalForm,
    "Output"->TraditionalForm},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
Each notebook should contain at least one title cell. Title resets all cell \
CounterBox values to zero (except Title).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {Inherited, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    CellFrameMargins->{{55, 4}, {8, 20}},
    LineSpacing->{1.125, 0},
    CounterIncrements->"Title",
    CounterAssignments->{{"Subtitle", 0}, {"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}, {"List", 0}, {"NumberedFigure", 0}, {
        "NumberedTable", 0}, {"NumberedProgram", 0}, {"Equation", 0}, {
        "Text", 0}, {"SmallText", 0}, {"Reference", 0}, {"Exercise", 0}},
    FontFamily->"Times",
    FontSize->36,
    FontSlant->"Italic",
    FontColor->GrayLevel[1],
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Presentation"],
    LineSpacing->{0.95, 0},
    FontSize->40,
    FontSlant->"Italic",
    Background->RGBColor[0.699931, 0.198672, 0.198672]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    CellFrameMargins->False,
    LineSpacing->{0.95, 0},
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["Title", "Production"],
    CellMargins->{{72, 72}, {14, 0}},
    CellFrameMargins->False,
    FontFamily->"Janson Text",
    FontColor->GrayLevel[0],
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subtitle is an optional cell. Used for Tech Support column, Subtitle states \
topics in current issue.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->24,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subtitle", "Presentation"]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{54, 0}, {10, 10}},
    FontSize->12],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{72, 72}, {12, 2}},
    FontFamily->"Janson Text",
    FontSize->12,
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{54, 25}, {0, 10}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    LineSpacing->{1, 0},
    CounterIncrements->"Subtitle",
    FontFamily->"Times",
    FontSize->18,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{54, 0}, {Inherited, Inherited}},
    FontSize->16],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{72, 72}, {6, 2}},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SectionFirst should be used for the first Section level heading in a \
notebook. Sets the following counter values to zero: Subsection and \
Subsubsection. Sets Section counter value to 1.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionFirst"],
    CellFrame->{{0, 0}, {0, 2}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Section", 0}, {"Subsection", 0}, {
        "Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionFirst", "Presentation"],
    CellFrame->{{0, 0}, {0, 3}},
    CellFrameMargins->{{0, 0}, {0, 4}},
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    FontSize->18],
  
  Cell[StyleData["SectionFirst", "Printout"],
    CellFrame->{{0, 0}, {0, 3}},
    CellMargins->{{54, 24}, {15, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionFirst", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Section should be used for subsequent Section level headings. Sets counter \
values Subsection and Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}},
    FontSize->18],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Subsection is an optional style. Sets counter Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Presentation"]],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
SubsectionNoSpace is an optional style, it is to be used if a subsection \
level heading directly follows a section level heading. Sets counter \
Subsubsection to zero.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpace"],
    CellDingbat->"\[GraySquare]",
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpace", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpace", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpace", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"]],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NoDingbat versions of headings for use in print published frontmatter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SectionNoDingbat"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 30}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameMargins->2,
    CellFrameColor->RGBColor[0.668009, 0.669383, 0.345068],
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->18,
    FontWeight->"Bold"],
  
  Cell[StyleData["SectionNoDingbat", "Presentation"],
    CellFrameMargins->{{0, 0}, {0, 4}}],
  
  Cell[StyleData["SectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {3, 15}},
    CellFrameMargins->{{0, 0}, {0, 5}},
    CellFrameColor->GrayLevel[0],
    FontSize->14],
  
  Cell[StyleData["SectionNoDingbat", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {2, 30}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoDingbat"],
    CellDingbat->None,
    CellMargins->{{54, 25}, {10, 26}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, Inherited}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat"],
    CellMargins->{{54, 25}, {2, 2}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->12],
  
  Cell[StyleData["SubsectionNoSpaceNoDingbat", "Production"],
    CellMargins->{{72, 72}, {2, 2}},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->10,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SubsubsectionNoDingbat"],
    CellMargins->{{54, 25}, {6, 20}},
    CellGroupingRules->{"SectionGrouping", 60},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Presentation"]],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Printout"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["SubsubsectionNoDingbat", "Production"],
    CellMargins->{{72, 72}, {-4, 2}},
    FontFamily->"Futura Book",
    FontSize->9,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"Text",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Text", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    CounterIncrements->"SmallText",
    FontFamily->"Times",
    FontSize->10],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{54, 24}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 11},
    FontFamily->"Janson Text",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginQuestion is used directly after a section cell. Followed by either \
Question or Input/Output etc. Last paragraph of the question should be in \
EndQuestion cell style.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginQuestion"],
    CellFrame->{{0, 0}, {0, 1}},
    CellMargins->{{54, 34}, {8, 8}},
    CellFrameMargins->{{0, 0}, {2, 4}},
    CounterIncrements->"Exercise",
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginQuestion", "Printout"],
    CellMargins->{{72, 34}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginQuestion", "Production"],
    PageWidth->PaperWidth,
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["EndQuestion used as the last paragraph of the question.", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["EndQuestion"],
    CellFrame->{{0, 0}, {1, 0}},
    CellMargins->{{54, 34}, {8, 8}},
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["EndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["EndQuestion", "Production"],
    CellFrame->{{0, 0}, {2, 0}},
    CellMargins->{{72, 72}, {2, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BeginEndQuestion is used in the In and Out column directly after a section \
cell. Used if the question is a single text paragraph.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginEndQuestion"],
    CellFrame->{{0, 0}, {1, 1}},
    CellMargins->{{54, 35}, {8, 8}},
    CounterIncrements->"Exercise",
    StyleMenuListing->Automatic,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Presentation"],
    LineSpacing->{1, 4},
    FontSize->16,
    FontColor->RGBColor[0.115511, 0.321752, 0.580118]],
  
  Cell[StyleData["BeginEndQuestion", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    FontSize->10,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["BeginEndQuestion", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell["\<\
BeginAnswer is used directly after an EndQuestion or BeginEndQuestion cell \
style to begin the answer portion. Followed by Text or Input/Output etc.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Answer"],
    CellDingbat->"Answer: ",
    CellMargins->{{54, 35}, {8, 8}},
    LineSpacing->{1, 4}],
  
  Cell[StyleData["Answer", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Answer", "Printout"],
    CellMargins->{{70, 35}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["Answer", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Quote should be used when displaying text previously published elsewhere (and \
appropriately cited).\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    TextJustification->0,
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{70, 40}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{96, 96}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontSlant->"Plain",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{76, 24}, {4, 4}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"]],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->False,
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontWeight->"Bold",
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Output cell style is usually generated by the Mathematica kernel. \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{76, 24}, {4, 4}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"]],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{96, 72}, {2, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {2, 4}},
    CellLabelMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1.25, 0},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Message cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically messages emitted during evaluation."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{78, 24}, {2, 2}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{72, 24}, {2, 2}},
    FontSize->8,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellFrame->True,
    CellDingbat->None,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    LineSpacing->{0, 10},
    FontFamily->"WriCMTT9",
    FontSize->8,
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell[TextData[{
    "Print cells are usually generated by the ",
    StyleBox["Mathematica",
      FontSlant->"Italic"],
    " kernel, typically from such commands as ?Plot."
  }], "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellFrame->True,
    CellMargins->{{78, 24}, {1, 6}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
    CellFrameColor->RGBColor[0.718318, 0.694575, 0.474449],
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    CounterIncrements->"Print",
    StyleMenuListing->None,
    FontSize->10],
  
  Cell[StyleData["Print", "Presentation"],
    CellFrame->2,
    FontSize->12,
    Background->None],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{54, 24}, {2, 6}},
    CellFrameColor->GrayLevel[0],
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellFrame->True,
    CellMargins->{{96, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    CellFrameMargins->4,
    CellFrameColor->GrayLevel[0],
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    Background->None,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]],
  
  Cell["\<\
Graphics cell usually output by kernel. To be preceded by Input cell, not \
followed by Output cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{54, 24}, {10, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelAutoDelete->True,
    DefaultFormatType->DefaultOutputFormatType,
    CounterIncrements->"Graphics",
    ImageMargins->{{30, 0}, {0, 0}}],
  
  Cell[StyleData["Graphics", "Presentation"]],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{54, 24}, {10, 0}},
    ImageSize->{266, 266},
    ImageMargins->{{40, Inherited}, {Inherited, Inherited}},
    Background->None],
  
  Cell[StyleData["Graphics", "Production"],
    CellFrame->False,
    CellMargins->{{96, 72}, {8, 10}},
    LineSpacing->{0, 12},
    ImageSize->{144, 144},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
CellLabel style definition controls how labels appear when a cell has \
ShowCellLabels->True.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->9,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    LineSpacing->{1, 0},
    FontFamily->"CLO Futura CondLightOblique",
    FontSize->6,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0],
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False},
    PrivateFontOptions->{
    "FontPostScriptName"->"Futura-CondensedLightOblique"}]
  }, Closed]],
  
  Cell["\<\
InlineInputTraditionalForm is for TraditionalForm input cells embedded within \
another cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineInputTraditionalForm"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    AutoItalicWords->{},
    FormatType->TraditionalForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    SingleLetterItalics->True,
    CounterIncrements->"Input",
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["InlineInputTraditionalForm", "Presentation"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Printout"]],
  
  Cell[StyleData["InlineInputTraditionalForm", "Production"],
    CounterIncrements->"Input",
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
NumberedEquation is for DisplayFormula-type cells that you want to number \
sequentially throughout a notebook.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{100, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "Title"], ".", 
              CounterBox[ "Section"], ".", 
              CounterBox[ "Equation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    CounterIncrements->"Equation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{Inherited, Inherited}, {10, Inherited}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedFigureCaption to be used directly after a PlacedGraphic cell. Use the \
TMJAuthorPalette.nb palette to begin the cell and paste in the word Figure \
and the NumberedFigure counter value. Allows for a descriptive caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigureCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellLabelPositioning->Left,
    CellFrameLabels->{{None, None}, {None, None}},
    TextAlignment->Left,
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica"],
  
  Cell[StyleData["NumberedFigureCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->14],
  
  Cell[StyleData["NumberedFigureCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedFigureCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedTableCaption to be used directly after a Table cell. Use the \
TMJAuthorPalette.nb palette to begin the cell and paste in the word Table and \
the NumberedTable counter value. Allows for a descriptive caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTableCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedTable",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedTableCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedTableCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedTableCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedProgramCaption to be used directly after a Program cell. Use the \
TMJAuthorPalette.nb palette to begin the cell and paste in the word Listing \
and the NumberedProgram counter value. Allows for a descriptive caption.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedProgramCaption"],
    CellDingbat->"\[FilledUpTriangle]",
    CellMargins->{{54, 24}, {5, 10}},
    CellFrameLabels->{{None, None}, {None, None}},
    HyphenationOptions->{"HyphenationCharacter"->"-"},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["NumberedProgramCaption", "Presentation"],
    CellMargins->{{54, 24}, {2, 10}},
    FontSize->12],
  
  Cell[StyleData["NumberedProgramCaption", "Printout"],
    CellFrameLabels->{{None, None}, {None, None}},
    FontSize->8],
  
  Cell[StyleData["NumberedProgramCaption", "Production"],
    CellDingbat->None,
    CellMargins->{{72, 72}, {2, 4}},
    TextJustification->1,
    FontFamily->"Futura Book",
    FontSize->9,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
BulletedList is an optional style. Adds a CellDingbat of FilledSmallCircle. \
Text indents left a little more.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[FilledSmallCircle]",
    CellMargins->{{86, 10}, {Inherited, Inherited}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BulletedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{96, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
BeginNumberedList to be used as the first item in a numbered list sequence. \
Use the TMJAuthorPalette.nb palette to begin the cell and paste in the List \
counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BeginNumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    CounterAssignments->{{"List", 0}},
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["BeginNumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["BeginNumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["BeginNumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedList to be used for subsequent items in a numbered list sequence with \
a single digit. Use the TMJAuthorPalette.nb palette to begin the cell and \
paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedList"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CellFrameLabels->{{None, None}, {None, None}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedList", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedList", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedList", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-13,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
NumberedListTwo to be used for subsequent items in a numbered list sequence \
with two digits. Use the TMJAuthorPalette.nb palette to begin the cell and \
paste in the List counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedListTwo"],
    CellMargins->{{74, 10}, {Inherited, Inherited}},
    CounterIncrements->"List",
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["NumberedListTwo", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["NumberedListTwo", "Printout"],
    FontSize->10],
  
  Cell[StyleData["NumberedListTwo", "Production"],
    CellMargins->{{84, 72}, {2, Inherited}},
    TextJustification->1,
    Hyphenation->True,
    ParagraphIndent->-17,
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Reference style to be used in the bibliography portion of a notebook. One \
cell for each bibliography entry. Use the TMJAuthorPalette.nb palette to \
begin cell and paste in the Reference counter value.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Reference"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Reference", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["Reference", "Printout"],
    FontSize->8],
  
  Cell[StyleData["Reference", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-14,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ReferenceTwo"],
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Reference",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["ReferenceTwo", "Presentation"],
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["ReferenceTwo", "Printout"],
    FontSize->8],
  
  Cell[StyleData["ReferenceTwo", "Production"],
    CellMargins->{{84, 72}, {2, 4}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 10},
    ParagraphIndent->-18,
    FontFamily->"Futura Book",
    FontSize->8,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
OnlineHeader to be used at the beginning of a notebook. Precedes the Title \
cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OnlineHeader"],
    ShowCellBracket->False,
    CellMargins->{{0, 25}, {0, 0}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    CellFrameMargins->{{54, 4}, {2, 8}},
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Wide",
    FontColor->GrayLevel[1],
    Background->GrayLevel[0],
    FontVariations->{"Underline"->False,
    "Outline"->False,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Masked"->False,
    "CompatibilityType"->0,
    "RotationAngle"->0}],
  
  Cell[StyleData["OnlineHeader", "Presentation"],
    CellFrameMargins->{{54, 25}, {8, 8}},
    FontSize->14],
  
  Cell[StyleData["OnlineHeader", "Printout"],
    CellFrame->False,
    CellMargins->{{54, 24}, {10, 10}},
    FontFamily->"Times",
    FontSize->10,
    FontColor->GrayLevel[0],
    Background->None],
  
  Cell[StyleData["OnlineHeader", "Production"],
    PageWidth->PaperWidth,
    CellFrame->False,
    CellMargins->{{72, 72}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->2},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell["\<\
Author to be used after the Title cell with author name(s). Author name(s) \
may be preced by \"Edited by \" for certain columns. Text in author cell to \
be used as the left page header. Usually followed by an Address cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Author"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["Author", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Author", "Printout"],
    CellMargins->{{54, 24}, {2, 15}},
    FontSize->12],
  
  Cell[StyleData["Author", "Production"],
    CellMargins->{{72, 72}, {4, 4}},
    LineSpacing->{0, 14},
    FontFamily->"CXB Futura CondExtraBold",
    FontSize->12,
    FontProperties->{"FontSerifed"->False,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Address to be used after Author or SecondAuthor. Contains contact information \
for article (section) author.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Address"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    CellGroupingRules->{"TitleGrouping", 30},
    PageBreakBelow->False,
    LineSpacing->{1, 1},
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["Address", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Address", "Printout"],
    CellMargins->{{54, 24}, {2, 2}},
    FontSize->10],
  
  Cell[StyleData["Address", "Production"],
    CellMargins->{{72, 72}, {22, 4}},
    LineSpacing->{0, 12},
    FontFamily->"I Janson Text Italic",
    FontSize->8,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
Abstract to be used after the Address cell. Contains a short descriptive \
summary of the article.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Abstract"],
    CellMargins->{{54, 24}, {Inherited, 30}},
    LineSpacing->{1, 3},
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Abstract", "Printout"],
    CellMargins->{{54, 24}, {20, 30}},
    FontSize->12,
    FontSlant->"Italic"],
  
  Cell[StyleData["Abstract", "Production"],
    CellMargins->{{72, 72}, {Inherited, 2}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{0, 12},
    FontFamily->"BI Janson Text Bold Italic",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell["\<\
PictureGroup style definitions included for compatability with the Help \
Browser.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PictureGroup"],
    CellFrame->{{1, 0}, {0, 1}},
    CellMargins->{{54, 25}, {0, 0}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    ShowCellLabel->False,
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Presentation"],
    CounterIncrements->"Graphics",
    ImageMargins->{{35, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["PictureGroup", "Printout"],
    CellMargins->{{54, Inherited}, {0, 0}},
    ImageSize->{0.0625, 0.0625}],
  
  Cell[StyleData["PictureGroup", "Production"],
    CellFrame->False,
    CellMargins->{{72, 72}, {8, 10}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MarkersComment"],
    CellFrame->False,
    CellDingbat->"\[FilledCircle]",
    CellMargins->{{54, 25}, {Inherited, Inherited}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontColor->RGBColor[1, 0, 0],
    Background->GrayLevel[1]],
  
  Cell[StyleData["MarkersComment", "Printout"],
    CellMargins->{{18, 4}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontSize->10],
  
  Cell[StyleData["MarkersComment", "Production"],
    CellMargins->{{24, 0}, {Inherited, 0}},
    LineSpacing->{1, 3},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell["\<\
Table cell style to be used for cells containing displayed tabular material. \
Can be followed by NumberedTableCaption cell.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Table"],
    CellMargins->{{54, 24}, {5, 10}},
    TextAlignment->Center,
    FontFamily->"Times",
    FontSize->12,
    Background->GrayLevel[0.899001]],
  
  Cell[StyleData["Table", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Table", "Printout"],
    FontSize->10,
    Background->None],
  
  Cell[StyleData["Table", "Production"],
    CellMargins->{{72, 72}, {0, 4}},
    FontFamily->"Janson Text",
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Menu"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontFamily->"Charcoal"],
  
  Cell[StyleData["Menu", "Presentation"]],
  
  Cell[StyleData["Menu", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Warning"],
    CellDingbat->"\[WarningSign]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    LineSpacing->{1, 4},
    ParagraphSpacing->{0, 12},
    FontSize->12],
  
  Cell[StyleData["Warning", "Presentation"],
    LineSpacing->{1, 5},
    ParagraphSpacing->{0, 12}],
  
  Cell[StyleData["Warning", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BrightIdea"],
    CellDingbat->"\[LightBulb]",
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    FontFamily->"Times"],
  
  Cell[StyleData["BrightIdea", "Presentation"]],
  
  Cell[StyleData["BrightIdea", "Printout"],
    TextJustification->1]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    TextAlignment->Center,
    ScriptLevel->0,
    SingleLetterItalics->True,
    FontFamily->"Times",
    FontSize->12,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    PrivateEvaluationOptions->{"OutputFormPageWidth"->342},
    LineSpacing->{1.25, 0},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{54, 25}, {2, 10}},
    DefaultFormatType->DefaultInputFormatType,
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["ChemicalFormula", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{54, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ChemicalFormula", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 12},
    FontFamily->"Janson Text",
    FontSize->10,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{54, 25}, {Inherited, 6}},
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Program", "Presentation"],
    FontFamily->"Courier",
    FontSize->12],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{54, 30}, {Inherited, 4}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{72, 72}, {2, 4}},
    LineSpacing->{0, 11},
    FontFamily->"WriCMTT9",
    FontSize->9,
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{54, 24}, {0, 0}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["Header", "Presentation"]],
  
  Cell[StyleData["Header", "Printout"]],
  
  Cell[StyleData["Header", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"I Janson Text Italic",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"B Janson Text Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Footer"],
    CellMargins->{{54, 24}, {Inherited, Inherited}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer", "Production"],
    PageWidth->PaperWidth,
    CellMargins->{{72, 72}, {2, 2}},
    StyleMenuListing->None,
    FontFamily->"O Futura BookOblique",
    FontSize->6]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These cells define styles that are mixed in with most other cells.  If the \
FormatType of a cell style matches the name of one of the styles defined \
below, then that style is applied along with the local cell style \
definitions. This is particularly true of Input and Output.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["CellExpression"],
    CellMargins->{{54, 24}, {2, 4}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    Hyphenation->False,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["OutputForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->False,
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->True}],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None,
    FontFamily->"Times",
    FontProperties->{"FontSerifed"->True,
    "FontMonospaced"->False}],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text",
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section",
    CellFrame->False,
    CellDingbat->None,
    ShowCellBracket->True,
    CellMargins->{{0, 0}, {10, 40}},
    CellFrameMargins->{{20, 4}, {8, 8}},
    FontColor->GrayLevel[1],
    Background->RGBColor[0.269902, 0.558434, 0.715618]],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell style.\
\>", "Text",
    PageWidth->342,
    CellMargins->{{24, 0}, {Inherited, Inherited}}],
  
  Cell["\<\
RM used to change selection to FontWeight->Plain, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["RM"],
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
BF used to change selection to FontWeight->Bold, FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["BF"],
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
IT used to change selection to FontWeight->Plain, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["IT"],
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
BFI used to change selection to FontWeight->Bold, FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["BFI"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
TR used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TR"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
TI used to change selection to normal text font, FontWeight->Plain, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TI"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell["\<\
TB used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["TB"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
TBI used to change selection to normal text font, FontWeight->Bold, \
FontSlant->Italic\
\>", "Text"],
  
  Cell[StyleData["TBI"],
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell["\<\
MR used to change selection to monospace font with FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MR"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
MR used to change selection to monospace font with FontWeight->Plain, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
MB used to change selection to monospace font with FontWeight->Bold, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["MB"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
MBO used to change selection to monospace font with FontWeight->Bold, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["MBO"],
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Oblique"],
  
  Cell["\<\
SR used to change selection to sans serif font with FontWeight->Plain, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SR"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell["\<\
SO used to change selection to sans serif font with FontWeight->Plain, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SO"],
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Oblique"],
  
  Cell["\<\
SB used to change selection to sans serif font with FontWeight->Bold, \
FontSlant->Plain\
\>", "Text"],
  
  Cell[StyleData["SB"],
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell["\<\
SBO used to change selection to sans serif font with FontWeight->Bold, \
FontSlant->Oblique\
\>", "Text"],
  
  Cell[StyleData["SBO"],
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Bold",
    FontSlant->"Oblique"]
  }, Closed]]
  }, Open  ]]
  }],
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon<3;08f0dL5N`?P0080001804P000000`d26P01
0000I00000400@410?l00BL?00400@00000000000000000801T1T0000000@000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "Kernel"->{
    Cell[3548, 125, 432, 9, 58, "Text",
      CellTags->{"Kernel", "Built-in functions"}]},
  "Built-in functions"->{
    Cell[3548, 125, 432, 9, 58, "Text",
      CellTags->{"Kernel", "Built-in functions"}],
    Cell[10149, 299, 186, 12, 54, "Subsection",
      CellTags->"Built-in functions"],
    Cell[188426, 5586, 146, 4, 22, "BulletedList",
      CellTags->"Built-in functions"]},
  "Tour of Mathematica"->{
    Cell[3983, 136, 468, 9, 56, "Text",
      CellTags->{
      "Tour of Mathematica", "The Mathematica Journal", "Tricks of the Trade",
         "In and Out"}]},
  "The Mathematica Journal"->{
    Cell[3983, 136, 468, 9, 56, "Text",
      CellTags->{
      "Tour of Mathematica", "The Mathematica Journal", "Tricks of the Trade",
         "In and Out"}]},
  "Tricks of the Trade"->{
    Cell[3983, 136, 468, 9, 56, "Text",
      CellTags->{
      "Tour of Mathematica", "The Mathematica Journal", "Tricks of the Trade",
         "In and Out"}]},
  "In and Out"->{
    Cell[3983, 136, 468, 9, 56, "Text",
      CellTags->{
      "Tour of Mathematica", "The Mathematica Journal", "Tricks of the Trade",
         "In and Out"}]},
  "Interpreted code"->{
    Cell[4454, 147, 1037, 19, 124, "Text",
      CellTags->{"Interpreted code", "Compiled code", "Spreadsheet"}]},
  "Compiled code"->{
    Cell[4454, 147, 1037, 19, 124, "Text",
      CellTags->{"Interpreted code", "Compiled code", "Spreadsheet"}]},
  "Spreadsheet"->{
    Cell[4454, 147, 1037, 19, 124, "Text",
      CellTags->{"Interpreted code", "Compiled code", "Spreadsheet"}]},
  "Programming principles"->{
    Cell[5494, 168, 496, 11, 58, "Text",
      CellTags->{
      "Programming principles", "Program verification", "Efficiency", 
        "Generalisation"}]},
  "Program verification"->{
    Cell[5494, 168, 496, 11, 58, "Text",
      CellTags->{
      "Programming principles", "Program verification", "Efficiency", 
        "Generalisation"}],
    Cell[44747, 1688, 153, 4, 24, "Text",
      CellTags->"Program verification"]},
  "Efficiency"->{
    Cell[5494, 168, 496, 11, 58, "Text",
      CellTags->{
      "Programming principles", "Program verification", "Efficiency", 
        "Generalisation"}],
    Cell[7916, 241, 452, 10, 38, "BulletedList",
      CellTags->{
      "Recursive programming", "Efficiency", "Inductive programming"}],
    Cell[14086, 473, 175, 6, 24, "BulletedList",
      CellTags->"Efficiency"],
    Cell[19872, 720, 281, 9, 26, "Text",
      CellTags->"Efficiency"],
    Cell[23394, 870, 191, 6, 24, "Text",
      CellTags->"Efficiency"],
    Cell[36084, 1361, 835, 24, 42, "Text",
      CellTags->{"Trace", "Efficiency"}],
    Cell[44230, 1670, 316, 7, 42, "Text",
      CellTags->{"Efficiency", "Polynomials"}],
    Cell[188979, 5602, 478, 11, 38, "BulletedList",
      CellTags->{"List", "Efficiency", "Procedural programming"}]},
  "Generalisation"->{
    Cell[5494, 168, 496, 11, 58, "Text",
      CellTags->{
      "Programming principles", "Program verification", "Efficiency", 
        "Generalisation"}],
    Cell[9396, 281, 728, 14, 74, "Text",
      CellTags->{
      "Optimal programming style", "Functional programming", 
        "Generalisation"}],
    Cell[10622, 329, 302, 7, 40, "Text",
      CellTags->{"Gamma function", "Generalisation"}],
    Cell[13610, 458, 193, 4, 22, "BulletedList",
      CellTags->"Generalisation"],
    Cell[47404, 1798, 513, 14, 44, "Text",
      CellTags->{
      "Generalisation", "Functional programming", 
        "Spherical polar coordinates"}]},
  "Factorial"->{
    Cell[6985, 213, 523, 14, 44, "Text",
      CellTags->{"Factorial", "Programming styles"}]},
  "Programming styles"->{
    Cell[6985, 213, 523, 14, 44, "Text",
      CellTags->{"Factorial", "Programming styles"}]},
  "Procedural programming"->{
    Cell[7511, 229, 402, 10, 24, "BulletedList",
      CellTags->{"Procedural programming", "Functional programming"}],
    Cell[11225, 357, 192, 12, 32, "Subsection",
      CellTags->"Procedural programming"],
    Cell[11420, 371, 233, 7, 26, "Text",
      CellTags->"Procedural programming"],
    Cell[12798, 426, 121, 2, 22, "BulletedList",
      CellTags->"Procedural programming"],
    Cell[188979, 5602, 478, 11, 38, "BulletedList",
      CellTags->{"List", "Efficiency", "Procedural programming"}]},
  "Functional programming"->{
    Cell[7511, 229, 402, 10, 24, "BulletedList",
      CellTags->{"Procedural programming", "Functional programming"}],
    Cell[8771, 264, 622, 15, 38, "BulletedList",
      CellTags->{"Pair-wise operations", "Functional programming"}],
    Cell[9396, 281, 728, 14, 74, "Text",
      CellTags->{
      "Optimal programming style", "Functional programming", 
        "Generalisation"}],
    Cell[17832, 630, 192, 12, 32, "Subsection",
      CellTags->"Functional programming"],
    Cell[18027, 644, 284, 7, 26, "Text",
      CellTags->"Functional programming"],
    Cell[19451, 702, 187, 5, 26, "Text",
      CellTags->{"FoldList", "Functional programming"}],
    Cell[40217, 1497, 163, 9, 39, "Section",
      CellTags->"Functional programming"],
    Cell[47404, 1798, 513, 14, 44, "Text",
      CellTags->{
      "Generalisation", "Functional programming", 
        "Spherical polar coordinates"}],
    Cell[189460, 5615, 544, 11, 52, "BulletedList",
      CellTags->"Functional programming"]},
  "Recursive programming"->{
    Cell[7916, 241, 452, 10, 38, "BulletedList",
      CellTags->{
      "Recursive programming", "Efficiency", "Inductive programming"}],
    Cell[14298, 484, 190, 12, 32, "Subsection",
      CellTags->"Recursive programming"],
    Cell[16705, 586, 84, 1, 24, "Text",
      CellTags->"Recursive programming"]},
  "Inductive programming"->{
    Cell[7916, 241, 452, 10, 38, "BulletedList",
      CellTags->{
      "Recursive programming", "Efficiency", "Inductive programming"}]},
  "Series"->{
    Cell[8371, 253, 397, 9, 24, "BulletedList",
      CellTags->{
      "Series", "Asymptotic expansion", "Analytic representation"}],
    Cell[20684, 757, 172, 12, 32, "Subsection",
      CellTags->"Series"]},
  "Asymptotic expansion"->{
    Cell[8371, 253, 397, 9, 24, "BulletedList",
      CellTags->{
      "Series", "Asymptotic expansion", "Analytic representation"}]},
  "Analytic representation"->{
    Cell[8371, 253, 397, 9, 24, "BulletedList",
      CellTags->{
      "Series", "Asymptotic expansion", "Analytic representation"}]},
  "Pair-wise operations"->{
    Cell[8771, 264, 622, 15, 38, "BulletedList",
      CellTags->{"Pair-wise operations", "Functional programming"}]},
  "Optimal programming style"->{
    Cell[9396, 281, 728, 14, 74, "Text",
      CellTags->{
      "Optimal programming style", "Functional programming", 
        "Generalisation"}],
    Cell[13806, 464, 277, 7, 24, "BulletedList",
      CellTags->{"Optimal programming style", "Mathematica design"}]},
  "Gamma function"->{
    Cell[10622, 329, 302, 7, 40, "Text",
      CellTags->{"Gamma function", "Generalisation"}],
    Cell[20859, 771, 261, 8, 26, "Text",
      CellTags->{"Asymptotic series", "Gamma function"}]},
  "Pure function"->{
    Cell[12288, 405, 448, 17, 26, "Text",
      CellTags->"Pure function"]},
  "Compilation"->{
    Cell[12922, 430, 130, 3, 22, "BulletedList",
      CellTags->"Compilation"]},
  "Conversion to fortran or C"->{
    Cell[13055, 435, 166, 4, 22, "BulletedList",
      CellTags->"Conversion to fortran or C"]},
  "Dummy variables"->{
    Cell[13265, 443, 342, 13, 24, "BulletedList",
      CellTags->"Dummy variables"]},
  "Mathematica design"->{
    Cell[13806, 464, 277, 7, 24, "BulletedList",
      CellTags->{"Optimal programming style", "Mathematica design"}]},
  "Blank"->{
    Cell[14976, 518, 939, 30, 60, "Text",
      CellTags->{
      "Blank", "Generic variables", "Delayed assignment", "SetDelayed", 
        "Variable binding"}],
    Cell[156405, 4353, 171, 6, 24, "Text",
      CellTags->{"Generic variable", "Blank", "_"}],
    Cell[160809, 4555, 338, 11, 24, "Text",
      CellTags->{"Blank", "_"}]},
  "Generic variables"->{
    Cell[14976, 518, 939, 30, 60, "Text",
      CellTags->{
      "Blank", "Generic variables", "Delayed assignment", "SetDelayed", 
        "Variable binding"}]},
  "Delayed assignment"->{
    Cell[14976, 518, 939, 30, 60, "Text",
      CellTags->{
      "Blank", "Generic variables", "Delayed assignment", "SetDelayed", 
        "Variable binding"}]},
  "SetDelayed"->{
    Cell[14976, 518, 939, 30, 60, "Text",
      CellTags->{
      "Blank", "Generic variables", "Delayed assignment", "SetDelayed", 
        "Variable binding"}]},
  "Variable binding"->{
    Cell[14976, 518, 939, 30, 60, "Text",
      CellTags->{
      "Blank", "Generic variables", "Delayed assignment", "SetDelayed", 
        "Variable binding"}]},
  "Rule-based programming"->{
    Cell[16244, 562, 192, 12, 32, "Subsection",
      CellTags->"Rule-based programming"]},
  "$RecursionLimit"->{
    Cell[16877, 592, 239, 7, 26, "Text",
      CellTags->"$RecursionLimit"],
    Cell[185179, 5459, 298, 10, 26, "Text",
      CellTags->{"$RecursionLimit", "global variable"}]},
  "Natural implementation"->{
    Cell[17286, 610, 359, 8, 42, "Text",
      CellTags->"Natural implementation"],
    Cell[187072, 5544, 242, 7, 24, "BulletedList",
      CellTags->"Natural implementation"]},
  "Range"->{
    Cell[18314, 653, 276, 9, 26, "Text",
      CellTags->"Range"]},
  "Apply"->{
    Cell[18655, 667, 351, 12, 26, "Text",
      CellTags->{"Apply", "Times", "List"}]},
  "Times"->{
    Cell[18655, 667, 351, 12, 26, "Text",
      CellTags->{"Apply", "Times", "List"}]},
  "List"->{
    Cell[18655, 667, 351, 12, 26, "Text",
      CellTags->{"Apply", "Times", "List"}],
    Cell[188979, 5602, 478, 11, 38, "BulletedList",
      CellTags->{"List", "Efficiency", "Procedural programming"}]},
  "FoldList"->{
    Cell[19451, 702, 187, 5, 26, "Text",
      CellTags->{"FoldList", "Functional programming"}]},
  "Asymptotic series"->{
    Cell[20859, 771, 261, 8, 26, "Text",
      CellTags->{"Asymptotic series", "Gamma function"}]},
  "Truncation"->{
    Cell[21385, 792, 209, 7, 24, "Text",
      CellTags->{"Truncation", "Normal"}]},
  "Normal"->{
    Cell[21385, 792, 209, 7, 24, "Text",
      CellTags->{"Truncation", "Normal"}]},
  "Approximation"->{
    Cell[21825, 811, 406, 10, 42, "Text",
      CellTags->{
      "Approximation", "fractional error", "Stirling's formula"}]},
  "fractional error"->{
    Cell[21825, 811, 406, 10, 42, "Text",
      CellTags->{
      "Approximation", "fractional error", "Stirling's formula"}]},
  "Stirling's formula"->{
    Cell[21825, 811, 406, 10, 42, "Text",
      CellTags->{
      "Approximation", "fractional error", "Stirling's formula"}]},
  "Dynamic programming"->{
    Cell[23193, 856, 198, 12, 32, "Subsection",
      CellTags->"Dynamic programming"],
    Cell[24614, 925, 720, 22, 42, "Text",
      CellTags->"Dynamic programming"]},
  "Information"->{
    Cell[23747, 887, 345, 15, 26, "Text",
      CellTags->{"Information", "?"}]},
  "?"->{
    Cell[23747, 887, 345, 15, 26, "Text",
      CellTags->{"Information", "?"}],
    Cell[25747, 967, 180, 6, 24, "Text",
      CellTags->"?"],
    Cell[28963, 1088, 501, 14, 44, "Text",
      CellTags->{"Condition", "Positive", "Integer", "?"}],
    Cell[157414, 4403, 543, 19, 44, "Text",
      CellTags->{
      "Infix operator", "Shorthand", "Condition", "Pattern-matching", "?", 
        "Predicates"}]},
  "Storage"->{
    Cell[27642, 1036, 498, 8, 58, "Text",
      CellTags->{"Storage", "Remove"}]},
  "Remove"->{
    Cell[27642, 1036, 498, 8, 58, "Text",
      CellTags->{"Storage", "Remove"}]},
  "Argument checking"->{
    Cell[28177, 1049, 194, 12, 32, "Subsection",
      CellTags->"Argument checking"],
    Cell[32128, 1227, 580, 13, 42, "Text",
      CellTags->{
      "Argument checking", "Function arguments", "Message", "Error messages", 
        "Catch-all rule"}],
    Cell[32917, 1248, 364, 9, 26, "Text",
      CellTags->{
      "Condition", "Side-effect", "Argument checking", "Shorthand", 
        "Infix operator"}]},
  "Condition"->{
    Cell[28963, 1088, 501, 14, 44, "Text",
      CellTags->{"Condition", "Positive", "Integer", "?"}],
    Cell[32917, 1248, 364, 9, 26, "Text",
      CellTags->{
      "Condition", "Side-effect", "Argument checking", "Shorthand", 
        "Infix operator"}],
    Cell[34606, 1304, 305, 6, 42, "Text",
      CellTags->{"Condition", "Null"}],
    Cell[157414, 4403, 543, 19, 44, "Text",
      CellTags->{
      "Infix operator", "Shorthand", "Condition", "Pattern-matching", "?", 
        "Predicates"}]},
  "Positive"->{
    Cell[28963, 1088, 501, 14, 44, "Text",
      CellTags->{"Condition", "Positive", "Integer", "?"}]},
  "Integer"->{
    Cell[28963, 1088, 501, 14, 44, "Text",
      CellTags->{"Condition", "Positive", "Integer", "?"}]},
  "Syntax"->{
    Cell[29538, 1107, 147, 6, 26, "Text",
      CellTags->"Syntax"],
    Cell[152600, 4206, 303, 10, 26, "Text",
      CellTags->{"Syntax", "cumulative sum"}]},
  "Function arguments"->{
    Cell[31200, 1185, 251, 6, 26, "Text",
      CellTags->{"Function arguments", "Argument type"}],
    Cell[32128, 1227, 580, 13, 42, "Text",
      CellTags->{
      "Argument checking", "Function arguments", "Message", "Error messages", 
        "Catch-all rule"}]},
  "Argument type"->{
    Cell[31200, 1185, 251, 6, 26, "Text",
      CellTags->{"Function arguments", "Argument type"}]},
  "Options"->{
    Cell[31454, 1193, 135, 5, 22, "BeginNumberedList",
      CellTags->"Options"]},
  "Overloading"->{
    Cell[31592, 1200, 169, 6, 22, "NumberedList",
      CellTags->{"Overloading", "Object-Oriented Programming"}]},
  "Object-Oriented Programming"->{
    Cell[31592, 1200, 169, 6, 22, "NumberedList",
      CellTags->{"Overloading", "Object-Oriented Programming"}],
    Cell[165322, 4752, 396, 8, 42, "Text",
      CellTags->{"Object-Oriented Programming", "Association"}]},
  "Unspecified arguments"->{
    Cell[31898, 1215, 169, 6, 22, "NumberedList",
      CellTags->"Unspecified arguments"]},
  "Message"->{
    Cell[32128, 1227, 580, 13, 42, "Text",
      CellTags->{
      "Argument checking", "Function arguments", "Message", "Error messages", 
        "Catch-all rule"}]},
  "Error messages"->{
    Cell[32128, 1227, 580, 13, 42, "Text",
      CellTags->{
      "Argument checking", "Function arguments", "Message", "Error messages", 
        "Catch-all rule"}]},
  "Catch-all rule"->{
    Cell[32128, 1227, 580, 13, 42, "Text",
      CellTags->{
      "Argument checking", "Function arguments", "Message", "Error messages", 
        "Catch-all rule"}]},
  "Side-effect"->{
    Cell[32917, 1248, 364, 9, 26, "Text",
      CellTags->{
      "Condition", "Side-effect", "Argument checking", "Shorthand", 
        "Infix operator"}]},
  "Shorthand"->{
    Cell[32917, 1248, 364, 9, 26, "Text",
      CellTags->{
      "Condition", "Side-effect", "Argument checking", "Shorthand", 
        "Infix operator"}],
    Cell[155884, 4333, 518, 18, 26, "Text",
      CellTags->{"Infix operator", "ReplaceAll", "Rule", "Shorthand"}],
    Cell[157414, 4403, 543, 19, 44, "Text",
      CellTags->{
      "Infix operator", "Shorthand", "Condition", "Pattern-matching", "?", 
        "Predicates"}]},
  "Infix operator"->{
    Cell[32917, 1248, 364, 9, 26, "Text",
      CellTags->{
      "Condition", "Side-effect", "Argument checking", "Shorthand", 
        "Infix operator"}],
    Cell[155884, 4333, 518, 18, 26, "Text",
      CellTags->{"Infix operator", "ReplaceAll", "Rule", "Shorthand"}],
    Cell[157414, 4403, 543, 19, 44, "Text",
      CellTags->{
      "Infix operator", "Shorthand", "Condition", "Pattern-matching", "?", 
        "Predicates"}]},
  "Null"->{
    Cell[34606, 1304, 305, 6, 42, "Text",
      CellTags->{"Condition", "Null"}]},
  "Tracing computations"->{
    Cell[35881, 1347, 200, 12, 32, "Subsection",
      CellTags->"Tracing computations"],
    Cell[178829, 5214, 94, 1, 24, "Text",
      CellTags->"Tracing computations"]},
  "Trace"->{
    Cell[36084, 1361, 835, 24, 42, "Text",
      CellTags->{"Trace", "Efficiency"}],
    Cell[168881, 4884, 108, 3, 24, "Text",
      CellTags->"Trace"]},
  "Pattern-matching"->{
    Cell[36922, 1387, 508, 15, 26, "Text",
      CellTags->"Pattern-matching"],
    Cell[37941, 1423, 596, 18, 42, "Text",
      CellTags->"Pattern-matching"],
    Cell[157414, 4403, 543, 19, 44, "Text",
      CellTags->{
      "Infix operator", "Shorthand", "Condition", "Pattern-matching", "?", 
        "Predicates"}],
    Cell[163954, 4686, 344, 10, 24, "Text",
      CellTags->{"Tests", "User-defined rules", "Pattern-matching"}],
    Cell[168351, 4862, 290, 9, 24, "Text",
      CellTags->{"Associativity", "Orderless", "Pattern-matching"}]},
  "Horner representation"->{
    Cell[40913, 1531, 236, 7, 26, "Text",
      CellTags->"Horner representation"]},
  "Function"->{
    Cell[41418, 1549, 1292, 45, 42, "Warning",
      CellTags->"Function"]},
  "BaseForm"->{
    Cell[43054, 1613, 165, 5, 26, "Text",
      CellTags->"BaseForm"]},
  "IntegerDigits"->{
    Cell[43844, 1651, 205, 8, 26, "Text",
      CellTags->"IntegerDigits"],
    Cell[48352, 1839, 189, 4, 24, "Text",
      CellTags->{"FixedPoint", "IntegerDigits"}]},
  "Polynomials"->{
    Cell[44230, 1670, 316, 7, 42, "Text",
      CellTags->{"Efficiency", "Polynomials"}]},
  "Matrix power"->{
    Cell[45200, 1707, 260, 7, 24, "Text",
      CellTags->"Matrix power"]},
  "Jacobian matrix"->{
    Cell[45928, 1743, 426, 12, 42, "Text",
      CellTags->{"Jacobian matrix", "Outer"}]},
  "Outer"->{
    Cell[45928, 1743, 426, 12, 42, "Text",
      CellTags->{"Jacobian matrix", "Outer"}]},
  "Cartesian coordinates"->{
    Cell[46469, 1761, 339, 9, 24, "Text",
      CellTags->{
      "Cartesian coordinates", "Polar coordinates", "Volume element"}]},
  "Polar coordinates"->{
    Cell[46469, 1761, 339, 9, 24, "Text",
      CellTags->{
      "Cartesian coordinates", "Polar coordinates", "Volume element"}]},
  "Volume element"->{
    Cell[46469, 1761, 339, 9, 24, "Text",
      CellTags->{
      "Cartesian coordinates", "Polar coordinates", "Volume element"}]},
  "Spherical polar coordinates"->{
    Cell[47404, 1798, 513, 14, 44, "Text",
      CellTags->{
      "Generalisation", "Functional programming", 
        "Spherical polar coordinates"}]},
  "FixedPoint"->{
    Cell[48352, 1839, 189, 4, 24, "Text",
      CellTags->{"FixedPoint", "IntegerDigits"}]},
  "Logistic map"->{
    Cell[50016, 1918, 182, 6, 26, "Text",
      CellTags->{"Logistic map", "Dynamical system"}]},
  "Dynamical system"->{
    Cell[50016, 1918, 182, 6, 26, "Text",
      CellTags->{"Logistic map", "Dynamical system"}]},
  "NestList"->{
    Cell[50302, 1930, 224, 9, 24, "Text",
      CellTags->"NestList"]},
  "Random walk"->{
    Cell[109627, 2935, 211, 6, 26, "Text",
      CellTags->"Random walk"]},
  "cumulative sum"->{
    Cell[152600, 4206, 303, 10, 26, "Text",
      CellTags->{"Syntax", "cumulative sum"}]},
  "replacement rules"->{
    Cell[154901, 4302, 436, 11, 44, "Text",
      CellTags->{"replacement rules", "pattern-matching"}]},
  "pattern-matching"->{
    Cell[154901, 4302, 436, 11, 44, "Text",
      CellTags->{"replacement rules", "pattern-matching"}],
    Cell[160428, 4538, 172, 5, 24, "Text",
      CellTags->"pattern-matching"]},
  "ReplaceAll"->{
    Cell[155884, 4333, 518, 18, 26, "Text",
      CellTags->{"Infix operator", "ReplaceAll", "Rule", "Shorthand"}]},
  "Rule"->{
    Cell[155884, 4333, 518, 18, 26, "Text",
      CellTags->{"Infix operator", "ReplaceAll", "Rule", "Shorthand"}]},
  "Generic variable"->{
    Cell[156405, 4353, 171, 6, 24, "Text",
      CellTags->{"Generic variable", "Blank", "_"}]},
  "_"->{
    Cell[156405, 4353, 171, 6, 24, "Text",
      CellTags->{"Generic variable", "Blank", "_"}],
    Cell[160809, 4555, 338, 11, 24, "Text",
      CellTags->{"Blank", "_"}]},
  "Predicates"->{
    Cell[157414, 4403, 543, 19, 44, "Text",
      CellTags->{
      "Infix operator", "Shorthand", "Condition", "Pattern-matching", "?", 
        "Predicates"}],
    Cell[158579, 4453, 442, 15, 26, "Text",
      CellTags->{"Predicates", "ReadProtected"}]},
  "Tests"->{
    Cell[157960, 4424, 217, 9, 24, "Text",
      CellTags->"Tests"],
    Cell[163954, 4686, 344, 10, 24, "Text",
      CellTags->{"Tests", "User-defined rules", "Pattern-matching"}]},
  "ReadProtected"->{
    Cell[158579, 4453, 442, 15, 26, "Text",
      CellTags->{"Predicates", "ReadProtected"}]},
  "Boolean"->{
    Cell[159024, 4470, 246, 9, 24, "Text",
      CellTags->"Boolean"]},
  "PrimeQ"->{
    Cell[159433, 4490, 425, 13, 42, "Text",
      CellTags->"PrimeQ"]},
  "BlankSequence"->{
    Cell[161445, 4580, 170, 6, 25, "Text",
      CellTags->{"BlankSequence", "__"}]},
  "__"->{
    Cell[161445, 4580, 170, 6, 25, "Text",
      CellTags->{"BlankSequence", "__"}]},
  "Pattern variables"->{
    Cell[162016, 4601, 123, 3, 24, "Text",
      CellTags->"Pattern variables"]},
  "BlankNullSequence"->{
    Cell[162437, 4619, 91, 1, 24, "Text",
      CellTags->{"BlankNullSequence", "___"}]},
  "___"->{
    Cell[162437, 4619, 91, 1, 24, "Text",
      CellTags->{"BlankNullSequence", "___"}]},
  "User-defined rules"->{
    Cell[163954, 4686, 344, 10, 24, "Text",
      CellTags->{"Tests", "User-defined rules", "Pattern-matching"}],
    Cell[166181, 4781, 735, 16, 58, "Text",
      CellTags->{"Association", "User-defined rules", "Protected"}],
    Cell[188575, 5592, 401, 8, 41, "BulletedList",
      CellTags->{
      "Full names", "Descriptive names", "User-defined rules", 
        "Command Completion"}]},
  "Association"->{
    Cell[165322, 4752, 396, 8, 42, "Text",
      CellTags->{"Object-Oriented Programming", "Association"}],
    Cell[166181, 4781, 735, 16, 58, "Text",
      CellTags->{"Association", "User-defined rules", "Protected"}],
    Cell[167289, 4815, 305, 11, 24, "Text",
      CellTags->"Association"]},
  "Protected"->{
    Cell[166181, 4781, 735, 16, 58, "Text",
      CellTags->{"Association", "User-defined rules", "Protected"}]},
  "Associativity"->{
    Cell[168351, 4862, 290, 9, 24, "Text",
      CellTags->{"Associativity", "Orderless", "Pattern-matching"}]},
  "Orderless"->{
    Cell[168351, 4862, 290, 9, 24, "Text",
      CellTags->{"Associativity", "Orderless", "Pattern-matching"}]},
  "Notebooks"->{
    Cell[169459, 4916, 436, 7, 40, "Text",
      CellTags->{"Notebooks", "Front end"}]},
  "Front end"->{
    Cell[169459, 4916, 436, 7, 40, "Text",
      CellTags->{"Notebooks", "Front end"}]},
  "spreadsheet"->{
    Cell[175457, 5073, 93, 1, 24, "Text",
      CellTags->"spreadsheet"]},
  "Block"->{
    Cell[176869, 5126, 203, 9, 39, "Section",
      CellTags->{"Block", "Module", "Variable scoping"}],
    Cell[178444, 5194, 212, 9, 24, "Text",
      CellTags->"Block"],
    Cell[182844, 5384, 671, 14, 44, "Text",
      CellTags->{"Block", "System variable"}],
    Cell[185639, 5480, 319, 7, 26, "Text",
      CellTags->{"Block", "Module"}]},
  "Module"->{
    Cell[176869, 5126, 203, 9, 39, "Section",
      CellTags->{"Block", "Module", "Variable scoping"}],
    Cell[185639, 5480, 319, 7, 26, "Text",
      CellTags->{"Block", "Module"}]},
  "Variable scoping"->{
    Cell[176869, 5126, 203, 9, 39, "Section",
      CellTags->{"Block", "Module", "Variable scoping"}]},
  "Dynamic scoping"->{
    Cell[180261, 5262, 259, 9, 26, "Text",
      CellTags->"Dynamic scoping"]},
  "Lexical scoping"->{
    Cell[182426, 5358, 218, 8, 26, "Text",
      CellTags->"Lexical scoping"]},
  "System variable"->{
    Cell[182844, 5384, 671, 14, 44, "Text",
      CellTags->{"Block", "System variable"}]},
  "global variable"->{
    Cell[185179, 5459, 298, 10, 26, "Text",
      CellTags->{"$RecursionLimit", "global variable"}]},
  "Mathematica syntax"->{
    Cell[187317, 5553, 318, 8, 38, "BulletedList",
      CellTags->"Mathematica syntax"]},
  "Functional dependence"->{
    Cell[187638, 5563, 785, 21, 52, "BulletedList",
      CellTags->"Functional dependence"]},
  "Full names"->{
    Cell[188575, 5592, 401, 8, 41, "BulletedList",
      CellTags->{
      "Full names", "Descriptive names", "User-defined rules", 
        "Command Completion"}]},
  "Descriptive names"->{
    Cell[188575, 5592, 401, 8, 41, "BulletedList",
      CellTags->{
      "Full names", "Descriptive names", "User-defined rules", 
        "Command Completion"}]},
  "Command Completion"->{
    Cell[188575, 5592, 401, 8, 41, "BulletedList",
      CellTags->{
      "Full names", "Descriptive names", "User-defined rules", 
        "Command Completion"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"Kernel", 254467, 7923},
  {"Built-in functions", 254585, 7926},
  {"Tour of Mathematica", 254881, 7933},
  {"The Mathematica Journal", 255075, 7938},
  {"Tricks of the Trade", 255265, 7943},
  {"In and Out", 255446, 7948},
  {"Interpreted code", 255633, 7953},
  {"Compiled code", 255769, 7956},
  {"Spreadsheet", 255903, 7959},
  {"Programming principles", 256048, 7962},
  {"Program verification", 256235, 7967},
  {"Efficiency", 256495, 7974},
  {"Generalisation", 257333, 7994},
  {"Factorial", 257991, 8011},
  {"Programming styles", 258113, 8014},
  {"Procedural programming", 258239, 8017},
  {"Functional programming", 258776, 8028},
  {"Recursive programming", 259802, 8051},
  {"Inductive programming", 260143, 8059},
  {"Series", 260297, 8063},
  {"Asymptotic expansion", 260536, 8069},
  {"Analytic representation", 260703, 8073},
  {"Pair-wise operations", 260867, 8077},
  {"Optimal programming style", 261019, 8080},
  {"Gamma function", 261310, 8087},
  {"Pure function", 261527, 8092},
  {"Compilation", 261623, 8095},
  {"Conversion to fortran or C", 261739, 8098},
  {"Dummy variables", 261859, 8101},
  {"Mathematica design", 261972, 8104},
  {"Blank", 262105, 8107},
  {"Generic variables", 262467, 8116},
  {"Delayed assignment", 262657, 8121},
  {"SetDelayed", 262839, 8126},
  {"Variable binding", 263027, 8131},
  {"Rule-based programming", 263221, 8136},
  {"$RecursionLimit", 263336, 8139},
  {"Natural implementation", 263545, 8144},
  {"Range", 263737, 8149},
  {"Apply", 263818, 8152},
  {"Times", 263919, 8155},
  {"List", 264019, 8158},
  {"FoldList", 264242, 8163},
  {"Asymptotic series", 264366, 8166},
  {"Truncation", 264484, 8169},
  {"Normal", 264583, 8172},
  {"Approximation", 264689, 8175},
  {"fractional error", 264841, 8179},
  {"Stirling's formula", 264995, 8183},
  {"Dynamic programming", 265150, 8187},
  {"Information", 265340, 8192},
  {"?", 265431, 8195},
  {"Storage", 265856, 8206},
  {"Remove", 265953, 8209},
  {"Argument checking", 266061, 8212},
  {"Condition", 266491, 8223},
  {"Positive", 267012, 8236},
  {"Integer", 267131, 8239},
  {"Syntax", 267249, 8242},
  {"Function arguments", 267436, 8247},
  {"Argument type", 267726, 8254},
  {"Options", 267842, 8257},
  {"Overloading", 267945, 8260},
  {"Object-Oriented Programming", 268096, 8263},
  {"Unspecified arguments", 268349, 8268},
  {"Message", 268457, 8271},
  {"Error messages", 268648, 8276},
  {"Catch-all rule", 268839, 8281},
  {"Side-effect", 269027, 8286},
  {"Shorthand", 269202, 8291},
  {"Infix operator", 269660, 8302},
  {"Null", 270108, 8313},
  {"Tracing computations", 270219, 8316},
  {"Trace", 270406, 8321},
  {"Pattern-matching", 270585, 8326},
  {"Horner representation", 271163, 8339},
  {"Function", 271264, 8342},
  {"BaseForm", 271357, 8345},
  {"IntegerDigits", 271450, 8348},
  {"Polynomials", 271638, 8353},
  {"Matrix power", 271749, 8356},
  {"Jacobian matrix", 271848, 8359},
  {"Outer", 271952, 8362},
  {"Cartesian coordinates", 272072, 8365},
  {"Polar coordinates", 272230, 8369},
  {"Volume element", 272385, 8373},
  {"Spherical polar coordinates", 272553, 8377},
  {"FixedPoint", 272725, 8382},
  {"Logistic map", 272838, 8385},
  {"Dynamical system", 272960, 8388},
  {"NestList", 273074, 8391},
  {"Random walk", 273165, 8394},
  {"cumulative sum", 273263, 8397},
  {"replacement rules", 273380, 8400},
  {"pattern-matching", 273509, 8403},
  {"ReplaceAll", 273712, 8408},
  {"Rule", 273841, 8411},
  {"Generic variable", 273982, 8414},
  {"_", 274088, 8417},
  {"Predicates", 274280, 8422},
  {"Tests", 274550, 8429},
  {"ReadProtected", 274755, 8434},
  {"Boolean", 274865, 8437},
  {"PrimeQ", 274951, 8440},
  {"BlankSequence", 275044, 8443},
  {"__", 275140, 8446},
  {"Pattern variables", 275251, 8449},
  {"BlankNullSequence", 275358, 8452},
  {"___", 275459, 8455},
  {"User-defined rules", 275575, 8458},
  {"Association", 275987, 8467},
  {"Protected", 276302, 8474},
  {"Associativity", 276437, 8477},
  {"Orderless", 276567, 8480},
  {"Notebooks", 276697, 8483},
  {"Front end", 276803, 8486},
  {"spreadsheet", 276911, 8489},
  {"Block", 276999, 8492},
  {"Module", 277359, 8501},
  {"Variable scoping", 277569, 8506},
  {"Dynamic scoping", 277697, 8509},
  {"Lexical scoping", 277800, 8512},
  {"System variable", 277903, 8515},
  {"global variable", 278018, 8518},
  {"Mathematica syntax", 278146, 8521},
  {"Functional dependence", 278266, 8524},
  {"Full names", 278379, 8527},
  {"Descriptive names", 278570, 8532},
  {"Command Completion", 278762, 8537}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1717, 49, 45, 0, 26, "OnlineHeader"],

Cell[CellGroupData[{
Cell[1787, 53, 182, 8, 74, "Title",
  CounterAssignments->{{"Title", 1}}],
Cell[1972, 63, 29, 0, 26, "Author"],
Cell[2004, 65, 414, 12, 88, "Address"],

Cell[CellGroupData[{
Cell[2443, 81, 39, 0, 42, "Subsubsection"],
Cell[2485, 83, 215, 5, 42, "Text"],
Cell[2703, 90, 112, 2, 24, "Input",
  InitializationCell->True],
Cell[2818, 94, 85, 2, 24, "Text"],
Cell[2906, 98, 117, 2, 24, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[3060, 105, 120, 8, 41, "SectionFirst"],
Cell[3183, 115, 362, 8, 58, "Text"],
Cell[3548, 125, 432, 9, 58, "Text",
  CellTags->{"Kernel", "Built-in functions"}],
Cell[3983, 136, 468, 9, 56, "Text",
  CellTags->{
  "Tour of Mathematica", "The Mathematica Journal", "Tricks of the Trade", 
    "In and Out"}],
Cell[4454, 147, 1037, 19, 124, "Text",
  CellTags->{"Interpreted code", "Compiled code", "Spreadsheet"}],
Cell[5494, 168, 496, 11, 58, "Text",
  CellTags->{
  "Programming principles", "Program verification", "Efficiency", 
    "Generalisation"}],
Cell[5993, 181, 614, 11, 74, "Text"],
Cell[6610, 194, 222, 4, 40, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[6869, 203, 113, 8, 39, "Section"],
Cell[6985, 213, 523, 14, 44, "Text",
  CellTags->{"Factorial", "Programming styles"}],
Cell[7511, 229, 402, 10, 24, "BulletedList",
  CellTags->{"Procedural programming", "Functional programming"}],
Cell[7916, 241, 452, 10, 38, "BulletedList",
  CellTags->{
  "Recursive programming", "Efficiency", "Inductive programming"}],
Cell[8371, 253, 397, 9, 24, "BulletedList",
  CellTags->{"Series", "Asymptotic expansion", "Analytic representation"}],
Cell[8771, 264, 622, 15, 38, "BulletedList",
  CellTags->{"Pair-wise operations", "Functional programming"}],
Cell[9396, 281, 728, 14, 74, "Text",
  CellTags->{
  "Optimal programming style", "Functional programming", "Generalisation"}],

Cell[CellGroupData[{
Cell[10149, 299, 186, 12, 54, "Subsection",
  CellTags->"Built-in functions"],
Cell[10338, 313, 126, 5, 26, "Text"],

Cell[CellGroupData[{
Cell[10489, 322, 57, 1, 24, "Input"],
Cell[10549, 325, 58, 1, 22, "Output"]
}, Open  ]],
Cell[10622, 329, 302, 7, 40, "Text",
  CellTags->{"Gamma function", "Generalisation"}],

Cell[CellGroupData[{
Cell[10949, 340, 69, 1, 24, "Input"],
Cell[11021, 343, 58, 1, 22, "Output"]
}, Open  ]],
Cell[11094, 347, 94, 5, 48, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[11225, 357, 192, 12, 32, "Subsection",
  CellTags->"Procedural programming"],
Cell[11420, 371, 233, 7, 26, "Text",
  CellTags->"Procedural programming"],
Cell[11656, 380, 256, 5, 114, "Input"],

Cell[CellGroupData[{
Cell[11937, 389, 78, 1, 24, "Input"],
Cell[12018, 392, 55, 1, 22, "Output"]
}, Open  ]],
Cell[12088, 396, 197, 7, 48, "BeginEndQuestion"],
Cell[12288, 405, 448, 17, 26, "Text",
  CellTags->"Pure function"],
Cell[12739, 424, 56, 0, 24, "Text"],
Cell[12798, 426, 121, 2, 22, "BulletedList",
  CellTags->"Procedural programming"],
Cell[12922, 430, 130, 3, 22, "BulletedList",
  CellTags->"Compilation"],
Cell[13055, 435, 166, 4, 22, "BulletedList",
  CellTags->"Conversion to fortran or C"],
Cell[13224, 441, 38, 0, 24, "Text"],
Cell[13265, 443, 342, 13, 24, "BulletedList",
  CellTags->"Dummy variables"],
Cell[13610, 458, 193, 4, 22, "BulletedList",
  CellTags->"Generalisation"],
Cell[13806, 464, 277, 7, 24, "BulletedList",
  CellTags->{"Optimal programming style", "Mathematica design"}],
Cell[14086, 473, 175, 6, 24, "BulletedList",
  CellTags->"Efficiency"]
}, Closed]],

Cell[CellGroupData[{
Cell[14298, 484, 190, 12, 32, "Subsection",
  CellTags->"Recursive programming"],
Cell[14491, 498, 195, 5, 26, "Text"],
Cell[14689, 505, 112, 2, 24, "Input"],

Cell[CellGroupData[{
Cell[14826, 511, 77, 1, 24, "Input"],
Cell[14906, 514, 55, 1, 22, "Output"]
}, Open  ]],
Cell[14976, 518, 939, 30, 60, "Text",
  CellTags->{
  "Blank", "Generic variables", "Delayed assignment", "SetDelayed", 
    "Variable binding"}],
Cell[15918, 550, 289, 7, 62, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[16244, 562, 192, 12, 32, "Subsection",
  CellTags->"Rule-based programming"],
Cell[16439, 576, 191, 5, 26, "Text"],
Cell[16633, 583, 69, 1, 24, "Input"],
Cell[16705, 586, 84, 1, 24, "Text",
  CellTags->"Recursive programming"],
Cell[16792, 589, 82, 1, 24, "Input"],
Cell[16877, 592, 239, 7, 26, "Text",
  CellTags->"$RecursionLimit"],

Cell[CellGroupData[{
Cell[17141, 603, 72, 1, 24, "Input"],
Cell[17216, 606, 55, 1, 22, "Output"]
}, Open  ]],
Cell[17286, 610, 359, 8, 42, "Text",
  CellTags->"Natural implementation"],
Cell[17648, 620, 147, 5, 48, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[17832, 630, 192, 12, 32, "Subsection",
  CellTags->"Functional programming"],
Cell[18027, 644, 284, 7, 26, "Text",
  CellTags->"Functional programming"],
Cell[18314, 653, 276, 9, 26, "Text",
  CellTags->"Range"],
Cell[18593, 664, 59, 1, 24, "Input"],
Cell[18655, 667, 351, 12, 26, "Text",
  CellTags->{"Apply", "Times", "List"}],
Cell[19009, 681, 58, 1, 24, "Input"],
Cell[19070, 684, 58, 0, 24, "Text"],
Cell[19131, 686, 86, 1, 24, "Input"],

Cell[CellGroupData[{
Cell[19242, 691, 78, 1, 24, "Input"],
Cell[19323, 694, 55, 1, 22, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19415, 700, 33, 0, 42, "Subsubsection"],
Cell[19451, 702, 187, 5, 26, "Text",
  CellTags->{"FoldList", "Functional programming"}],

Cell[CellGroupData[{
Cell[19663, 711, 63, 1, 24, "Input"],
Cell[19729, 714, 128, 3, 36, "Print"]
}, Open  ]],
Cell[19872, 720, 281, 9, 26, "Text",
  CellTags->"Efficiency"],

Cell[CellGroupData[{
Cell[20178, 733, 79, 1, 24, "Input"],
Cell[20260, 736, 112, 2, 22, "Output"]
}, Open  ]],
Cell[20387, 741, 248, 10, 52, "BeginEndQuestion"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[20684, 757, 172, 12, 32, "Subsection",
  CellTags->"Series"],
Cell[20859, 771, 261, 8, 26, "Text",
  CellTags->{"Asymptotic series", "Gamma function"}],

Cell[CellGroupData[{
Cell[21145, 783, 112, 2, 24, "Input"],
Cell[21260, 787, 110, 2, 46, "Output"]
}, Open  ]],
Cell[21385, 792, 209, 7, 24, "Text",
  CellTags->{"Truncation", "Normal"}],

Cell[CellGroupData[{
Cell[21619, 803, 70, 1, 24, "Input"],
Cell[21692, 806, 118, 2, 46, "Output"]
}, Open  ]],
Cell[21825, 811, 406, 10, 42, "Text",
  CellTags->{"Approximation", "fractional error", "Stirling's formula"}],

Cell[CellGroupData[{
Cell[22256, 825, 109, 2, 39, "Input"],
Cell[22368, 829, 297, 4, 22, "Output"]
}, Open  ]],
Cell[22680, 836, 199, 4, 24, "Text"],
Cell[22882, 842, 274, 9, 48, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[23193, 856, 198, 12, 32, "Subsection",
  CellTags->"Dynamic programming"],
Cell[23394, 870, 191, 6, 24, "Text",
  CellTags->"Efficiency"],

Cell[CellGroupData[{
Cell[23610, 880, 61, 1, 24, "Input"],
Cell[23674, 883, 58, 1, 22, "Output"]
}, Open  ]],
Cell[23747, 887, 345, 15, 26, "Text",
  CellTags->{"Information", "?"}],

Cell[CellGroupData[{
Cell[24117, 906, 62, 1, 24, "Input"],
Cell[24182, 909, 66, 1, 36, "Print"],
Cell[24251, 912, 348, 10, 64, "Print"]
}, Open  ]],
Cell[24614, 925, 720, 22, 42, "Text",
  CellTags->"Dynamic programming"],
Cell[25337, 949, 73, 1, 24, "Input"],
Cell[25413, 952, 117, 2, 24, "Input"],
Cell[25533, 956, 56, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[25614, 960, 63, 1, 24, "Input"],
Cell[25680, 963, 52, 1, 22, "Output"]
}, Open  ]],
Cell[25747, 967, 180, 6, 24, "Text",
  CellTags->"?"],

Cell[CellGroupData[{
Cell[25952, 977, 65, 1, 24, "Input"],
Cell[26020, 980, 69, 1, 36, "Print"],
Cell[26092, 983, 522, 15, 148, "Print"]
}, Open  ]],
Cell[26629, 1001, 672, 20, 70, "BeginEndQuestion"],
Cell[27304, 1023, 335, 11, 52, "BeginEndQuestion"],
Cell[27642, 1036, 498, 8, 58, "Text",
  CellTags->{"Storage", "Remove"}]
}, Closed]],

Cell[CellGroupData[{
Cell[28177, 1049, 194, 12, 32, "Subsection",
  CellTags->"Argument checking"],
Cell[28374, 1063, 177, 5, 24, "Text"],
Cell[28554, 1070, 385, 14, 49, "BeginEndQuestion"],
Cell[28942, 1086, 18, 0, 32, "Answer"],
Cell[28963, 1088, 501, 14, 44, "Text",
  CellTags->{"Condition", "Positive", "Integer", "?"}],
Cell[29467, 1104, 68, 1, 24, "Input"],
Cell[29538, 1107, 147, 6, 26, "Text",
  CellTags->"Syntax"],
Cell[29688, 1115, 73, 1, 24, "Input"],
Cell[29764, 1118, 136, 3, 24, "Input"],
Cell[29903, 1123, 70, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[29998, 1127, 63, 1, 24, "Input"],
Cell[30064, 1130, 52, 1, 22, "Output"]
}, Open  ]],
Cell[30131, 1134, 27, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[30183, 1138, 63, 1, 24, "Input"],
Cell[30249, 1141, 64, 1, 22, "Output"]
}, Open  ]],
Cell[30328, 1145, 128, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[30481, 1153, 68, 1, 24, "Input"],
Cell[30552, 1156, 69, 1, 22, "Output"]
}, Open  ]],
Cell[30636, 1160, 130, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[30791, 1168, 65, 1, 24, "Input"],
Cell[30859, 1171, 203, 5, 22, "Output"]
}, Open  ]],
Cell[31077, 1179, 120, 4, 26, "Text"],
Cell[31200, 1185, 251, 6, 26, "Text",
  CellTags->{"Function arguments", "Argument type"}],
Cell[31454, 1193, 135, 5, 22, "BeginNumberedList",
  CellTags->"Options"],
Cell[31592, 1200, 169, 6, 22, "NumberedList",
  CellTags->{"Overloading", "Object-Oriented Programming"}],
Cell[31764, 1208, 131, 5, 22, "NumberedList"],
Cell[31898, 1215, 169, 6, 22, "NumberedList",
  CellTags->"Unspecified arguments"],

Cell[CellGroupData[{
Cell[32092, 1225, 33, 0, 42, "Subsubsection"],
Cell[32128, 1227, 580, 13, 42, "Text",
  CellTags->{
  "Argument checking", "Function arguments", "Message", "Error messages", 
    "Catch-all rule"}],
Cell[32711, 1242, 203, 4, 24, "Input"],
Cell[32917, 1248, 364, 9, 26, "Text",
  CellTags->{
  "Condition", "Side-effect", "Argument checking", "Shorthand", 
    "Infix operator"}],

Cell[CellGroupData[{
Cell[33306, 1261, 57, 1, 24, "Input"],
Cell[33366, 1264, 313, 5, 50, "Print"]
}, Open  ]],
Cell[33694, 1272, 484, 14, 42, "Text"],

Cell[CellGroupData[{
Cell[34203, 1290, 66, 1, 24, "Input"],
Cell[34272, 1293, 249, 5, 17, "Message"],
Cell[34524, 1300, 67, 1, 22, "Output"]
}, Open  ]],
Cell[34606, 1304, 305, 6, 42, "Text",
  CellTags->{"Condition", "Null"}],

Cell[CellGroupData[{
Cell[34936, 1314, 65, 1, 24, "Input"],
Cell[35004, 1317, 69, 1, 36, "Print"],
Cell[35076, 1320, 744, 20, 176, "Print"]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[35881, 1347, 200, 12, 32, "Subsection",
  CellTags->"Tracing computations"],
Cell[36084, 1361, 835, 24, 42, "Text",
  CellTags->{"Trace", "Efficiency"}],
Cell[36922, 1387, 508, 15, 26, "Text",
  CellTags->"Pattern-matching"],

Cell[CellGroupData[{
Cell[37455, 1406, 85, 1, 24, "Input"],
Cell[37543, 1409, 383, 11, 22, "Output"]
}, Open  ]],
Cell[37941, 1423, 596, 18, 42, "Text",
  CellTags->"Pattern-matching"],

Cell[CellGroupData[{
Cell[38562, 1445, 104, 2, 24, "Input"],
Cell[38669, 1449, 878, 20, 22, "Output"]
}, Open  ]],
Cell[39562, 1472, 606, 19, 66, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[40217, 1497, 163, 9, 39, "Section",
  CellTags->"Functional programming"],
Cell[40383, 1508, 347, 6, 40, "Text"],

Cell[CellGroupData[{
Cell[40755, 1518, 155, 11, 54, "Subsection"],
Cell[40913, 1531, 236, 7, 26, "Text",
  CellTags->"Horner representation"],
Cell[41152, 1540, 263, 7, 24, "Input"],
Cell[41418, 1549, 1292, 45, 42, "Warning",
  CellTags->"Function"],
Cell[42713, 1596, 167, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[42905, 1606, 76, 1, 24, "Input"],
Cell[42984, 1609, 55, 1, 22, "Output"]
}, Open  ]],
Cell[43054, 1613, 165, 5, 26, "Text",
  CellTags->"BaseForm"],

Cell[CellGroupData[{
Cell[43244, 1622, 69, 1, 24, "Input"],
Cell[43316, 1625, 186, 6, 34, "Output"]
}, Open  ]],
Cell[43517, 1634, 163, 6, 26, "Text"],

Cell[CellGroupData[{
Cell[43705, 1644, 66, 1, 24, "Input"],
Cell[43774, 1647, 55, 1, 22, "Output"]
}, Open  ]],
Cell[43844, 1651, 205, 8, 26, "Text",
  CellTags->"IntegerDigits"],

Cell[CellGroupData[{
Cell[44074, 1663, 72, 1, 24, "Input"],
Cell[44149, 1666, 66, 1, 22, "Output"]
}, Open  ]],
Cell[44230, 1670, 316, 7, 42, "Text",
  CellTags->{"Efficiency", "Polynomials"}],

Cell[CellGroupData[{
Cell[44571, 1681, 73, 1, 24, "Input"],
Cell[44647, 1684, 85, 1, 22, "Output"]
}, Open  ]],
Cell[44747, 1688, 153, 4, 24, "Text",
  CellTags->"Program verification"],

Cell[CellGroupData[{
Cell[44925, 1696, 81, 1, 24, "Input"],
Cell[45009, 1699, 79, 1, 25, "Output"]
}, Open  ]],
Cell[45103, 1703, 94, 2, 24, "Text"],
Cell[45200, 1707, 260, 7, 24, "Text",
  CellTags->"Matrix power"],
Cell[45463, 1716, 261, 9, 52, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[45761, 1730, 164, 11, 32, "Subsection"],
Cell[45928, 1743, 426, 12, 42, "Text",
  CellTags->{"Jacobian matrix", "Outer"}],
Cell[46357, 1757, 109, 2, 24, "Input"],
Cell[46469, 1761, 339, 9, 24, "Text",
  CellTags->{
  "Cartesian coordinates", "Polar coordinates", "Volume element"}],

Cell[CellGroupData[{
Cell[46833, 1774, 125, 3, 24, "Input"],
Cell[46961, 1779, 229, 5, 37, "Output"]
}, Open  ]],
Cell[47205, 1787, 36, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[47266, 1791, 68, 1, 24, "Input"],
Cell[47337, 1794, 52, 1, 22, "Output"]
}, Open  ]],
Cell[47404, 1798, 513, 14, 44, "Text",
  CellTags->{
  "Generalisation", "Functional programming", 
    "Spherical polar coordinates"}],
Cell[47920, 1814, 235, 7, 52, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[48192, 1826, 157, 11, 32, "Subsection"],
Cell[48352, 1839, 189, 4, 24, "Text",
  CellTags->{"FixedPoint", "IntegerDigits"}],
Cell[48544, 1845, 112, 2, 24, "Input"],

Cell[CellGroupData[{
Cell[48681, 1851, 70, 1, 24, "Input"],
Cell[48754, 1854, 52, 1, 22, "Output"]
}, Open  ]],
Cell[48821, 1858, 549, 22, 48, "BeginEndQuestion"],
Cell[49373, 1882, 426, 16, 48, "BeginEndQuestion"],
Cell[49802, 1900, 18, 0, 32, "Answer"]
}, Closed]],

Cell[CellGroupData[{
Cell[49857, 1905, 156, 11, 32, "Subsection"],
Cell[50016, 1918, 182, 6, 26, "Text",
  CellTags->{"Logistic map", "Dynamical system"}],
Cell[50201, 1926, 98, 2, 28, "Input"],
Cell[50302, 1930, 224, 9, 24, "Text",
  CellTags->"NestList"],

Cell[CellGroupData[{
Cell[50551, 1943, 82, 1, 26, "Input"],
Cell[50636, 1946, 1616, 26, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52289, 1977, 92, 1, 24, "Input"],
Cell[52384, 1980, 56850, 927, 188, 3739, 267, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[109249, 2910, 183, 7, 48, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[109469, 2922, 155, 11, 32, "Subsection"],
Cell[109627, 2935, 211, 6, 26, "Text",
  CellTags->"Random walk"],
Cell[109841, 2943, 66, 1, 24, "Input"],
Cell[109910, 2946, 180, 6, 24, "Text"],
Cell[110093, 2954, 83, 1, 24, "Input"],
Cell[110179, 2957, 137, 5, 24, "Text"],

Cell[CellGroupData[{
Cell[110341, 2966, 66, 1, 24, "Input"],
Cell[110410, 2969, 190, 4, 22, "Output"]
}, Open  ]],
Cell[110615, 2976, 188, 5, 24, "Text"],
Cell[110806, 2983, 132, 3, 26, "Input"],
Cell[110941, 2988, 131, 3, 39, "Input"],
Cell[111075, 2993, 82, 1, 24, "Input"],
Cell[111160, 2996, 671, 22, 42, "Warning"],
Cell[111834, 3020, 224, 9, 24, "Text"],
Cell[112061, 3031, 124, 3, 24, "Input"],
Cell[112188, 3036, 22, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[112235, 3040, 63, 1, 24, "Input"],
Cell[112301, 3043, 502, 10, 101, "Output"]
}, Open  ]],
Cell[112818, 3056, 76, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[112919, 3060, 189, 4, 24, "Input"],
Cell[113111, 3066, 39134, 1121, 201, 11584, 776, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[152260, 4190, 132, 5, 24, "Text"],

Cell[CellGroupData[{
Cell[152417, 4199, 78, 1, 24, "Input"],
Cell[152498, 4202, 87, 1, 22, "Output"]
}, Open  ]],
Cell[152600, 4206, 303, 10, 26, "Text",
  CellTags->{"Syntax", "cumulative sum"}],

Cell[CellGroupData[{
Cell[152928, 4220, 90, 1, 24, "Input"],
Cell[153021, 4223, 210, 6, 53, "Output"]
}, Open  ]],
Cell[153246, 4232, 812, 27, 64, "BeginEndQuestion"],
Cell[154061, 4261, 647, 25, 64, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[154757, 4292, 141, 8, 39, "Section"],
Cell[154901, 4302, 436, 11, 44, "Text",
  CellTags->{"replacement rules", "pattern-matching"}],
Cell[155340, 4315, 294, 4, 40, "Text"],
Cell[155637, 4321, 64, 1, 24, "Input"],

Cell[CellGroupData[{
Cell[155726, 4326, 77, 1, 24, "Input"],
Cell[155806, 4329, 63, 1, 22, "Output"]
}, Open  ]],
Cell[155884, 4333, 518, 18, 26, "Text",
  CellTags->{"Infix operator", "ReplaceAll", "Rule", "Shorthand"}],
Cell[156405, 4353, 171, 6, 24, "Text",
  CellTags->{"Generic variable", "Blank", "_"}],

Cell[CellGroupData[{
Cell[156601, 4363, 78, 1, 24, "Input"],
Cell[156682, 4366, 69, 1, 22, "Output"]
}, Open  ]],
Cell[156766, 4370, 227, 11, 24, "Text"],
Cell[156996, 4383, 236, 3, 40, "Text"],

Cell[CellGroupData[{
Cell[157257, 4390, 154, 11, 54, "Subsection"],
Cell[157414, 4403, 543, 19, 44, "Text",
  CellTags->{
  "Infix operator", "Shorthand", "Condition", "Pattern-matching", "?", 
    "Predicates"}],
Cell[157960, 4424, 217, 9, 24, "Text",
  CellTags->"Tests"],

Cell[CellGroupData[{
Cell[158202, 4437, 90, 1, 24, "Input"],
Cell[158295, 4440, 66, 1, 22, "Output"]
}, Open  ]],
Cell[158376, 4444, 200, 7, 48, "BeginEndQuestion"],
Cell[158579, 4453, 442, 15, 26, "Text",
  CellTags->{"Predicates", "ReadProtected"}],
Cell[159024, 4470, 246, 9, 24, "Text",
  CellTags->"Boolean"],

Cell[CellGroupData[{
Cell[159295, 4483, 65, 1, 24, "Input"],
Cell[159363, 4486, 55, 1, 22, "Output"]
}, Open  ]],
Cell[159433, 4490, 425, 13, 42, "Text",
  CellTags->"PrimeQ"],

Cell[CellGroupData[{
Cell[159883, 4507, 91, 1, 25, "Input"],
Cell[159977, 4510, 67, 1, 22, "Output"]
}, Open  ]],
Cell[160059, 4514, 174, 6, 48, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[160270, 4525, 155, 11, 54, "Subsection"],
Cell[160428, 4538, 172, 5, 24, "Text",
  CellTags->"pattern-matching"],

Cell[CellGroupData[{
Cell[160625, 4547, 113, 2, 24, "Input"],
Cell[160741, 4551, 53, 1, 22, "Output"]
}, Open  ]],
Cell[160809, 4555, 338, 11, 24, "Text",
  CellTags->{"Blank", "_"}],

Cell[CellGroupData[{
Cell[161172, 4570, 56, 1, 24, "Input"],
Cell[161231, 4573, 199, 4, 36, "Print"]
}, Open  ]],
Cell[161445, 4580, 170, 6, 25, "Text",
  CellTags->{"BlankSequence", "__"}],

Cell[CellGroupData[{
Cell[161640, 4590, 57, 1, 24, "Input"],
Cell[161700, 4593, 301, 5, 50, "Print"]
}, Open  ]],
Cell[162016, 4601, 123, 3, 24, "Text",
  CellTags->"Pattern variables"],

Cell[CellGroupData[{
Cell[162164, 4608, 114, 2, 24, "Input"],
Cell[162281, 4612, 141, 4, 22, "Output"]
}, Open  ]],
Cell[162437, 4619, 91, 1, 24, "Text",
  CellTags->{"BlankNullSequence", "___"}],

Cell[CellGroupData[{
Cell[162553, 4624, 58, 1, 24, "Input"],
Cell[162614, 4627, 302, 5, 50, "Print"]
}, Open  ]],
Cell[162931, 4635, 56, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[163012, 4639, 120, 3, 24, "Input"],
Cell[163135, 4644, 250, 7, 69, "Output"]
}, Open  ]],
Cell[163400, 4654, 217, 8, 48, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[163654, 4667, 157, 11, 54, "Subsection"],
Cell[163814, 4680, 32, 0, 24, "Text"],
Cell[163849, 4682, 102, 2, 24, "Input"],
Cell[163954, 4686, 344, 10, 24, "Text",
  CellTags->{"Tests", "User-defined rules", "Pattern-matching"}],

Cell[CellGroupData[{
Cell[164323, 4700, 164, 3, 24, "Input"],
Cell[164490, 4705, 67, 1, 22, "Output"]
}, Open  ]],
Cell[164572, 4709, 226, 9, 48, "BeginEndQuestion"],
Cell[164801, 4720, 355, 16, 50, "BeginEndQuestion"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[165205, 4742, 114, 8, 39, "Section"],
Cell[165322, 4752, 396, 8, 42, "Text",
  CellTags->{"Object-Oriented Programming", "Association"}],
Cell[165721, 4762, 30, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[165776, 4766, 75, 1, 24, "Input"],
Cell[165854, 4769, 251, 6, 17, "Message"],
Cell[166108, 4777, 58, 1, 22, "Output"]
}, Open  ]],
Cell[166181, 4781, 735, 16, 58, "Text",
  CellTags->{"Association", "User-defined rules", "Protected"}],

Cell[CellGroupData[{
Cell[166941, 4801, 57, 1, 24, "Input"],
Cell[167001, 4804, 157, 3, 36, "Print"]
}, Open  ]],
Cell[167173, 4810, 30, 0, 24, "Text"],
Cell[167206, 4812, 80, 1, 24, "Input"],
Cell[167289, 4815, 305, 11, 24, "Text",
  CellTags->"Association"],

Cell[CellGroupData[{
Cell[167619, 4830, 56, 1, 24, "Input"],
Cell[167678, 4833, 60, 1, 36, "Print"],
Cell[167741, 4836, 306, 9, 36, "Print"]
}, Open  ]],
Cell[168062, 4848, 115, 3, 24, "Text"],

Cell[CellGroupData[{
Cell[168202, 4855, 68, 1, 24, "Input"],
Cell[168273, 4858, 63, 1, 22, "Output"]
}, Open  ]],
Cell[168351, 4862, 290, 9, 24, "Text",
  CellTags->{"Associativity", "Orderless", "Pattern-matching"}],

Cell[CellGroupData[{
Cell[168666, 4875, 66, 1, 24, "Input"],
Cell[168735, 4878, 131, 3, 22, "Output"]
}, Open  ]],
Cell[168881, 4884, 108, 3, 24, "Text",
  CellTags->"Trace"],
Cell[168992, 4889, 306, 12, 48, "BeginEndQuestion"]
}, Closed]],

Cell[CellGroupData[{
Cell[169335, 4906, 121, 8, 39, "Section"],
Cell[169459, 4916, 436, 7, 40, "Text",
  CellTags->{"Notebooks", "Front end"}],

Cell[CellGroupData[{
Cell[169920, 4927, 161, 11, 54, "Subsection"],
Cell[170084, 4940, 199, 6, 24, "Text"],
Cell[170286, 4948, 81, 1, 24, "Input"],
Cell[170370, 4951, 65, 1, 24, "Input"],

Cell[CellGroupData[{
Cell[170460, 4956, 154, 2, 24, "Input"],
Cell[170617, 4960, 4544, 98, 294, 737, 46, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[175176, 5061, 278, 10, 48, "BeginEndQuestion"],
Cell[175457, 5073, 93, 1, 24, "Text",
  CellTags->"spreadsheet"]
}, Closed]],

Cell[CellGroupData[{
Cell[175587, 5079, 188, 11, 32, "Subsection"],
Cell[175778, 5092, 272, 7, 26, "Text"],
Cell[176053, 5101, 289, 4, 78, "Input"],
Cell[176345, 5107, 134, 4, 48, "BeginEndQuestion"],
Cell[176482, 5113, 338, 7, 42, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[176869, 5126, 203, 9, 39, "Section",
  CellTags->{"Block", "Module", "Variable scoping"}],
Cell[177075, 5137, 651, 16, 44, "Text"],
Cell[177729, 5155, 360, 11, 42, "Text"],

Cell[CellGroupData[{
Cell[178114, 5170, 149, 11, 54, "Subsection"],
Cell[178266, 5183, 22, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[178313, 5187, 58, 1, 25, "Input"],
Cell[178374, 5190, 55, 1, 25, "Output"]
}, Open  ]],
Cell[178444, 5194, 212, 9, 24, "Text",
  CellTags->"Block"],

Cell[CellGroupData[{
Cell[178681, 5207, 71, 1, 24, "Input"],
Cell[178755, 5210, 59, 1, 25, "Output"]
}, Open  ]],
Cell[178829, 5214, 94, 1, 24, "Text",
  CellTags->"Tracing computations"],

Cell[CellGroupData[{
Cell[178948, 5219, 78, 1, 24, "Input"],
Cell[179029, 5222, 1217, 37, 25, "Output"]
}, Open  ]],
Cell[180261, 5262, 259, 9, 26, "Text",
  CellTags->"Dynamic scoping"]
}, Closed]],

Cell[CellGroupData[{
Cell[180557, 5276, 150, 11, 32, "Subsection"],
Cell[180710, 5289, 225, 8, 24, "Text"],

Cell[CellGroupData[{
Cell[180960, 5301, 72, 1, 24, "Input"],
Cell[181035, 5304, 59, 1, 25, "Output"]
}, Open  ]],
Cell[181109, 5308, 263, 11, 24, "Text"],

Cell[CellGroupData[{
Cell[181397, 5323, 79, 1, 24, "Input"],
Cell[181479, 5326, 932, 29, 25, "Output"]
}, Open  ]],
Cell[182426, 5358, 218, 8, 26, "Text",
  CellTags->"Lexical scoping"]
}, Closed]],

Cell[CellGroupData[{
Cell[182681, 5371, 160, 11, 32, "Subsection"],
Cell[182844, 5384, 671, 14, 44, "Text",
  CellTags->{"Block", "System variable"}],
Cell[183518, 5400, 167, 4, 114, "Input"],
Cell[183688, 5406, 46, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[183759, 5410, 74, 1, 24, "Input"],
Cell[183836, 5413, 55, 1, 22, "Output"]
}, Open  ]],
Cell[183906, 5417, 116, 5, 24, "Text"],

Cell[CellGroupData[{
Cell[184047, 5426, 56, 1, 24, "Input"],
Cell[184106, 5429, 60, 1, 36, "Print"]
}, Open  ]],
Cell[184181, 5433, 75, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[184281, 5437, 58, 1, 24, "Input"],
Cell[184342, 5440, 216, 5, 17, "Message"],
Cell[184561, 5447, 603, 9, 67, "Output"]
}, Open  ]],
Cell[185179, 5459, 298, 10, 26, "Text",
  CellTags->{"$RecursionLimit", "global variable"}],

Cell[CellGroupData[{
Cell[185502, 5473, 65, 1, 24, "Input"],
Cell[185570, 5476, 54, 1, 22, "Output"]
}, Open  ]],
Cell[185639, 5480, 319, 7, 26, "Text",
  CellTags->{"Block", "Module"}],
Cell[185961, 5489, 245, 6, 150, "Input"],
Cell[186209, 5497, 71, 0, 24, "Text"],

Cell[CellGroupData[{
Cell[186305, 5501, 76, 1, 24, "Input"],
Cell[186384, 5504, 55, 1, 22, "Output"]
}, Open  ]],
Cell[186454, 5508, 138, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[186617, 5516, 65, 1, 24, "Input"],
Cell[186685, 5519, 54, 1, 22, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[186800, 5527, 110, 8, 39, "Section"],
Cell[186913, 5537, 156, 5, 26, "Text"],
Cell[187072, 5544, 242, 7, 24, "BulletedList",
  CellTags->"Natural implementation"],
Cell[187317, 5553, 318, 8, 38, "BulletedList",
  CellTags->"Mathematica syntax"],
Cell[187638, 5563, 785, 21, 52, "BulletedList",
  CellTags->"Functional dependence"],
Cell[188426, 5586, 146, 4, 22, "BulletedList",
  CellTags->"Built-in functions"],
Cell[188575, 5592, 401, 8, 41, "BulletedList",
  CellTags->{
  "Full names", "Descriptive names", "User-defined rules", 
    "Command Completion"}],
Cell[188979, 5602, 478, 11, 38, "BulletedList",
  CellTags->{"List", "Efficiency", "Procedural programming"}],
Cell[189460, 5615, 544, 11, 52, "BulletedList",
  CellTags->"Functional programming"]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

